/* version.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from version.vala, do not modify */

#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include "pamac.h"

#define VERSION "11.7.4"
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

gchar*
pamac_get_version (void)
{
	gchar* _tmp0_;
	gchar* result;
	_tmp0_ = g_strdup (VERSION);
	result = _tmp0_;
	return result;
}

