/* package.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from package.vala, do not modify */

/*
 *  pamac-vala
 *
 *  Copyright (C) 2014-2023 Guillaume Benoit <guillaume@manjaro.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a get of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define PAMAC_TYPE_PACKAGE (pamac_package_get_type ())
#define PAMAC_PACKAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PAMAC_TYPE_PACKAGE, PamacPackage))
#define PAMAC_PACKAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PAMAC_TYPE_PACKAGE, PamacPackageClass))
#define PAMAC_IS_PACKAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PAMAC_TYPE_PACKAGE))
#define PAMAC_IS_PACKAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PAMAC_TYPE_PACKAGE))
#define PAMAC_PACKAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PAMAC_TYPE_PACKAGE, PamacPackageClass))

typedef struct _PamacPackage PamacPackage;
typedef struct _PamacPackageClass PamacPackageClass;
typedef struct _PamacPackagePrivate PamacPackagePrivate;
enum  {
	PAMAC_PACKAGE_0_PROPERTY,
	PAMAC_PACKAGE_NAME_PROPERTY,
	PAMAC_PACKAGE_ID_PROPERTY,
	PAMAC_PACKAGE_APP_NAME_PROPERTY,
	PAMAC_PACKAGE_APP_ID_PROPERTY,
	PAMAC_PACKAGE_VERSION_PROPERTY,
	PAMAC_PACKAGE_INSTALLED_VERSION_PROPERTY,
	PAMAC_PACKAGE_DESC_PROPERTY,
	PAMAC_PACKAGE_LONG_DESC_PROPERTY,
	PAMAC_PACKAGE_REPO_PROPERTY,
	PAMAC_PACKAGE_LAUNCHABLE_PROPERTY,
	PAMAC_PACKAGE_LICENSE_PROPERTY,
	PAMAC_PACKAGE_URL_PROPERTY,
	PAMAC_PACKAGE_ICON_PROPERTY,
	PAMAC_PACKAGE_INSTALLED_SIZE_PROPERTY,
	PAMAC_PACKAGE_DOWNLOAD_SIZE_PROPERTY,
	PAMAC_PACKAGE_INSTALL_DATE_PROPERTY,
	PAMAC_PACKAGE_SCREENSHOTS_PROPERTY,
	PAMAC_PACKAGE_NUM_PROPERTIES
};
static GParamSpec* pamac_package_properties[PAMAC_PACKAGE_NUM_PROPERTIES];

struct _PamacPackage {
	GObject parent_instance;
	PamacPackagePrivate * priv;
};

struct _PamacPackageClass {
	GObjectClass parent_class;
	const gchar* (*get_name) (PamacPackage* self);
	void (*set_name) (PamacPackage* self, const gchar* value);
	const gchar* (*get_id) (PamacPackage* self);
	void (*set_id) (PamacPackage* self, const gchar* value);
	const gchar* (*get_app_name) (PamacPackage* self);
	const gchar* (*get_app_id) (PamacPackage* self);
	const gchar* (*get_version) (PamacPackage* self);
	void (*set_version) (PamacPackage* self, const gchar* value);
	const gchar* (*get_installed_version) (PamacPackage* self);
	void (*set_installed_version) (PamacPackage* self, const gchar* value);
	const gchar* (*get_desc) (PamacPackage* self);
	void (*set_desc) (PamacPackage* self, const gchar* value);
	const gchar* (*get_long_desc) (PamacPackage* self);
	const gchar* (*get_repo) (PamacPackage* self);
	void (*set_repo) (PamacPackage* self, const gchar* value);
	const gchar* (*get_launchable) (PamacPackage* self);
	const gchar* (*get_license) (PamacPackage* self);
	const gchar* (*get_url) (PamacPackage* self);
	const gchar* (*get_icon) (PamacPackage* self);
	guint64 (*get_installed_size) (PamacPackage* self);
	guint64 (*get_download_size) (PamacPackage* self);
	GDateTime* (*get_install_date) (PamacPackage* self);
	GPtrArray* (*get_screenshots) (PamacPackage* self);
};

static gpointer pamac_package_parent_class = NULL;

VALA_EXTERN GType pamac_package_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PamacPackage, g_object_unref)
VALA_EXTERN PamacPackage* pamac_package_construct (GType object_type);
VALA_EXTERN const gchar* pamac_package_get_name (PamacPackage* self);
VALA_EXTERN void pamac_package_set_name (PamacPackage* self,
                             const gchar* value);
VALA_EXTERN const gchar* pamac_package_get_id (PamacPackage* self);
VALA_EXTERN void pamac_package_set_id (PamacPackage* self,
                           const gchar* value);
VALA_EXTERN const gchar* pamac_package_get_app_name (PamacPackage* self);
VALA_EXTERN const gchar* pamac_package_get_app_id (PamacPackage* self);
VALA_EXTERN const gchar* pamac_package_get_version (PamacPackage* self);
VALA_EXTERN void pamac_package_set_version (PamacPackage* self,
                                const gchar* value);
VALA_EXTERN const gchar* pamac_package_get_installed_version (PamacPackage* self);
VALA_EXTERN void pamac_package_set_installed_version (PamacPackage* self,
                                          const gchar* value);
VALA_EXTERN const gchar* pamac_package_get_desc (PamacPackage* self);
VALA_EXTERN void pamac_package_set_desc (PamacPackage* self,
                             const gchar* value);
VALA_EXTERN const gchar* pamac_package_get_long_desc (PamacPackage* self);
VALA_EXTERN const gchar* pamac_package_get_repo (PamacPackage* self);
VALA_EXTERN void pamac_package_set_repo (PamacPackage* self,
                             const gchar* value);
VALA_EXTERN const gchar* pamac_package_get_launchable (PamacPackage* self);
VALA_EXTERN const gchar* pamac_package_get_license (PamacPackage* self);
VALA_EXTERN const gchar* pamac_package_get_url (PamacPackage* self);
VALA_EXTERN const gchar* pamac_package_get_icon (PamacPackage* self);
VALA_EXTERN guint64 pamac_package_get_installed_size (PamacPackage* self);
VALA_EXTERN guint64 pamac_package_get_download_size (PamacPackage* self);
VALA_EXTERN GDateTime* pamac_package_get_install_date (PamacPackage* self);
VALA_EXTERN GPtrArray* pamac_package_get_screenshots (PamacPackage* self);
static GType pamac_package_get_type_once (void);
static void _vala_pamac_package_get_property (GObject * object,
                                       guint property_id,
                                       GValue * value,
                                       GParamSpec * pspec);
static void _vala_pamac_package_set_property (GObject * object,
                                       guint property_id,
                                       const GValue * value,
                                       GParamSpec * pspec);

PamacPackage*
pamac_package_construct (GType object_type)
{
	PamacPackage * self = NULL;
	self = (PamacPackage*) g_object_new (object_type, NULL);
	return self;
}

const gchar*
pamac_package_get_name (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_name) {
		return _klass_->get_name (self);
	}
	return NULL;
}

void
pamac_package_set_name (PamacPackage* self,
                        const gchar* value)
{
	PamacPackageClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->set_name) {
		_klass_->set_name (self, value);
	}
}

const gchar*
pamac_package_get_id (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_id) {
		return _klass_->get_id (self);
	}
	return NULL;
}

void
pamac_package_set_id (PamacPackage* self,
                      const gchar* value)
{
	PamacPackageClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->set_id) {
		_klass_->set_id (self, value);
	}
}

const gchar*
pamac_package_get_app_name (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_app_name) {
		return _klass_->get_app_name (self);
	}
	return NULL;
}

const gchar*
pamac_package_get_app_id (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_app_id) {
		return _klass_->get_app_id (self);
	}
	return NULL;
}

const gchar*
pamac_package_get_version (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_version) {
		return _klass_->get_version (self);
	}
	return NULL;
}

void
pamac_package_set_version (PamacPackage* self,
                           const gchar* value)
{
	PamacPackageClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->set_version) {
		_klass_->set_version (self, value);
	}
}

const gchar*
pamac_package_get_installed_version (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_installed_version) {
		return _klass_->get_installed_version (self);
	}
	return NULL;
}

void
pamac_package_set_installed_version (PamacPackage* self,
                                     const gchar* value)
{
	PamacPackageClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->set_installed_version) {
		_klass_->set_installed_version (self, value);
	}
}

const gchar*
pamac_package_get_desc (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_desc) {
		return _klass_->get_desc (self);
	}
	return NULL;
}

void
pamac_package_set_desc (PamacPackage* self,
                        const gchar* value)
{
	PamacPackageClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->set_desc) {
		_klass_->set_desc (self, value);
	}
}

const gchar*
pamac_package_get_long_desc (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_long_desc) {
		return _klass_->get_long_desc (self);
	}
	return NULL;
}

const gchar*
pamac_package_get_repo (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_repo) {
		return _klass_->get_repo (self);
	}
	return NULL;
}

void
pamac_package_set_repo (PamacPackage* self,
                        const gchar* value)
{
	PamacPackageClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->set_repo) {
		_klass_->set_repo (self, value);
	}
}

const gchar*
pamac_package_get_launchable (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_launchable) {
		return _klass_->get_launchable (self);
	}
	return NULL;
}

const gchar*
pamac_package_get_license (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_license) {
		return _klass_->get_license (self);
	}
	return NULL;
}

const gchar*
pamac_package_get_url (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_url) {
		return _klass_->get_url (self);
	}
	return NULL;
}

const gchar*
pamac_package_get_icon (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_icon) {
		return _klass_->get_icon (self);
	}
	return NULL;
}

guint64
pamac_package_get_installed_size (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, 0ULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_installed_size) {
		return _klass_->get_installed_size (self);
	}
	return 0ULL;
}

guint64
pamac_package_get_download_size (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, 0ULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_download_size) {
		return _klass_->get_download_size (self);
	}
	return 0ULL;
}

GDateTime*
pamac_package_get_install_date (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_install_date) {
		return _klass_->get_install_date (self);
	}
	return NULL;
}

GPtrArray*
pamac_package_get_screenshots (PamacPackage* self)
{
	PamacPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_PACKAGE_GET_CLASS (self);
	if (_klass_->get_screenshots) {
		return _klass_->get_screenshots (self);
	}
	return NULL;
}

static void
pamac_package_class_init (PamacPackageClass * klass,
                          gpointer klass_data)
{
	pamac_package_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_pamac_package_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_pamac_package_set_property;
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_NAME_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_ID_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_APP_NAME_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_APP_NAME_PROPERTY] = g_param_spec_string ("app-name", "app-name", "app-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_APP_ID_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_APP_ID_PROPERTY] = g_param_spec_string ("app-id", "app-id", "app-id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_VERSION_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_VERSION_PROPERTY] = g_param_spec_string ("version", "version", "version", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_INSTALLED_VERSION_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_INSTALLED_VERSION_PROPERTY] = g_param_spec_string ("installed-version", "installed-version", "installed-version", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_DESC_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_DESC_PROPERTY] = g_param_spec_string ("desc", "desc", "desc", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_LONG_DESC_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_LONG_DESC_PROPERTY] = g_param_spec_string ("long-desc", "long-desc", "long-desc", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_REPO_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_REPO_PROPERTY] = g_param_spec_string ("repo", "repo", "repo", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_LAUNCHABLE_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_LAUNCHABLE_PROPERTY] = g_param_spec_string ("launchable", "launchable", "launchable", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_LICENSE_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_LICENSE_PROPERTY] = g_param_spec_string ("license", "license", "license", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_URL_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_URL_PROPERTY] = g_param_spec_string ("url", "url", "url", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_ICON_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_ICON_PROPERTY] = g_param_spec_string ("icon", "icon", "icon", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_INSTALLED_SIZE_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_INSTALLED_SIZE_PROPERTY] = g_param_spec_uint64 ("installed-size", "installed-size", "installed-size", 0, G_MAXUINT64, 0U, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_DOWNLOAD_SIZE_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_DOWNLOAD_SIZE_PROPERTY] = g_param_spec_uint64 ("download-size", "download-size", "download-size", 0, G_MAXUINT64, 0U, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_INSTALL_DATE_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_INSTALL_DATE_PROPERTY] = g_param_spec_boxed ("install-date", "install-date", "install-date", G_TYPE_DATE_TIME, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_PACKAGE_SCREENSHOTS_PROPERTY, pamac_package_properties[PAMAC_PACKAGE_SCREENSHOTS_PROPERTY] = g_param_spec_boxed ("screenshots", "screenshots", "screenshots", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
pamac_package_instance_init (PamacPackage * self,
                             gpointer klass)
{
}

static GType
pamac_package_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PamacPackageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) pamac_package_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PamacPackage), 0, (GInstanceInitFunc) pamac_package_instance_init, NULL };
	GType pamac_package_type_id;
	pamac_package_type_id = g_type_register_static (G_TYPE_OBJECT, "PamacPackage", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
	return pamac_package_type_id;
}

GType
pamac_package_get_type (void)
{
	static volatile gsize pamac_package_type_id__once = 0;
	if (g_once_init_enter (&pamac_package_type_id__once)) {
		GType pamac_package_type_id;
		pamac_package_type_id = pamac_package_get_type_once ();
		g_once_init_leave (&pamac_package_type_id__once, pamac_package_type_id);
	}
	return pamac_package_type_id__once;
}

static void
_vala_pamac_package_get_property (GObject * object,
                                  guint property_id,
                                  GValue * value,
                                  GParamSpec * pspec)
{
	PamacPackage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_PACKAGE, PamacPackage);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_pamac_package_set_property (GObject * object,
                                  guint property_id,
                                  const GValue * value,
                                  GParamSpec * pspec)
{
	PamacPackage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_PACKAGE, PamacPackage);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

