/* alpm_package.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from alpm_package.vala, do not modify */

/*
 *  pamac-vala
 *
 *  Copyright (C) 2014-2023 Guillaume Benoit <guillaume@manjaro.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a get of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "pamac.h"
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <alpm.h>
#include <alpm_list.h>
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	PAMAC_ALPM_PACKAGE_0_PROPERTY,
	PAMAC_ALPM_PACKAGE_BUILD_DATE_PROPERTY,
	PAMAC_ALPM_PACKAGE_PACKAGER_PROPERTY,
	PAMAC_ALPM_PACKAGE_REASON_PROPERTY,
	PAMAC_ALPM_PACKAGE_VALIDATIONS_PROPERTY,
	PAMAC_ALPM_PACKAGE_GROUPS_PROPERTY,
	PAMAC_ALPM_PACKAGE_DEPENDS_PROPERTY,
	PAMAC_ALPM_PACKAGE_OPTDEPENDS_PROPERTY,
	PAMAC_ALPM_PACKAGE_MAKEDEPENDS_PROPERTY,
	PAMAC_ALPM_PACKAGE_CHECKDEPENDS_PROPERTY,
	PAMAC_ALPM_PACKAGE_REQUIREDBY_PROPERTY,
	PAMAC_ALPM_PACKAGE_OPTIONALFOR_PROPERTY,
	PAMAC_ALPM_PACKAGE_PROVIDES_PROPERTY,
	PAMAC_ALPM_PACKAGE_REPLACES_PROPERTY,
	PAMAC_ALPM_PACKAGE_CONFLICTS_PROPERTY,
	PAMAC_ALPM_PACKAGE_BACKUPS_PROPERTY,
	PAMAC_ALPM_PACKAGE_NUM_PROPERTIES
};
static GParamSpec* pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_NUM_PROPERTIES];

#define PAMAC_TYPE_ALPM_PACKAGE_LINKED (pamac_alpm_package_linked_get_type ())
#define PAMAC_ALPM_PACKAGE_LINKED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PAMAC_TYPE_ALPM_PACKAGE_LINKED, PamacAlpmPackageLinked))
#define PAMAC_ALPM_PACKAGE_LINKED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PAMAC_TYPE_ALPM_PACKAGE_LINKED, PamacAlpmPackageLinkedClass))
#define PAMAC_IS_ALPM_PACKAGE_LINKED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PAMAC_TYPE_ALPM_PACKAGE_LINKED))
#define PAMAC_IS_ALPM_PACKAGE_LINKED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PAMAC_TYPE_ALPM_PACKAGE_LINKED))
#define PAMAC_ALPM_PACKAGE_LINKED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PAMAC_TYPE_ALPM_PACKAGE_LINKED, PamacAlpmPackageLinkedClass))

typedef struct _PamacAlpmPackageLinked PamacAlpmPackageLinked;
typedef struct _PamacAlpmPackageLinkedClass PamacAlpmPackageLinkedClass;
typedef struct _PamacAlpmPackageLinkedPrivate PamacAlpmPackageLinkedPrivate;

#define PAMAC_TYPE_APP (pamac_app_get_type ())
#define PAMAC_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PAMAC_TYPE_APP, PamacApp))
#define PAMAC_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PAMAC_TYPE_APP, PamacAppClass))
#define PAMAC_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PAMAC_TYPE_APP))
#define PAMAC_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PAMAC_TYPE_APP))
#define PAMAC_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PAMAC_TYPE_APP, PamacAppClass))

typedef struct _PamacApp PamacApp;
typedef struct _PamacAppClass PamacAppClass;
enum  {
	PAMAC_ALPM_PACKAGE_LINKED_0_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_NAME_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_ID_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_VERSION_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_INSTALLED_VERSION_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_DESC_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_REPO_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_LICENSE_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_URL_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_INSTALLED_SIZE_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_DOWNLOAD_SIZE_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_INSTALL_DATE_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_APP_NAME_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_APP_ID_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_LONG_DESC_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_LAUNCHABLE_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_ICON_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_SCREENSHOTS_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_BUILD_DATE_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_PACKAGER_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_REASON_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_VALIDATIONS_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_GROUPS_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_DEPENDS_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_OPTDEPENDS_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_MAKEDEPENDS_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_CHECKDEPENDS_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_REQUIREDBY_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_OPTIONALFOR_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_PROVIDES_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_REPLACES_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_CONFLICTS_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_BACKUPS_PROPERTY,
	PAMAC_ALPM_PACKAGE_LINKED_NUM_PROPERTIES
};
static GParamSpec* pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
#define _g_ptr_array_unref0(var) ((var == NULL) ? NULL : (var = (g_ptr_array_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _PamacAlpmPackageLinkedGetFilesAsyncData PamacAlpmPackageLinkedGetFilesAsyncData;
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
#define _alpm_list_free0(var) ((var == NULL) ? NULL : (var = (alpm_list_free (var), NULL)))

#define PAMAC_TYPE_ALPM_PACKAGE_STATIC (pamac_alpm_package_static_get_type ())
#define PAMAC_ALPM_PACKAGE_STATIC(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PAMAC_TYPE_ALPM_PACKAGE_STATIC, PamacAlpmPackageStatic))
#define PAMAC_ALPM_PACKAGE_STATIC_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PAMAC_TYPE_ALPM_PACKAGE_STATIC, PamacAlpmPackageStaticClass))
#define PAMAC_IS_ALPM_PACKAGE_STATIC(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PAMAC_TYPE_ALPM_PACKAGE_STATIC))
#define PAMAC_IS_ALPM_PACKAGE_STATIC_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PAMAC_TYPE_ALPM_PACKAGE_STATIC))
#define PAMAC_ALPM_PACKAGE_STATIC_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PAMAC_TYPE_ALPM_PACKAGE_STATIC, PamacAlpmPackageStaticClass))

typedef struct _PamacAlpmPackageStatic PamacAlpmPackageStatic;
typedef struct _PamacAlpmPackageStaticClass PamacAlpmPackageStaticClass;
typedef struct _PamacAlpmPackageStaticPrivate PamacAlpmPackageStaticPrivate;
enum  {
	PAMAC_ALPM_PACKAGE_STATIC_0_PROPERTY,
	PAMAC_ALPM_PACKAGE_STATIC_VERSION_PROPERTY,
	PAMAC_ALPM_PACKAGE_STATIC_INSTALLED_VERSION_PROPERTY,
	PAMAC_ALPM_PACKAGE_STATIC_DESC_PROPERTY,
	PAMAC_ALPM_PACKAGE_STATIC_REPO_PROPERTY,
	PAMAC_ALPM_PACKAGE_STATIC_URL_PROPERTY,
	PAMAC_ALPM_PACKAGE_STATIC_PACKAGER_PROPERTY,
	PAMAC_ALPM_PACKAGE_STATIC_NUM_PROPERTIES
};
static GParamSpec* pamac_alpm_package_static_properties[PAMAC_ALPM_PACKAGE_STATIC_NUM_PROPERTIES];
enum  {
	PAMAC_AUR_PACKAGE_0_PROPERTY,
	PAMAC_AUR_PACKAGE_PACKAGEBASE_PROPERTY,
	PAMAC_AUR_PACKAGE_MAINTAINER_PROPERTY,
	PAMAC_AUR_PACKAGE_POPULARITY_PROPERTY,
	PAMAC_AUR_PACKAGE_LASTMODIFIED_PROPERTY,
	PAMAC_AUR_PACKAGE_OUTOFDATE_PROPERTY,
	PAMAC_AUR_PACKAGE_FIRSTSUBMITTED_PROPERTY,
	PAMAC_AUR_PACKAGE_NUMVOTES_PROPERTY,
	PAMAC_AUR_PACKAGE_NUM_PROPERTIES
};
static GParamSpec* pamac_aur_package_properties[PAMAC_AUR_PACKAGE_NUM_PROPERTIES];

#define PAMAC_TYPE_AUR_PACKAGE_LINKED (pamac_aur_package_linked_get_type ())
#define PAMAC_AUR_PACKAGE_LINKED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PAMAC_TYPE_AUR_PACKAGE_LINKED, PamacAURPackageLinked))
#define PAMAC_AUR_PACKAGE_LINKED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PAMAC_TYPE_AUR_PACKAGE_LINKED, PamacAURPackageLinkedClass))
#define PAMAC_IS_AUR_PACKAGE_LINKED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PAMAC_TYPE_AUR_PACKAGE_LINKED))
#define PAMAC_IS_AUR_PACKAGE_LINKED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PAMAC_TYPE_AUR_PACKAGE_LINKED))
#define PAMAC_AUR_PACKAGE_LINKED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PAMAC_TYPE_AUR_PACKAGE_LINKED, PamacAURPackageLinkedClass))

typedef struct _PamacAURPackageLinked PamacAURPackageLinked;
typedef struct _PamacAURPackageLinkedClass PamacAURPackageLinkedClass;
typedef struct _PamacAURPackageLinkedPrivate PamacAURPackageLinkedPrivate;

#define PAMAC_TYPE_AUR_INFOS (pamac_aur_infos_get_type ())
#define PAMAC_AUR_INFOS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PAMAC_TYPE_AUR_INFOS, PamacAURInfos))
#define PAMAC_AUR_INFOS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PAMAC_TYPE_AUR_INFOS, PamacAURInfosClass))
#define PAMAC_IS_AUR_INFOS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PAMAC_TYPE_AUR_INFOS))
#define PAMAC_IS_AUR_INFOS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PAMAC_TYPE_AUR_INFOS))
#define PAMAC_AUR_INFOS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PAMAC_TYPE_AUR_INFOS, PamacAURInfosClass))

typedef struct _PamacAURInfos PamacAURInfos;
typedef struct _PamacAURInfosClass PamacAURInfosClass;
enum  {
	PAMAC_AUR_PACKAGE_LINKED_0_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_NAME_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_ID_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_VERSION_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_INSTALLED_VERSION_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_DESC_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_REPO_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_LICENSE_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_URL_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_INSTALLED_SIZE_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_DOWNLOAD_SIZE_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_INSTALL_DATE_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_APP_NAME_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_APP_ID_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_LONG_DESC_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_LAUNCHABLE_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_ICON_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_SCREENSHOTS_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_BUILD_DATE_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_PACKAGER_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_REASON_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_VALIDATIONS_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_GROUPS_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_DEPENDS_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_OPTDEPENDS_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_MAKEDEPENDS_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_CHECKDEPENDS_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_REQUIREDBY_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_OPTIONALFOR_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_PROVIDES_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_REPLACES_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_CONFLICTS_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_BACKUPS_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_PACKAGEBASE_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_MAINTAINER_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_POPULARITY_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_LASTMODIFIED_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_OUTOFDATE_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_FIRSTSUBMITTED_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_NUMVOTES_PROPERTY,
	PAMAC_AUR_PACKAGE_LINKED_NUM_PROPERTIES
};
static GParamSpec* pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_NUM_PROPERTIES];
typedef struct _PamacAurPackageLinkedGetFilesAsyncData PamacAurPackageLinkedGetFilesAsyncData;

#define PAMAC_TYPE_AUR_PACKAGE_STATIC (pamac_aur_package_static_get_type ())
#define PAMAC_AUR_PACKAGE_STATIC(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PAMAC_TYPE_AUR_PACKAGE_STATIC, PamacAURPackageStatic))
#define PAMAC_AUR_PACKAGE_STATIC_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PAMAC_TYPE_AUR_PACKAGE_STATIC, PamacAURPackageStaticClass))
#define PAMAC_IS_AUR_PACKAGE_STATIC(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PAMAC_TYPE_AUR_PACKAGE_STATIC))
#define PAMAC_IS_AUR_PACKAGE_STATIC_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PAMAC_TYPE_AUR_PACKAGE_STATIC))
#define PAMAC_AUR_PACKAGE_STATIC_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PAMAC_TYPE_AUR_PACKAGE_STATIC, PamacAURPackageStaticClass))

typedef struct _PamacAURPackageStatic PamacAURPackageStatic;
typedef struct _PamacAURPackageStaticClass PamacAURPackageStaticClass;
typedef struct _PamacAURPackageStaticPrivate PamacAURPackageStaticPrivate;
enum  {
	PAMAC_AUR_PACKAGE_STATIC_0_PROPERTY,
	PAMAC_AUR_PACKAGE_STATIC_DESC_PROPERTY,
	PAMAC_AUR_PACKAGE_STATIC_PACKAGEBASE_PROPERTY,
	PAMAC_AUR_PACKAGE_STATIC_NUM_PROPERTIES
};
static GParamSpec* pamac_aur_package_static_properties[PAMAC_AUR_PACKAGE_STATIC_NUM_PROPERTIES];
enum  {
	PAMAC_TRANSACTION_SUMMARY_0_PROPERTY,
	PAMAC_TRANSACTION_SUMMARY_TO_INSTALL_PROPERTY,
	PAMAC_TRANSACTION_SUMMARY_TO_UPGRADE_PROPERTY,
	PAMAC_TRANSACTION_SUMMARY_TO_DOWNGRADE_PROPERTY,
	PAMAC_TRANSACTION_SUMMARY_TO_REINSTALL_PROPERTY,
	PAMAC_TRANSACTION_SUMMARY_TO_REMOVE_PROPERTY,
	PAMAC_TRANSACTION_SUMMARY_CONFLICTS_TO_REMOVE_PROPERTY,
	PAMAC_TRANSACTION_SUMMARY_TO_BUILD_PROPERTY,
	PAMAC_TRANSACTION_SUMMARY_AUR_PKGBASES_TO_BUILD_PROPERTY,
	PAMAC_TRANSACTION_SUMMARY_TO_LOAD_PROPERTY,
	PAMAC_TRANSACTION_SUMMARY_NUM_PROPERTIES
};
static GParamSpec* pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_NUM_PROPERTIES];
enum  {
	PAMAC_UPDATES_0_PROPERTY,
	PAMAC_UPDATES_REPOS_UPDATES_PROPERTY,
	PAMAC_UPDATES_IGNORED_REPOS_UPDATES_PROPERTY,
	PAMAC_UPDATES_AUR_UPDATES_PROPERTY,
	PAMAC_UPDATES_IGNORED_AUR_UPDATES_PROPERTY,
	PAMAC_UPDATES_OUTOFDATE_PROPERTY,
	PAMAC_UPDATES_FLATPAK_UPDATES_PROPERTY,
	PAMAC_UPDATES_NUM_PROPERTIES
};
static GParamSpec* pamac_updates_properties[PAMAC_UPDATES_NUM_PROPERTIES];

struct _PamacAlpmPackageLinked {
	PamacAlpmPackage parent_instance;
	PamacAlpmPackageLinkedPrivate * priv;
};

struct _PamacAlpmPackageLinkedClass {
	PamacAlpmPackageClass parent_class;
};

struct _PamacAlpmPackageLinkedPrivate {
	gchar* _name;
	gchar* _id;
	const gchar* _version;
	const gchar* _installed_version;
	const gchar* _desc;
	const gchar* _repo;
	gchar* _license;
	const gchar* _url;
	guint64 _installed_size;
	guint64 _download_size;
	GDateTime* _install_date;
	PamacApp* _app;
	const gchar* _app_name;
	const gchar* _app_id;
	const gchar* _long_desc;
	const gchar* _launchable;
	const gchar* _icon;
	GPtrArray* _screenshots;
	PamacDatabase* database;
	alpm_pkg_t* alpm_pkg;
	alpm_pkg_t* local_pkg;
	alpm_pkg_t* sync_pkg;
	gboolean local_pkg_set;
	gboolean sync_pkg_set;
	gboolean version_set;
	gboolean installed_version_set;
	gboolean repo_set;
	gboolean license_set;
	gboolean install_date_set;
	gboolean download_size_set;
	gboolean installed_size_set;
	gboolean reason_set;
	GDateTime* _build_date;
	const gchar* _packager;
	const gchar* _reason;
	GPtrArray* _validations;
	GPtrArray* _groups;
	GPtrArray* _depends;
	GPtrArray* _optdepends;
	GPtrArray* _makedepends;
	GPtrArray* _checkdepends;
	GPtrArray* _requiredby;
	GPtrArray* _optionalfor;
	GPtrArray* _provides;
	GPtrArray* _replaces;
	GPtrArray* _conflicts;
	GPtrArray* _backups;
	GPtrArray* _files;
};

struct _PamacAlpmPackageLinkedGetFilesAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	PamacAlpmPackageLinked* self;
	GPtrArray* result;
	GPtrArray* _tmp0_;
	PamacDatabase* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	alpm_pkg_t* _tmp4_;
	GPtrArray* _tmp5_;
	GPtrArray* _tmp6_;
};

struct _PamacAlpmPackageStatic {
	PamacAlpmPackageLinked parent_instance;
	PamacAlpmPackageStaticPrivate * priv;
};

struct _PamacAlpmPackageStaticClass {
	PamacAlpmPackageLinkedClass parent_class;
};

struct _PamacAlpmPackageStaticPrivate {
	gchar* _version;
	gchar* _installed_version;
	gchar* _desc;
	gchar* _repo;
	gchar* _url;
	gchar* _packager;
};

struct _PamacAURPackageLinked {
	PamacAURPackage parent_instance;
	PamacAURPackageLinkedPrivate * priv;
};

struct _PamacAURPackageLinkedClass {
	PamacAURPackageClass parent_class;
};

struct _PamacAURPackageLinkedPrivate {
	gboolean installed_version_set;
	gboolean install_date_set;
	gboolean installed_size_set;
	gboolean download_size_set;
	gboolean license_set;
	gboolean reason_set;
	gboolean packager_set;
	gboolean build_date_set;
	gchar* _name;
	gchar* _id;
	gchar* _version;
	const gchar* _installed_version;
	const gchar* _desc;
	const gchar* _repo;
	gchar* _license;
	const gchar* _url;
	guint64 _installed_size;
	guint64 _download_size;
	GDateTime* _install_date;
	alpm_pkg_t* local_pkg;
	PamacDatabase* database;
	GDateTime* _build_date;
	const gchar* _packager;
	const gchar* _reason;
	GPtrArray* _validations;
	GPtrArray* _groups;
	GPtrArray* _depends;
	GPtrArray* _optdepends;
	GPtrArray* _makedepends;
	GPtrArray* _checkdepends;
	GPtrArray* _requiredby;
	GPtrArray* _optionalfor;
	GPtrArray* _provides;
	GPtrArray* _replaces;
	GPtrArray* _conflicts;
	GPtrArray* _backups;
	GPtrArray* _files;
	GPtrArray* _screenshots;
	PamacAURInfos* aur_infos;
	gboolean is_update;
	const gchar* _packagebase;
	const gchar* _maintainer;
	gdouble _popularity;
	GDateTime* _lastmodified;
	GDateTime* _outofdate;
	GDateTime* _firstsubmitted;
	guint64 _numvotes;
};

struct _PamacAurPackageLinkedGetFilesAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	PamacAURPackageLinked* self;
	GPtrArray* result;
	GPtrArray* _tmp0_;
	alpm_pkg_t* _tmp1_;
	GPtrArray* _tmp2_;
	PamacDatabase* _tmp3_;
	alpm_pkg_t* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	alpm_pkg_t* _tmp7_;
	GPtrArray* _tmp8_;
	GPtrArray* _tmp9_;
};

struct _PamacAURPackageStatic {
	PamacAURPackageLinked parent_instance;
	PamacAURPackageStaticPrivate * priv;
};

struct _PamacAURPackageStaticClass {
	PamacAURPackageLinkedClass parent_class;
};

struct _PamacAURPackageStaticPrivate {
	gchar* _desc;
	gchar* _packagebase;
};

struct _PamacTransactionSummaryPrivate {
	GPtrArray* _to_install;
	GPtrArray* _to_upgrade;
	GPtrArray* _to_downgrade;
	GPtrArray* _to_reinstall;
	GPtrArray* _to_remove;
	GPtrArray* _conflicts_to_remove;
	GPtrArray* _to_build;
	GPtrArray* _aur_pkgbases_to_build;
	GPtrArray* _to_load;
};

struct _PamacUpdatesPrivate {
	GPtrArray* _repos_updates;
	GPtrArray* _ignored_repos_updates;
	GPtrArray* _aur_updates;
	GPtrArray* _ignored_aur_updates;
	GPtrArray* _outofdate;
	GPtrArray* _flatpak_updates;
};

static gpointer pamac_alpm_package_parent_class = NULL;
static gint PamacAlpmPackageLinked_private_offset;
static gpointer pamac_alpm_package_linked_parent_class = NULL;
static gint PamacAlpmPackageStatic_private_offset;
static gpointer pamac_alpm_package_static_parent_class = NULL;
static gpointer pamac_aur_package_parent_class = NULL;
static gint PamacAURPackageLinked_private_offset;
static gpointer pamac_aur_package_linked_parent_class = NULL;
static gint PamacAURPackageStatic_private_offset;
static gpointer pamac_aur_package_static_parent_class = NULL;
static gint PamacTransactionSummary_private_offset;
static gpointer pamac_transaction_summary_parent_class = NULL;
static gint PamacUpdates_private_offset;
static gpointer pamac_updates_parent_class = NULL;

VALA_EXTERN PamacAlpmPackage* pamac_alpm_package_construct (GType object_type);
VALA_EXTERN PamacPackage* pamac_package_construct (GType object_type);
static GPtrArray* pamac_alpm_package_real_get_files (PamacAlpmPackage* self);
VALA_EXTERN void pamac_alpm_package_set_depends (PamacAlpmPackage* self,
                                     GPtrArray* value);
VALA_EXTERN void pamac_alpm_package_set_provides (PamacAlpmPackage* self,
                                      GPtrArray* value);
VALA_EXTERN void pamac_alpm_package_set_replaces (PamacAlpmPackage* self,
                                      GPtrArray* value);
VALA_EXTERN void pamac_alpm_package_set_conflicts (PamacAlpmPackage* self,
                                       GPtrArray* value);
static GType pamac_alpm_package_get_type_once (void);
static void _vala_pamac_alpm_package_get_property (GObject * object,
                                            guint property_id,
                                            GValue * value,
                                            GParamSpec * pspec);
static void _vala_pamac_alpm_package_set_property (GObject * object,
                                            guint property_id,
                                            const GValue * value,
                                            GParamSpec * pspec);
VALA_EXTERN GType pamac_alpm_package_linked_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType pamac_app_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void pamac_package_set_name (PamacPackage* self,
                             const gchar* value);
VALA_EXTERN void pamac_package_set_id (PamacPackage* self,
                           const gchar* value);
VALA_EXTERN void pamac_package_set_version (PamacPackage* self,
                                const gchar* value);
VALA_EXTERN void pamac_package_set_installed_version (PamacPackage* self,
                                          const gchar* value);
VALA_EXTERN void pamac_package_set_desc (PamacPackage* self,
                             const gchar* value);
VALA_EXTERN void pamac_package_set_repo (PamacPackage* self,
                             const gchar* value);
VALA_EXTERN PamacAlpmPackageLinked* pamac_alpm_package_linked_new (void);
VALA_EXTERN PamacAlpmPackageLinked* pamac_alpm_package_linked_construct (GType object_type);
VALA_EXTERN PamacAlpmPackageLinked* pamac_alpm_package_linked_new_from_alpm (alpm_pkg_t* alpm_pkg,
                                                                 PamacDatabase* database);
VALA_EXTERN PamacAlpmPackageLinked* pamac_alpm_package_linked_construct_from_alpm (GType object_type,
                                                                       alpm_pkg_t* alpm_pkg,
                                                                       PamacDatabase* database);
VALA_EXTERN void pamac_alpm_package_linked_set_alpm_pkg (PamacAlpmPackageLinked* self,
                                             alpm_pkg_t* alpm_pkg);
VALA_EXTERN void pamac_alpm_package_linked_set_local_pkg (PamacAlpmPackageLinked* self,
                                              alpm_pkg_t* local_pkg);
VALA_EXTERN void pamac_alpm_package_linked_set_sync_pkg (PamacAlpmPackageLinked* self,
                                             alpm_pkg_t* sync_pkg);
static void pamac_alpm_package_linked_found_local_pkg (PamacAlpmPackageLinked* self);
VALA_EXTERN alpm_pkg_t* pamac_database_intern_get_local_pkg (PamacDatabase* self,
                                                 const gchar* pkgname);
static void pamac_alpm_package_linked_found_sync_pkg (PamacAlpmPackageLinked* self);
VALA_EXTERN alpm_pkg_t* pamac_database_intern_get_syncpkg (PamacDatabase* self,
                                               const gchar* pkgname);
static GPtrArray* pamac_alpm_package_linked_real_get_files (PamacAlpmPackage* base);
VALA_EXTERN GPtrArray* pamac_database_get_pkg_files (PamacDatabase* self,
                                         const gchar* pkgname,
                                         alpm_pkg_t* local_pkg);
static void pamac_alpm_package_linked_real_get_files_async_data_free (gpointer _data);
static void pamac_alpm_package_linked_real_get_files_async (PamacAlpmPackage* base,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
static gboolean pamac_alpm_package_linked_real_get_files_async_co (PamacAlpmPackageLinkedGetFilesAsyncData* _data_);
VALA_EXTERN void pamac_database_get_pkg_files_async (PamacDatabase* self,
                                         const gchar* pkgname,
                                         alpm_pkg_t* local_pkg,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_);
VALA_EXTERN GPtrArray* pamac_database_get_pkg_files_finish (PamacDatabase* self,
                                                GAsyncResult* _res_);
static void pamac_alpm_package_linked_get_files_async_ready (GObject* source_object,
                                                      GAsyncResult* _res_,
                                                      gpointer _user_data_);
VALA_EXTERN void pamac_alpm_package_linked_set_app (PamacAlpmPackageLinked* self,
                                        PamacApp* app);
VALA_EXTERN const gchar* pamac_app_get_desc (PamacApp* self);
VALA_EXTERN const gchar* pamac_app_get_name (PamacApp* self);
VALA_EXTERN const gchar* pamac_app_get_id (PamacApp* self);
VALA_EXTERN const gchar* pamac_app_get_long_desc (PamacApp* self);
VALA_EXTERN const gchar* pamac_app_get_launchable (PamacApp* self);
VALA_EXTERN const gchar* pamac_app_get_icon (PamacApp* self);
VALA_EXTERN GPtrArray* pamac_app_get_screenshots (PamacApp* self);
static void _g_free0_ (gpointer var);
static void pamac_alpm_package_linked_finalize (GObject * obj);
static GType pamac_alpm_package_linked_get_type_once (void);
static void _vala_pamac_alpm_package_linked_get_property (GObject * object,
                                                   guint property_id,
                                                   GValue * value,
                                                   GParamSpec * pspec);
static void _vala_pamac_alpm_package_linked_set_property (GObject * object,
                                                   guint property_id,
                                                   const GValue * value,
                                                   GParamSpec * pspec);
VALA_EXTERN GType pamac_alpm_package_static_get_type (void) G_GNUC_CONST ;
VALA_EXTERN PamacAlpmPackageStatic* pamac_alpm_package_static_new (alpm_pkg_t* alpm_pkg,
                                                       alpm_pkg_t* local_pkg,
                                                       alpm_pkg_t* sync_pkg);
VALA_EXTERN PamacAlpmPackageStatic* pamac_alpm_package_static_construct (GType object_type,
                                                             alpm_pkg_t* alpm_pkg,
                                                             alpm_pkg_t* local_pkg,
                                                             alpm_pkg_t* sync_pkg);
VALA_EXTERN PamacAlpmPackageStatic* pamac_alpm_package_static_new_transaction (alpm_pkg_t* alpm_pkg,
                                                                   alpm_pkg_t* local_pkg,
                                                                   alpm_pkg_t* sync_pkg);
VALA_EXTERN PamacAlpmPackageStatic* pamac_alpm_package_static_construct_transaction (GType object_type,
                                                                         alpm_pkg_t* alpm_pkg,
                                                                         alpm_pkg_t* local_pkg,
                                                                         alpm_pkg_t* sync_pkg);
static void pamac_alpm_package_static_finalize (GObject * obj);
static GType pamac_alpm_package_static_get_type_once (void);
static void _vala_pamac_alpm_package_static_get_property (GObject * object,
                                                   guint property_id,
                                                   GValue * value,
                                                   GParamSpec * pspec);
static void _vala_pamac_alpm_package_static_set_property (GObject * object,
                                                   guint property_id,
                                                   const GValue * value,
                                                   GParamSpec * pspec);
VALA_EXTERN PamacAURPackage* pamac_aur_package_construct (GType object_type);
VALA_EXTERN void pamac_aur_package_set_packagebase (PamacAURPackage* self,
                                        const gchar* value);
static GType pamac_aur_package_get_type_once (void);
static void _vala_pamac_aur_package_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec);
static void _vala_pamac_aur_package_set_property (GObject * object,
                                           guint property_id,
                                           const GValue * value,
                                           GParamSpec * pspec);
VALA_EXTERN GType pamac_aur_package_linked_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType pamac_aur_infos_get_type (void) G_GNUC_CONST ;
VALA_EXTERN PamacAURPackageLinked* pamac_aur_package_linked_new (void);
VALA_EXTERN PamacAURPackageLinked* pamac_aur_package_linked_construct (GType object_type);
VALA_EXTERN void pamac_aur_package_linked_initialise_from_aur_infos (PamacAURPackageLinked* self,
                                                         PamacAURInfos* aur_infos,
                                                         alpm_pkg_t* local_pkg,
                                                         PamacDatabase* database,
                                                         gboolean is_update);
static GPtrArray* pamac_aur_package_linked_real_get_files (PamacAlpmPackage* base);
static void pamac_aur_package_linked_real_get_files_async_data_free (gpointer _data);
static void pamac_aur_package_linked_real_get_files_async (PamacAlpmPackage* base,
                                                    GAsyncReadyCallback _callback_,
                                                    gpointer _user_data_);
static gboolean pamac_aur_package_linked_real_get_files_async_co (PamacAurPackageLinkedGetFilesAsyncData* _data_);
static void pamac_aur_package_linked_get_files_async_ready (GObject* source_object,
                                                     GAsyncResult* _res_,
                                                     gpointer _user_data_);
VALA_EXTERN const gchar* pamac_aur_infos_get_name (PamacAURInfos* self);
VALA_EXTERN const gchar* pamac_aur_infos_get_version (PamacAURInfos* self);
VALA_EXTERN const gchar* pamac_aur_infos_get_desc (PamacAURInfos* self);
VALA_EXTERN const gchar* pamac_aur_infos_get_license (PamacAURInfos* self);
VALA_EXTERN const gchar* pamac_aur_infos_get_url (PamacAURInfos* self);
VALA_EXTERN GPtrArray* pamac_aur_infos_get_groups (PamacAURInfos* self);
VALA_EXTERN GPtrArray* pamac_aur_infos_get_depends (PamacAURInfos* self);
VALA_EXTERN GPtrArray* pamac_aur_infos_get_optdepends (PamacAURInfos* self);
VALA_EXTERN GPtrArray* pamac_aur_infos_get_makedepends (PamacAURInfos* self);
VALA_EXTERN GPtrArray* pamac_aur_infos_get_checkdepends (PamacAURInfos* self);
VALA_EXTERN GPtrArray* pamac_aur_infos_get_provides (PamacAURInfos* self);
VALA_EXTERN GPtrArray* pamac_aur_infos_get_replaces (PamacAURInfos* self);
VALA_EXTERN GPtrArray* pamac_aur_infos_get_conflicts (PamacAURInfos* self);
VALA_EXTERN const gchar* pamac_aur_infos_get_packagebase (PamacAURInfos* self);
VALA_EXTERN const gchar* pamac_aur_infos_get_maintainer (PamacAURInfos* self);
VALA_EXTERN gdouble pamac_aur_infos_get_popularity (PamacAURInfos* self);
VALA_EXTERN GDateTime* pamac_aur_infos_get_lastmodified (PamacAURInfos* self);
VALA_EXTERN GDateTime* pamac_aur_infos_get_outofdate (PamacAURInfos* self);
VALA_EXTERN GDateTime* pamac_aur_infos_get_firstsubmitted (PamacAURInfos* self);
VALA_EXTERN guint64 pamac_aur_infos_get_numvotes (PamacAURInfos* self);
static void pamac_aur_package_linked_finalize (GObject * obj);
static GType pamac_aur_package_linked_get_type_once (void);
static void _vala_pamac_aur_package_linked_get_property (GObject * object,
                                                  guint property_id,
                                                  GValue * value,
                                                  GParamSpec * pspec);
static void _vala_pamac_aur_package_linked_set_property (GObject * object,
                                                  guint property_id,
                                                  const GValue * value,
                                                  GParamSpec * pspec);
VALA_EXTERN GType pamac_aur_package_static_get_type (void) G_GNUC_CONST ;
VALA_EXTERN PamacAURPackageStatic* pamac_aur_package_static_new (void);
VALA_EXTERN PamacAURPackageStatic* pamac_aur_package_static_construct (GType object_type);
static void pamac_aur_package_static_finalize (GObject * obj);
static GType pamac_aur_package_static_get_type_once (void);
static void _vala_pamac_aur_package_static_get_property (GObject * object,
                                                  guint property_id,
                                                  GValue * value,
                                                  GParamSpec * pspec);
static void _vala_pamac_aur_package_static_set_property (GObject * object,
                                                  guint property_id,
                                                  const GValue * value,
                                                  GParamSpec * pspec);
static void _g_object_unref0_ (gpointer var);
VALA_EXTERN PamacTransactionSummary* pamac_transaction_summary_new (void);
VALA_EXTERN PamacTransactionSummary* pamac_transaction_summary_construct (GType object_type);
VALA_EXTERN void pamac_transaction_summary_set_to_install (PamacTransactionSummary* self,
                                               GPtrArray* value);
VALA_EXTERN void pamac_transaction_summary_set_to_upgrade (PamacTransactionSummary* self,
                                               GPtrArray* value);
VALA_EXTERN void pamac_transaction_summary_set_to_downgrade (PamacTransactionSummary* self,
                                                 GPtrArray* value);
VALA_EXTERN void pamac_transaction_summary_set_to_reinstall (PamacTransactionSummary* self,
                                                 GPtrArray* value);
VALA_EXTERN void pamac_transaction_summary_set_to_remove (PamacTransactionSummary* self,
                                              GPtrArray* value);
VALA_EXTERN void pamac_transaction_summary_set_conflicts_to_remove (PamacTransactionSummary* self,
                                                        GPtrArray* value);
VALA_EXTERN void pamac_transaction_summary_set_to_build (PamacTransactionSummary* self,
                                             GPtrArray* value);
VALA_EXTERN GPtrArray* pamac_transaction_summary_get_aur_pkgbases_to_build (PamacTransactionSummary* self);
VALA_EXTERN void pamac_transaction_summary_set_aur_pkgbases_to_build (PamacTransactionSummary* self,
                                                          GPtrArray* value);
VALA_EXTERN GPtrArray* pamac_transaction_summary_get_to_load (PamacTransactionSummary* self);
VALA_EXTERN void pamac_transaction_summary_set_to_load (PamacTransactionSummary* self,
                                            GPtrArray* value);
static void pamac_transaction_summary_finalize (GObject * obj);
static GType pamac_transaction_summary_get_type_once (void);
static void _vala_pamac_transaction_summary_get_property (GObject * object,
                                                   guint property_id,
                                                   GValue * value,
                                                   GParamSpec * pspec);
static void _vala_pamac_transaction_summary_set_property (GObject * object,
                                                   guint property_id,
                                                   const GValue * value,
                                                   GParamSpec * pspec);
VALA_EXTERN PamacUpdates* pamac_updates_new (void);
VALA_EXTERN PamacUpdates* pamac_updates_construct (GType object_type);
VALA_EXTERN void pamac_updates_set_repos_updates (PamacUpdates* self,
                                      GPtrArray* value);
VALA_EXTERN void pamac_updates_set_ignored_repos_updates (PamacUpdates* self,
                                              GPtrArray* value);
VALA_EXTERN void pamac_updates_set_aur_updates (PamacUpdates* self,
                                    GPtrArray* value);
VALA_EXTERN void pamac_updates_set_ignored_aur_updates (PamacUpdates* self,
                                            GPtrArray* value);
VALA_EXTERN void pamac_updates_set_outofdate (PamacUpdates* self,
                                  GPtrArray* value);
VALA_EXTERN void pamac_updates_set_flatpak_updates (PamacUpdates* self,
                                        GPtrArray* value);
static void pamac_updates_finalize (GObject * obj);
static GType pamac_updates_get_type_once (void);
static void _vala_pamac_updates_get_property (GObject * object,
                                       guint property_id,
                                       GValue * value,
                                       GParamSpec * pspec);
static void _vala_pamac_updates_set_property (GObject * object,
                                       guint property_id,
                                       const GValue * value,
                                       GParamSpec * pspec);

PamacAlpmPackage*
pamac_alpm_package_construct (GType object_type)
{
	PamacAlpmPackage * self = NULL;
	self = (PamacAlpmPackage*) pamac_package_construct (object_type);
	return self;
}

static GPtrArray*
pamac_alpm_package_real_get_files (PamacAlpmPackage* self)
{
	g_critical ("Type `%s' does not implement abstract method `pamac_alpm_package_get_files'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

GPtrArray*
pamac_alpm_package_get_files (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_files) {
		return _klass_->get_files (self);
	}
	return NULL;
}

void
pamac_alpm_package_get_files_async (PamacAlpmPackage* self,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_)
{
	PamacAlpmPackageClass* _klass_;
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_files_async) {
		_klass_->get_files_async (self, _callback_, _user_data_);
	}
}

GPtrArray*
pamac_alpm_package_get_files_finish (PamacAlpmPackage* self,
                                     GAsyncResult* _res_)
{
	PamacAlpmPackageClass* _klass_;
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_files_finish) {
		return _klass_->get_files_finish (self, _res_);
	}
	return NULL;
}

GDateTime*
pamac_alpm_package_get_build_date (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_build_date) {
		return _klass_->get_build_date (self);
	}
	return NULL;
}

const gchar*
pamac_alpm_package_get_packager (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_packager) {
		return _klass_->get_packager (self);
	}
	return NULL;
}

const gchar*
pamac_alpm_package_get_reason (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_reason) {
		return _klass_->get_reason (self);
	}
	return NULL;
}

GPtrArray*
pamac_alpm_package_get_validations (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_validations) {
		return _klass_->get_validations (self);
	}
	return NULL;
}

GPtrArray*
pamac_alpm_package_get_groups (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_groups) {
		return _klass_->get_groups (self);
	}
	return NULL;
}

GPtrArray*
pamac_alpm_package_get_depends (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_depends) {
		return _klass_->get_depends (self);
	}
	return NULL;
}

void
pamac_alpm_package_set_depends (PamacAlpmPackage* self,
                                GPtrArray* value)
{
	PamacAlpmPackageClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->set_depends) {
		_klass_->set_depends (self, value);
	}
}

GPtrArray*
pamac_alpm_package_get_optdepends (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_optdepends) {
		return _klass_->get_optdepends (self);
	}
	return NULL;
}

GPtrArray*
pamac_alpm_package_get_makedepends (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_makedepends) {
		return _klass_->get_makedepends (self);
	}
	return NULL;
}

GPtrArray*
pamac_alpm_package_get_checkdepends (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_checkdepends) {
		return _klass_->get_checkdepends (self);
	}
	return NULL;
}

GPtrArray*
pamac_alpm_package_get_requiredby (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_requiredby) {
		return _klass_->get_requiredby (self);
	}
	return NULL;
}

GPtrArray*
pamac_alpm_package_get_optionalfor (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_optionalfor) {
		return _klass_->get_optionalfor (self);
	}
	return NULL;
}

GPtrArray*
pamac_alpm_package_get_provides (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_provides) {
		return _klass_->get_provides (self);
	}
	return NULL;
}

void
pamac_alpm_package_set_provides (PamacAlpmPackage* self,
                                 GPtrArray* value)
{
	PamacAlpmPackageClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->set_provides) {
		_klass_->set_provides (self, value);
	}
}

GPtrArray*
pamac_alpm_package_get_replaces (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_replaces) {
		return _klass_->get_replaces (self);
	}
	return NULL;
}

void
pamac_alpm_package_set_replaces (PamacAlpmPackage* self,
                                 GPtrArray* value)
{
	PamacAlpmPackageClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->set_replaces) {
		_klass_->set_replaces (self, value);
	}
}

GPtrArray*
pamac_alpm_package_get_conflicts (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_conflicts) {
		return _klass_->get_conflicts (self);
	}
	return NULL;
}

void
pamac_alpm_package_set_conflicts (PamacAlpmPackage* self,
                                  GPtrArray* value)
{
	PamacAlpmPackageClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->set_conflicts) {
		_klass_->set_conflicts (self, value);
	}
}

GPtrArray*
pamac_alpm_package_get_backups (PamacAlpmPackage* self)
{
	PamacAlpmPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_ALPM_PACKAGE_GET_CLASS (self);
	if (_klass_->get_backups) {
		return _klass_->get_backups (self);
	}
	return NULL;
}

static void
pamac_alpm_package_class_init (PamacAlpmPackageClass * klass,
                               gpointer klass_data)
{
	pamac_alpm_package_parent_class = g_type_class_peek_parent (klass);
	((PamacAlpmPackageClass *) klass)->get_files = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_alpm_package_real_get_files;
	G_OBJECT_CLASS (klass)->get_property = _vala_pamac_alpm_package_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_pamac_alpm_package_set_property;
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_BUILD_DATE_PROPERTY, pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_BUILD_DATE_PROPERTY] = g_param_spec_boxed ("build-date", "build-date", "build-date", G_TYPE_DATE_TIME, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_PACKAGER_PROPERTY, pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_PACKAGER_PROPERTY] = g_param_spec_string ("packager", "packager", "packager", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_REASON_PROPERTY, pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_REASON_PROPERTY] = g_param_spec_string ("reason", "reason", "reason", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_VALIDATIONS_PROPERTY, pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_VALIDATIONS_PROPERTY] = g_param_spec_boxed ("validations", "validations", "validations", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_GROUPS_PROPERTY, pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_GROUPS_PROPERTY] = g_param_spec_boxed ("groups", "groups", "groups", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_DEPENDS_PROPERTY, pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_DEPENDS_PROPERTY] = g_param_spec_boxed ("depends", "depends", "depends", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_OPTDEPENDS_PROPERTY, pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_OPTDEPENDS_PROPERTY] = g_param_spec_boxed ("optdepends", "optdepends", "optdepends", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_MAKEDEPENDS_PROPERTY, pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_MAKEDEPENDS_PROPERTY] = g_param_spec_boxed ("makedepends", "makedepends", "makedepends", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_CHECKDEPENDS_PROPERTY, pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_CHECKDEPENDS_PROPERTY] = g_param_spec_boxed ("checkdepends", "checkdepends", "checkdepends", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_REQUIREDBY_PROPERTY, pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_REQUIREDBY_PROPERTY] = g_param_spec_boxed ("requiredby", "requiredby", "requiredby", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_OPTIONALFOR_PROPERTY, pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_OPTIONALFOR_PROPERTY] = g_param_spec_boxed ("optionalfor", "optionalfor", "optionalfor", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_PROVIDES_PROPERTY, pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_PROVIDES_PROPERTY] = g_param_spec_boxed ("provides", "provides", "provides", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_REPLACES_PROPERTY, pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_REPLACES_PROPERTY] = g_param_spec_boxed ("replaces", "replaces", "replaces", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_CONFLICTS_PROPERTY, pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_CONFLICTS_PROPERTY] = g_param_spec_boxed ("conflicts", "conflicts", "conflicts", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_BACKUPS_PROPERTY, pamac_alpm_package_properties[PAMAC_ALPM_PACKAGE_BACKUPS_PROPERTY] = g_param_spec_boxed ("backups", "backups", "backups", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
pamac_alpm_package_instance_init (PamacAlpmPackage * self,
                                  gpointer klass)
{
}

static GType
pamac_alpm_package_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PamacAlpmPackageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) pamac_alpm_package_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PamacAlpmPackage), 0, (GInstanceInitFunc) pamac_alpm_package_instance_init, NULL };
	GType pamac_alpm_package_type_id;
	pamac_alpm_package_type_id = g_type_register_static (PAMAC_TYPE_PACKAGE, "PamacAlpmPackage", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
	return pamac_alpm_package_type_id;
}

GType
pamac_alpm_package_get_type (void)
{
	static volatile gsize pamac_alpm_package_type_id__once = 0;
	if (g_once_init_enter (&pamac_alpm_package_type_id__once)) {
		GType pamac_alpm_package_type_id;
		pamac_alpm_package_type_id = pamac_alpm_package_get_type_once ();
		g_once_init_leave (&pamac_alpm_package_type_id__once, pamac_alpm_package_type_id);
	}
	return pamac_alpm_package_type_id__once;
}

static void
_vala_pamac_alpm_package_get_property (GObject * object,
                                       guint property_id,
                                       GValue * value,
                                       GParamSpec * pspec)
{
	PamacAlpmPackage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_ALPM_PACKAGE, PamacAlpmPackage);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_pamac_alpm_package_set_property (GObject * object,
                                       guint property_id,
                                       const GValue * value,
                                       GParamSpec * pspec)
{
	PamacAlpmPackage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_ALPM_PACKAGE, PamacAlpmPackage);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
pamac_alpm_package_linked_get_instance_private (PamacAlpmPackageLinked* self)
{
	return G_STRUCT_MEMBER_P (self, PamacAlpmPackageLinked_private_offset);
}

PamacAlpmPackageLinked*
pamac_alpm_package_linked_construct (GType object_type)
{
	PamacAlpmPackageLinked * self = NULL;
	self = (PamacAlpmPackageLinked*) pamac_alpm_package_construct (object_type);
	return self;
}

PamacAlpmPackageLinked*
pamac_alpm_package_linked_new (void)
{
	return pamac_alpm_package_linked_construct (PAMAC_TYPE_ALPM_PACKAGE_LINKED);
}

PamacAlpmPackageLinked*
pamac_alpm_package_linked_construct_from_alpm (GType object_type,
                                               alpm_pkg_t* alpm_pkg,
                                               PamacDatabase* database)
{
	PamacAlpmPackageLinked * self = NULL;
	g_return_val_if_fail (database != NULL, NULL);
	self = (PamacAlpmPackageLinked*) pamac_alpm_package_construct (object_type);
	self->priv->alpm_pkg = alpm_pkg;
	self->priv->database = database;
	return self;
}

PamacAlpmPackageLinked*
pamac_alpm_package_linked_new_from_alpm (alpm_pkg_t* alpm_pkg,
                                         PamacDatabase* database)
{
	return pamac_alpm_package_linked_construct_from_alpm (PAMAC_TYPE_ALPM_PACKAGE_LINKED, alpm_pkg, database);
}

void
pamac_alpm_package_linked_set_alpm_pkg (PamacAlpmPackageLinked* self,
                                        alpm_pkg_t* alpm_pkg)
{
	g_return_if_fail (self != NULL);
	self->priv->alpm_pkg = alpm_pkg;
}

void
pamac_alpm_package_linked_set_local_pkg (PamacAlpmPackageLinked* self,
                                         alpm_pkg_t* local_pkg)
{
	g_return_if_fail (self != NULL);
	self->priv->local_pkg = local_pkg;
	self->priv->local_pkg_set = TRUE;
}

void
pamac_alpm_package_linked_set_sync_pkg (PamacAlpmPackageLinked* self,
                                        alpm_pkg_t* sync_pkg)
{
	g_return_if_fail (self != NULL);
	self->priv->sync_pkg = sync_pkg;
	self->priv->sync_pkg_set = TRUE;
}

static void
pamac_alpm_package_linked_found_local_pkg (PamacAlpmPackageLinked* self)
{
	g_return_if_fail (self != NULL);
	if (!self->priv->local_pkg_set) {
		alpm_pkg_t* _tmp0_;
		alpm_pkgfrom_t _tmp1_;
		alpm_pkgfrom_t _tmp2_;
		self->priv->local_pkg_set = TRUE;
		_tmp0_ = self->priv->alpm_pkg;
		_tmp1_ = alpm_pkg_get_origin (_tmp0_);
		_tmp2_ = _tmp1_;
		if (_tmp2_ == ALPM_PKG_FROM_LOCALDB) {
			alpm_pkg_t* _tmp3_;
			_tmp3_ = self->priv->alpm_pkg;
			self->priv->local_pkg = _tmp3_;
		} else {
			alpm_pkg_t* _tmp4_;
			alpm_pkgfrom_t _tmp5_;
			alpm_pkgfrom_t _tmp6_;
			_tmp4_ = self->priv->alpm_pkg;
			_tmp5_ = alpm_pkg_get_origin (_tmp4_);
			_tmp6_ = _tmp5_;
			if (_tmp6_ == ALPM_PKG_FROM_SYNCDB) {
				PamacDatabase* _tmp7_;
				alpm_pkg_t* _tmp8_;
				const gchar* _tmp9_;
				const gchar* _tmp10_;
				alpm_pkg_t* _tmp11_;
				_tmp7_ = self->priv->database;
				_tmp8_ = self->priv->alpm_pkg;
				_tmp9_ = alpm_pkg_get_name (_tmp8_);
				_tmp10_ = _tmp9_;
				_tmp11_ = pamac_database_intern_get_local_pkg (_tmp7_, _tmp10_);
				self->priv->local_pkg = _tmp11_;
			}
		}
	}
}

static void
pamac_alpm_package_linked_found_sync_pkg (PamacAlpmPackageLinked* self)
{
	g_return_if_fail (self != NULL);
	if (!self->priv->sync_pkg_set) {
		alpm_pkg_t* _tmp0_;
		alpm_pkgfrom_t _tmp1_;
		alpm_pkgfrom_t _tmp2_;
		self->priv->sync_pkg_set = TRUE;
		_tmp0_ = self->priv->alpm_pkg;
		_tmp1_ = alpm_pkg_get_origin (_tmp0_);
		_tmp2_ = _tmp1_;
		if (_tmp2_ == ALPM_PKG_FROM_LOCALDB) {
			PamacDatabase* _tmp3_;
			alpm_pkg_t* _tmp4_;
			const gchar* _tmp5_;
			const gchar* _tmp6_;
			alpm_pkg_t* _tmp7_;
			_tmp3_ = self->priv->database;
			_tmp4_ = self->priv->alpm_pkg;
			_tmp5_ = alpm_pkg_get_name (_tmp4_);
			_tmp6_ = _tmp5_;
			_tmp7_ = pamac_database_intern_get_syncpkg (_tmp3_, _tmp6_);
			self->priv->sync_pkg = _tmp7_;
		} else {
			alpm_pkg_t* _tmp8_;
			alpm_pkgfrom_t _tmp9_;
			alpm_pkgfrom_t _tmp10_;
			_tmp8_ = self->priv->alpm_pkg;
			_tmp9_ = alpm_pkg_get_origin (_tmp8_);
			_tmp10_ = _tmp9_;
			if (_tmp10_ == ALPM_PKG_FROM_SYNCDB) {
				alpm_pkg_t* _tmp11_;
				_tmp11_ = self->priv->alpm_pkg;
				self->priv->sync_pkg = _tmp11_;
			}
		}
	}
}

static GPtrArray*
pamac_alpm_package_linked_real_get_files (PamacAlpmPackage* base)
{
	PamacAlpmPackageLinked * self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp6_;
	GPtrArray* result;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_files;
	if (_tmp0_ == NULL) {
		PamacDatabase* _tmp1_;
		const gchar* _tmp2_;
		const gchar* _tmp3_;
		alpm_pkg_t* _tmp4_;
		GPtrArray* _tmp5_;
		pamac_alpm_package_linked_found_local_pkg (self);
		_tmp1_ = self->priv->database;
		_tmp2_ = pamac_package_get_name ((PamacPackage*) self);
		_tmp3_ = _tmp2_;
		_tmp4_ = self->priv->local_pkg;
		_tmp5_ = pamac_database_get_pkg_files (_tmp1_, _tmp3_, _tmp4_);
		_g_ptr_array_unref0 (self->priv->_files);
		self->priv->_files = _tmp5_;
	}
	_tmp6_ = self->priv->_files;
	result = _tmp6_;
	return result;
}

static void
pamac_alpm_package_linked_real_get_files_async_data_free (gpointer _data)
{
	PamacAlpmPackageLinkedGetFilesAsyncData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (PamacAlpmPackageLinkedGetFilesAsyncData, _data_);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
pamac_alpm_package_linked_real_get_files_async (PamacAlpmPackage* base,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_)
{
	PamacAlpmPackageLinked * self;
	PamacAlpmPackageLinkedGetFilesAsyncData* _data_;
	PamacAlpmPackageLinked* _tmp0_;
	self = (PamacAlpmPackageLinked*) base;
	_data_ = g_slice_new0 (PamacAlpmPackageLinkedGetFilesAsyncData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, pamac_alpm_package_linked_real_get_files_async_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	pamac_alpm_package_linked_real_get_files_async_co (_data_);
}

static GPtrArray*
pamac_alpm_package_linked_get_files_finish (PamacAlpmPackage* base,
                                            GAsyncResult* _res_)
{
	GPtrArray* result;
	PamacAlpmPackageLinkedGetFilesAsyncData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
	result = _data_->result;
	_data_->result = NULL;
	return result;
}

static void
pamac_alpm_package_linked_get_files_async_ready (GObject* source_object,
                                                 GAsyncResult* _res_,
                                                 gpointer _user_data_)
{
	PamacAlpmPackageLinkedGetFilesAsyncData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	pamac_alpm_package_linked_real_get_files_async_co (_data_);
}

static gboolean
pamac_alpm_package_linked_real_get_files_async_co (PamacAlpmPackageLinkedGetFilesAsyncData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = _data_->self->priv->_files;
	if (_data_->_tmp0_ == NULL) {
		pamac_alpm_package_linked_found_local_pkg (_data_->self);
		_data_->_tmp1_ = _data_->self->priv->database;
		_data_->_tmp2_ = pamac_package_get_name ((PamacPackage*) _data_->self);
		_data_->_tmp3_ = _data_->_tmp2_;
		_data_->_tmp4_ = _data_->self->priv->local_pkg;
		_data_->_state_ = 1;
		pamac_database_get_pkg_files_async (_data_->_tmp1_, _data_->_tmp3_, _data_->_tmp4_, pamac_alpm_package_linked_get_files_async_ready, _data_);
		return FALSE;
		_state_1:
		_data_->_tmp5_ = pamac_database_get_pkg_files_finish (_data_->_tmp1_, _data_->_res_);
		_g_ptr_array_unref0 (_data_->self->priv->_files);
		_data_->self->priv->_files = _data_->_tmp5_;
	}
	_data_->_tmp6_ = _data_->self->priv->_files;
	_data_->result = _data_->_tmp6_;
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

void
pamac_alpm_package_linked_set_app (PamacAlpmPackageLinked* self,
                                   PamacApp* app)
{
	g_return_if_fail (self != NULL);
	self->priv->_app = app;
}

static const gchar*
pamac_alpm_package_linked_real_get_name (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageLinked* self;
	const gchar* _tmp0_;
	const gchar* _tmp5_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_name;
	if (_tmp0_ == NULL) {
		alpm_pkg_t* _tmp1_;
		const gchar* _tmp2_;
		const gchar* _tmp3_;
		gchar* _tmp4_;
		_tmp1_ = self->priv->alpm_pkg;
		_tmp2_ = alpm_pkg_get_name (_tmp1_);
		_tmp3_ = _tmp2_;
		_tmp4_ = g_strdup (_tmp3_);
		_g_free0 (self->priv->_name);
		self->priv->_name = _tmp4_;
	}
	_tmp5_ = self->priv->_name;
	result = _tmp5_;
	return result;
}

static void
pamac_alpm_package_linked_real_set_name (PamacPackage* base,
                                         const gchar* value)
{
	PamacAlpmPackageLinked* self;
	gchar* _tmp0_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_name);
	self->priv->_name = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_NAME_PROPERTY]);
}

static const gchar*
pamac_alpm_package_linked_real_get_id (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageLinked* self;
	const gchar* _tmp0_;
	const gchar* _tmp8_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_id;
	if (_tmp0_ == NULL) {
		PamacApp* _tmp1_;
		_tmp1_ = self->priv->_app;
		if (_tmp1_ != NULL) {
			const gchar* _tmp2_;
			const gchar* _tmp3_;
			gchar* _tmp4_;
			_tmp2_ = pamac_package_get_app_id ((PamacPackage*) self);
			_tmp3_ = _tmp2_;
			_tmp4_ = g_strdup (_tmp3_);
			_g_free0 (self->priv->_id);
			self->priv->_id = _tmp4_;
		} else {
			const gchar* _tmp5_;
			const gchar* _tmp6_;
			gchar* _tmp7_;
			_tmp5_ = pamac_package_get_name ((PamacPackage*) self);
			_tmp6_ = _tmp5_;
			_tmp7_ = g_strdup (_tmp6_);
			_g_free0 (self->priv->_id);
			self->priv->_id = _tmp7_;
		}
	}
	_tmp8_ = self->priv->_id;
	result = _tmp8_;
	return result;
}

static void
pamac_alpm_package_linked_real_set_id (PamacPackage* base,
                                       const gchar* value)
{
	PamacAlpmPackageLinked* self;
	gchar* _tmp0_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_id);
	self->priv->_id = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_ID_PROPERTY]);
}

static const gchar*
pamac_alpm_package_linked_real_get_version (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageLinked* self;
	const gchar* _tmp7_;
	self = (PamacAlpmPackageLinked*) base;
	if (!self->priv->version_set) {
		alpm_pkg_t* _tmp0_;
		self->priv->version_set = TRUE;
		pamac_alpm_package_linked_found_sync_pkg (self);
		_tmp0_ = self->priv->sync_pkg;
		if (_tmp0_ != NULL) {
			alpm_pkg_t* _tmp1_;
			const gchar* _tmp2_;
			const gchar* _tmp3_;
			_tmp1_ = self->priv->sync_pkg;
			_tmp2_ = alpm_pkg_get_version (_tmp1_);
			_tmp3_ = _tmp2_;
			self->priv->_version = _tmp3_;
		} else {
			alpm_pkg_t* _tmp4_;
			const gchar* _tmp5_;
			const gchar* _tmp6_;
			_tmp4_ = self->priv->alpm_pkg;
			_tmp5_ = alpm_pkg_get_version (_tmp4_);
			_tmp6_ = _tmp5_;
			self->priv->_version = _tmp6_;
		}
	}
	_tmp7_ = self->priv->_version;
	result = _tmp7_;
	return result;
}

static void
pamac_alpm_package_linked_real_set_version (PamacPackage* base,
                                            const gchar* value)
{
	PamacAlpmPackageLinked* self;
	self = (PamacAlpmPackageLinked*) base;
	self->priv->_version = value;
	g_object_notify_by_pspec ((GObject *) self, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_VERSION_PROPERTY]);
}

static const gchar*
pamac_alpm_package_linked_real_get_installed_version (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageLinked* self;
	const gchar* _tmp3_;
	self = (PamacAlpmPackageLinked*) base;
	if (!self->priv->installed_version_set) {
		alpm_pkg_t* _tmp0_;
		const gchar* _tmp1_;
		const gchar* _tmp2_;
		self->priv->installed_version_set = TRUE;
		pamac_alpm_package_linked_found_local_pkg (self);
		_tmp0_ = self->priv->local_pkg;
		_tmp1_ = alpm_pkg_get_version (_tmp0_);
		_tmp2_ = _tmp1_;
		self->priv->_installed_version = _tmp2_;
	}
	_tmp3_ = self->priv->_installed_version;
	result = _tmp3_;
	return result;
}

static void
pamac_alpm_package_linked_real_set_installed_version (PamacPackage* base,
                                                      const gchar* value)
{
	PamacAlpmPackageLinked* self;
	self = (PamacAlpmPackageLinked*) base;
	self->priv->_installed_version = value;
	g_object_notify_by_pspec ((GObject *) self, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_INSTALLED_VERSION_PROPERTY]);
}

static const gchar*
pamac_alpm_package_linked_real_get_desc (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageLinked* self;
	const gchar* _tmp0_;
	const gchar* _tmp13_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_desc;
	if (_tmp0_ == NULL) {
		PamacApp* _tmp1_;
		_tmp1_ = self->priv->_app;
		if (_tmp1_ != NULL) {
			const gchar* summary = NULL;
			PamacApp* _tmp2_;
			const gchar* _tmp3_;
			const gchar* _tmp4_;
			const gchar* _tmp5_;
			_tmp2_ = self->priv->_app;
			_tmp3_ = pamac_app_get_desc (_tmp2_);
			_tmp4_ = _tmp3_;
			summary = _tmp4_;
			_tmp5_ = summary;
			if (_tmp5_ != NULL) {
				const gchar* _tmp6_;
				_tmp6_ = summary;
				self->priv->_desc = _tmp6_;
			} else {
				alpm_pkg_t* _tmp7_;
				const gchar* _tmp8_;
				const gchar* _tmp9_;
				_tmp7_ = self->priv->alpm_pkg;
				_tmp8_ = alpm_pkg_get_desc (_tmp7_);
				_tmp9_ = _tmp8_;
				self->priv->_desc = _tmp9_;
			}
		} else {
			alpm_pkg_t* _tmp10_;
			const gchar* _tmp11_;
			const gchar* _tmp12_;
			_tmp10_ = self->priv->alpm_pkg;
			_tmp11_ = alpm_pkg_get_desc (_tmp10_);
			_tmp12_ = _tmp11_;
			self->priv->_desc = _tmp12_;
		}
	}
	_tmp13_ = self->priv->_desc;
	result = _tmp13_;
	return result;
}

static void
pamac_alpm_package_linked_real_set_desc (PamacPackage* base,
                                         const gchar* value)
{
	PamacAlpmPackageLinked* self;
	self = (PamacAlpmPackageLinked*) base;
	self->priv->_desc = value;
	g_object_notify_by_pspec ((GObject *) self, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_DESC_PROPERTY]);
}

static const gchar*
pamac_alpm_package_linked_real_get_repo (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageLinked* self;
	const gchar* _tmp7_;
	self = (PamacAlpmPackageLinked*) base;
	if (!self->priv->repo_set) {
		alpm_db_t* db = NULL;
		alpm_pkg_t* _tmp0_;
		alpm_db_t* _tmp1_;
		alpm_db_t* _tmp2_;
		alpm_db_t* _tmp3_;
		self->priv->repo_set = TRUE;
		pamac_alpm_package_linked_found_sync_pkg (self);
		_tmp0_ = self->priv->sync_pkg;
		_tmp1_ = alpm_pkg_get_db (_tmp0_);
		_tmp2_ = _tmp1_;
		db = _tmp2_;
		_tmp3_ = db;
		if (_tmp3_ != NULL) {
			alpm_db_t* _tmp4_;
			const gchar* _tmp5_;
			const gchar* _tmp6_;
			_tmp4_ = db;
			_tmp5_ = alpm_db_get_name (_tmp4_);
			_tmp6_ = _tmp5_;
			self->priv->_repo = _tmp6_;
		}
	}
	_tmp7_ = self->priv->_repo;
	result = _tmp7_;
	return result;
}

static void
pamac_alpm_package_linked_real_set_repo (PamacPackage* base,
                                         const gchar* value)
{
	PamacAlpmPackageLinked* self;
	self = (PamacAlpmPackageLinked*) base;
	self->priv->_repo = value;
	g_object_notify_by_pspec ((GObject *) self, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_REPO_PROPERTY]);
}

static const gchar*
pamac_alpm_package_linked_real_get_license (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageLinked* self;
	const gchar* _tmp15_;
	self = (PamacAlpmPackageLinked*) base;
	if (!self->priv->license_set) {
		alpm_list_t* list = NULL;
		alpm_pkg_t* _tmp0_;
		alpm_list_t* _tmp1_;
		alpm_list_t* _tmp2_;
		alpm_list_t* _tmp3_;
		self->priv->license_set = TRUE;
		_tmp0_ = self->priv->alpm_pkg;
		_tmp1_ = alpm_pkg_get_licenses (_tmp0_);
		_tmp2_ = _tmp1_;
		list = _tmp2_;
		_tmp3_ = list;
		if (_tmp3_ != NULL) {
			GString* license_str = NULL;
			alpm_list_t* _tmp4_;
			gconstpointer _tmp5_;
			GString* _tmp6_;
			GString* _tmp12_;
			gchar* _tmp13_;
			_tmp4_ = list;
			_tmp5_ = _tmp4_->data;
			_tmp6_ = g_string_new ((const gchar*) _tmp5_);
			license_str = _tmp6_;
			list = alpm_list_next (list);
			while (TRUE) {
				alpm_list_t* _tmp7_;
				GString* _tmp8_;
				GString* _tmp9_;
				alpm_list_t* _tmp10_;
				gconstpointer _tmp11_;
				_tmp7_ = list;
				if (!(_tmp7_ != NULL)) {
					break;
				}
				_tmp8_ = license_str;
				g_string_append (_tmp8_, " ");
				_tmp9_ = license_str;
				_tmp10_ = list;
				_tmp11_ = _tmp10_->data;
				g_string_append (_tmp9_, (const gchar*) _tmp11_);
				list = alpm_list_next (list);
			}
			_tmp12_ = license_str;
			_tmp13_ = _tmp12_->str;
			_tmp12_->str = NULL;
			_g_free0 (self->priv->_license);
			self->priv->_license = _tmp13_;
			_g_string_free0 (license_str);
		} else {
			gchar* _tmp14_;
			_tmp14_ = g_strdup (g_dgettext (NULL, "Unknown"));
			_g_free0 (self->priv->_license);
			self->priv->_license = _tmp14_;
		}
	}
	_tmp15_ = self->priv->_license;
	result = _tmp15_;
	return result;
}

static const gchar*
pamac_alpm_package_linked_real_get_url (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageLinked* self;
	const gchar* _tmp0_;
	const gchar* _tmp4_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_url;
	if (_tmp0_ == NULL) {
		alpm_pkg_t* _tmp1_;
		const gchar* _tmp2_;
		const gchar* _tmp3_;
		_tmp1_ = self->priv->alpm_pkg;
		_tmp2_ = alpm_pkg_get_url (_tmp1_);
		_tmp3_ = _tmp2_;
		self->priv->_url = _tmp3_;
	}
	_tmp4_ = self->priv->_url;
	result = _tmp4_;
	return result;
}

static guint64
pamac_alpm_package_linked_real_get_installed_size (PamacPackage* base)
{
	guint64 result;
	PamacAlpmPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	self = (PamacAlpmPackageLinked*) base;
	if (self->priv->_installed_size == ((guint64) 0)) {
		_tmp0_ = !self->priv->installed_size_set;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		alpm_pkg_t* _tmp1_;
		guint64 _tmp2_;
		guint64 _tmp3_;
		self->priv->installed_size_set = TRUE;
		_tmp1_ = self->priv->alpm_pkg;
		_tmp2_ = alpm_pkg_get_isize (_tmp1_);
		_tmp3_ = _tmp2_;
		self->priv->_installed_size = _tmp3_;
	}
	result = self->priv->_installed_size;
	return result;
}

static guint64
pamac_alpm_package_linked_real_get_download_size (PamacPackage* base)
{
	guint64 result;
	PamacAlpmPackageLinked* self;
	self = (PamacAlpmPackageLinked*) base;
	if (!self->priv->download_size_set) {
		alpm_pkg_t* _tmp0_;
		guint64 _tmp1_;
		guint64 _tmp2_;
		self->priv->download_size_set = TRUE;
		_tmp0_ = self->priv->alpm_pkg;
		_tmp1_ = alpm_pkg_download_size (_tmp0_);
		_tmp2_ = _tmp1_;
		self->priv->_download_size = _tmp2_;
	}
	result = self->priv->_download_size;
	return result;
}

static GDateTime*
pamac_alpm_package_linked_real_get_install_date (PamacPackage* base)
{
	GDateTime* result;
	PamacAlpmPackageLinked* self;
	GDateTime* _tmp5_;
	self = (PamacAlpmPackageLinked*) base;
	if (!self->priv->install_date_set) {
		alpm_pkg_t* _tmp0_;
		self->priv->install_date_set = TRUE;
		pamac_alpm_package_linked_found_local_pkg (self);
		_tmp0_ = self->priv->local_pkg;
		if (_tmp0_ != NULL) {
			alpm_pkg_t* _tmp1_;
			alpm_time_t _tmp2_;
			alpm_time_t _tmp3_;
			GDateTime* _tmp4_;
			_tmp1_ = self->priv->local_pkg;
			_tmp2_ = alpm_pkg_get_installdate (_tmp1_);
			_tmp3_ = _tmp2_;
			_tmp4_ = g_date_time_new_from_unix_local ((gint64) _tmp3_);
			_g_date_time_unref0 (self->priv->_install_date);
			self->priv->_install_date = _tmp4_;
		}
	}
	_tmp5_ = self->priv->_install_date;
	result = _tmp5_;
	return result;
}

static const gchar*
pamac_alpm_package_linked_real_get_app_name (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	const gchar* _tmp6_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp1_ = self->priv->_app_name;
	if (_tmp1_ == NULL) {
		PamacApp* _tmp2_;
		_tmp2_ = self->priv->_app;
		_tmp0_ = _tmp2_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		PamacApp* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		_tmp3_ = self->priv->_app;
		_tmp4_ = pamac_app_get_name (_tmp3_);
		_tmp5_ = _tmp4_;
		self->priv->_app_name = _tmp5_;
	}
	_tmp6_ = self->priv->_app_name;
	result = _tmp6_;
	return result;
}

static const gchar*
pamac_alpm_package_linked_real_get_app_id (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	const gchar* _tmp6_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp1_ = self->priv->_app_id;
	if (_tmp1_ == NULL) {
		PamacApp* _tmp2_;
		_tmp2_ = self->priv->_app;
		_tmp0_ = _tmp2_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		PamacApp* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		_tmp3_ = self->priv->_app;
		_tmp4_ = pamac_app_get_id (_tmp3_);
		_tmp5_ = _tmp4_;
		self->priv->_app_id = _tmp5_;
	}
	_tmp6_ = self->priv->_app_id;
	result = _tmp6_;
	return result;
}

static const gchar*
pamac_alpm_package_linked_real_get_long_desc (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	const gchar* _tmp6_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp1_ = self->priv->_long_desc;
	if (_tmp1_ == NULL) {
		PamacApp* _tmp2_;
		_tmp2_ = self->priv->_app;
		_tmp0_ = _tmp2_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		PamacApp* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		_tmp3_ = self->priv->_app;
		_tmp4_ = pamac_app_get_long_desc (_tmp3_);
		_tmp5_ = _tmp4_;
		self->priv->_long_desc = _tmp5_;
	}
	_tmp6_ = self->priv->_long_desc;
	result = _tmp6_;
	return result;
}

static const gchar*
pamac_alpm_package_linked_real_get_launchable (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	const gchar* _tmp6_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp1_ = self->priv->_launchable;
	if (_tmp1_ == NULL) {
		PamacApp* _tmp2_;
		_tmp2_ = self->priv->_app;
		_tmp0_ = _tmp2_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		PamacApp* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		_tmp3_ = self->priv->_app;
		_tmp4_ = pamac_app_get_launchable (_tmp3_);
		_tmp5_ = _tmp4_;
		self->priv->_launchable = _tmp5_;
	}
	_tmp6_ = self->priv->_launchable;
	result = _tmp6_;
	return result;
}

static const gchar*
pamac_alpm_package_linked_real_get_icon (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	const gchar* _tmp6_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp1_ = self->priv->_icon;
	if (_tmp1_ == NULL) {
		PamacApp* _tmp2_;
		_tmp2_ = self->priv->_app;
		_tmp0_ = _tmp2_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		PamacApp* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		_tmp3_ = self->priv->_app;
		_tmp4_ = pamac_app_get_icon (_tmp3_);
		_tmp5_ = _tmp4_;
		self->priv->_icon = _tmp5_;
	}
	_tmp6_ = self->priv->_icon;
	result = _tmp6_;
	return result;
}

static gpointer
_g_ptr_array_ref0 (gpointer self)
{
	return self ? g_ptr_array_ref (self) : NULL;
}

static void
_g_free0_ (gpointer var)
{
	var = (g_free (var), NULL);
}

static GPtrArray*
pamac_alpm_package_linked_real_get_screenshots (PamacPackage* base)
{
	GPtrArray* result;
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp7_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_screenshots;
	if (_tmp0_ == NULL) {
		PamacApp* _tmp1_;
		_tmp1_ = self->priv->_app;
		if (_tmp1_ != NULL) {
			PamacApp* _tmp2_;
			GPtrArray* _tmp3_;
			GPtrArray* _tmp4_;
			GPtrArray* _tmp5_;
			_tmp2_ = self->priv->_app;
			_tmp3_ = pamac_app_get_screenshots (_tmp2_);
			_tmp4_ = _tmp3_;
			_tmp5_ = _g_ptr_array_ref0 (_tmp4_);
			_g_ptr_array_unref0 (self->priv->_screenshots);
			self->priv->_screenshots = _tmp5_;
		} else {
			GPtrArray* _tmp6_;
			_tmp6_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
			_g_ptr_array_unref0 (self->priv->_screenshots);
			self->priv->_screenshots = _tmp6_;
		}
	}
	_tmp7_ = self->priv->_screenshots;
	result = _tmp7_;
	return result;
}

static GDateTime*
pamac_alpm_package_linked_real_get_build_date (PamacAlpmPackage* base)
{
	GDateTime* result;
	PamacAlpmPackageLinked* self;
	GDateTime* _tmp0_;
	GDateTime* _tmp5_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_build_date;
	if (_tmp0_ == NULL) {
		alpm_pkg_t* _tmp1_;
		alpm_time_t _tmp2_;
		alpm_time_t _tmp3_;
		GDateTime* _tmp4_;
		_tmp1_ = self->priv->alpm_pkg;
		_tmp2_ = alpm_pkg_get_builddate (_tmp1_);
		_tmp3_ = _tmp2_;
		_tmp4_ = g_date_time_new_from_unix_local ((gint64) _tmp3_);
		_g_date_time_unref0 (self->priv->_build_date);
		self->priv->_build_date = _tmp4_;
	}
	_tmp5_ = self->priv->_build_date;
	result = _tmp5_;
	return result;
}

static const gchar*
pamac_alpm_package_linked_real_get_packager (PamacAlpmPackage* base)
{
	const gchar* result;
	PamacAlpmPackageLinked* self;
	const gchar* _tmp0_;
	const gchar* _tmp4_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_packager;
	if (_tmp0_ == NULL) {
		alpm_pkg_t* _tmp1_;
		const gchar* _tmp2_;
		const gchar* _tmp3_;
		_tmp1_ = self->priv->alpm_pkg;
		_tmp2_ = alpm_pkg_get_packager (_tmp1_);
		_tmp3_ = _tmp2_;
		self->priv->_packager = _tmp3_;
	}
	_tmp4_ = self->priv->_packager;
	result = _tmp4_;
	return result;
}

static const gchar*
pamac_alpm_package_linked_real_get_reason (PamacAlpmPackage* base)
{
	const gchar* result;
	PamacAlpmPackageLinked* self;
	const gchar* _tmp7_;
	self = (PamacAlpmPackageLinked*) base;
	if (!self->priv->reason_set) {
		alpm_pkg_t* _tmp0_;
		self->priv->reason_set = TRUE;
		pamac_alpm_package_linked_found_local_pkg (self);
		_tmp0_ = self->priv->local_pkg;
		if (_tmp0_ != NULL) {
			alpm_pkg_t* _tmp1_;
			alpm_pkgreason_t _tmp2_;
			alpm_pkgreason_t _tmp3_;
			_tmp1_ = self->priv->local_pkg;
			_tmp2_ = alpm_pkg_get_reason (_tmp1_);
			_tmp3_ = _tmp2_;
			if (_tmp3_ == ALPM_PKG_REASON_EXPLICIT) {
				self->priv->_reason = g_dgettext (NULL, "Explicitly installed");
			} else {
				alpm_pkg_t* _tmp4_;
				alpm_pkgreason_t _tmp5_;
				alpm_pkgreason_t _tmp6_;
				_tmp4_ = self->priv->local_pkg;
				_tmp5_ = alpm_pkg_get_reason (_tmp4_);
				_tmp6_ = _tmp5_;
				if (_tmp6_ == ALPM_PKG_REASON_DEPEND) {
					self->priv->_reason = g_dgettext (NULL, "Installed as a dependency for another package");
				}
			}
		}
	}
	_tmp7_ = self->priv->_reason;
	result = _tmp7_;
	return result;
}

static GPtrArray*
pamac_alpm_package_linked_real_get_validations (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp15_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_validations;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		alpm_pkgvalidation_t validation = 0;
		alpm_pkg_t* _tmp2_;
		alpm_pkgvalidation_t _tmp3_;
		alpm_pkgvalidation_t _tmp4_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_validations);
		self->priv->_validations = _tmp1_;
		_tmp2_ = self->priv->alpm_pkg;
		_tmp3_ = alpm_pkg_get_validation (_tmp2_);
		_tmp4_ = _tmp3_;
		validation = _tmp4_;
		if (validation != 0) {
			if ((validation & ALPM_PKG_VALIDATION_NONE) != 0) {
				GPtrArray* _tmp5_;
				gchar* _tmp6_;
				_tmp5_ = self->priv->_validations;
				_tmp6_ = g_strdup (g_dgettext (NULL, "None"));
				g_ptr_array_add (_tmp5_, _tmp6_);
			} else {
				if ((validation & ALPM_PKG_VALIDATION_MD5SUM) != 0) {
					GPtrArray* _tmp7_;
					gchar* _tmp8_;
					_tmp7_ = self->priv->_validations;
					_tmp8_ = g_strdup (g_dgettext (NULL, "MD5 Sum"));
					g_ptr_array_add (_tmp7_, _tmp8_);
				}
				if ((validation & ALPM_PKG_VALIDATION_SHA256SUM) != 0) {
					GPtrArray* _tmp9_;
					gchar* _tmp10_;
					_tmp9_ = self->priv->_validations;
					_tmp10_ = g_strdup (g_dgettext (NULL, "SHA-256 Sum"));
					g_ptr_array_add (_tmp9_, _tmp10_);
				}
				if ((validation & ALPM_PKG_VALIDATION_SIGNATURE) != 0) {
					GPtrArray* _tmp11_;
					gchar* _tmp12_;
					_tmp11_ = self->priv->_validations;
					_tmp12_ = g_strdup (g_dgettext (NULL, "Signature"));
					g_ptr_array_add (_tmp11_, _tmp12_);
				}
			}
		} else {
			GPtrArray* _tmp13_;
			gchar* _tmp14_;
			_tmp13_ = self->priv->_validations;
			_tmp14_ = g_strdup (g_dgettext (NULL, "Unknown"));
			g_ptr_array_add (_tmp13_, _tmp14_);
		}
	}
	_tmp15_ = self->priv->_validations;
	result = _tmp15_;
	return result;
}

static GPtrArray*
pamac_alpm_package_linked_real_get_groups (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp10_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_groups;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		alpm_list_t* list = NULL;
		alpm_pkg_t* _tmp2_;
		alpm_list_t* _tmp3_;
		alpm_list_t* _tmp4_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_groups);
		self->priv->_groups = _tmp1_;
		_tmp2_ = self->priv->alpm_pkg;
		_tmp3_ = alpm_pkg_get_groups (_tmp2_);
		_tmp4_ = _tmp3_;
		list = _tmp4_;
		while (TRUE) {
			alpm_list_t* _tmp5_;
			GPtrArray* _tmp6_;
			alpm_list_t* _tmp7_;
			gconstpointer _tmp8_;
			gchar* _tmp9_;
			_tmp5_ = list;
			if (!(_tmp5_ != NULL)) {
				break;
			}
			_tmp6_ = self->priv->_groups;
			_tmp7_ = list;
			_tmp8_ = _tmp7_->data;
			_tmp9_ = g_strdup ((const gchar*) _tmp8_);
			g_ptr_array_add (_tmp6_, _tmp9_);
			list = alpm_list_next (list);
		}
	}
	_tmp10_ = self->priv->_groups;
	result = _tmp10_;
	return result;
}

static GPtrArray*
pamac_alpm_package_linked_real_get_depends (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp10_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_depends;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		alpm_list_t* list = NULL;
		alpm_pkg_t* _tmp2_;
		alpm_list_t* _tmp3_;
		alpm_list_t* _tmp4_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_depends);
		self->priv->_depends = _tmp1_;
		_tmp2_ = self->priv->alpm_pkg;
		_tmp3_ = alpm_pkg_get_depends (_tmp2_);
		_tmp4_ = _tmp3_;
		list = _tmp4_;
		while (TRUE) {
			alpm_list_t* _tmp5_;
			GPtrArray* _tmp6_;
			alpm_list_t* _tmp7_;
			gconstpointer _tmp8_;
			gchar* _tmp9_;
			_tmp5_ = list;
			if (!(_tmp5_ != NULL)) {
				break;
			}
			_tmp6_ = self->priv->_depends;
			_tmp7_ = list;
			_tmp8_ = _tmp7_->data;
			_tmp9_ = alpm_dep_compute_string ((alpm_depend_t*) _tmp8_);
			g_ptr_array_add (_tmp6_, _tmp9_);
			list = alpm_list_next (list);
		}
	}
	_tmp10_ = self->priv->_depends;
	result = _tmp10_;
	return result;
}

static void
pamac_alpm_package_linked_real_set_depends (PamacAlpmPackage* base,
                                            GPtrArray* value)
{
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = _g_ptr_array_ref0 (value);
	_g_ptr_array_unref0 (self->priv->_depends);
	self->priv->_depends = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_DEPENDS_PROPERTY]);
}

static GPtrArray*
pamac_alpm_package_linked_real_get_optdepends (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp10_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_optdepends;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		alpm_list_t* list = NULL;
		alpm_pkg_t* _tmp2_;
		alpm_list_t* _tmp3_;
		alpm_list_t* _tmp4_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_optdepends);
		self->priv->_optdepends = _tmp1_;
		_tmp2_ = self->priv->alpm_pkg;
		_tmp3_ = alpm_pkg_get_optdepends (_tmp2_);
		_tmp4_ = _tmp3_;
		list = _tmp4_;
		while (TRUE) {
			alpm_list_t* _tmp5_;
			GPtrArray* _tmp6_;
			alpm_list_t* _tmp7_;
			gconstpointer _tmp8_;
			gchar* _tmp9_;
			_tmp5_ = list;
			if (!(_tmp5_ != NULL)) {
				break;
			}
			_tmp6_ = self->priv->_optdepends;
			_tmp7_ = list;
			_tmp8_ = _tmp7_->data;
			_tmp9_ = alpm_dep_compute_string ((alpm_depend_t*) _tmp8_);
			g_ptr_array_add (_tmp6_, _tmp9_);
			list = alpm_list_next (list);
		}
	}
	_tmp10_ = self->priv->_optdepends;
	result = _tmp10_;
	return result;
}

static GPtrArray*
pamac_alpm_package_linked_real_get_makedepends (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp11_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_makedepends;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		alpm_pkg_t* _tmp2_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_makedepends);
		self->priv->_makedepends = _tmp1_;
		_tmp2_ = self->priv->sync_pkg;
		if (_tmp2_ != NULL) {
			alpm_list_t* list = NULL;
			alpm_pkg_t* _tmp3_;
			alpm_list_t* _tmp4_;
			alpm_list_t* _tmp5_;
			_tmp3_ = self->priv->sync_pkg;
			_tmp4_ = alpm_pkg_get_makedepends (_tmp3_);
			_tmp5_ = _tmp4_;
			list = _tmp5_;
			while (TRUE) {
				alpm_list_t* _tmp6_;
				GPtrArray* _tmp7_;
				alpm_list_t* _tmp8_;
				gconstpointer _tmp9_;
				gchar* _tmp10_;
				_tmp6_ = list;
				if (!(_tmp6_ != NULL)) {
					break;
				}
				_tmp7_ = self->priv->_makedepends;
				_tmp8_ = list;
				_tmp9_ = _tmp8_->data;
				_tmp10_ = alpm_dep_compute_string ((alpm_depend_t*) _tmp9_);
				g_ptr_array_add (_tmp7_, _tmp10_);
				list = alpm_list_next (list);
			}
		}
	}
	_tmp11_ = self->priv->_makedepends;
	result = _tmp11_;
	return result;
}

static GPtrArray*
pamac_alpm_package_linked_real_get_checkdepends (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp11_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_checkdepends;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		alpm_pkg_t* _tmp2_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_checkdepends);
		self->priv->_checkdepends = _tmp1_;
		_tmp2_ = self->priv->sync_pkg;
		if (_tmp2_ != NULL) {
			alpm_list_t* list = NULL;
			alpm_pkg_t* _tmp3_;
			alpm_list_t* _tmp4_;
			alpm_list_t* _tmp5_;
			_tmp3_ = self->priv->sync_pkg;
			_tmp4_ = alpm_pkg_get_checkdepends (_tmp3_);
			_tmp5_ = _tmp4_;
			list = _tmp5_;
			while (TRUE) {
				alpm_list_t* _tmp6_;
				GPtrArray* _tmp7_;
				alpm_list_t* _tmp8_;
				gconstpointer _tmp9_;
				gchar* _tmp10_;
				_tmp6_ = list;
				if (!(_tmp6_ != NULL)) {
					break;
				}
				_tmp7_ = self->priv->_checkdepends;
				_tmp8_ = list;
				_tmp9_ = _tmp8_->data;
				_tmp10_ = alpm_dep_compute_string ((alpm_depend_t*) _tmp9_);
				g_ptr_array_add (_tmp7_, _tmp10_);
				list = alpm_list_next (list);
			}
		}
	}
	_tmp11_ = self->priv->_checkdepends;
	result = _tmp11_;
	return result;
}

static GPtrArray*
pamac_alpm_package_linked_real_get_requiredby (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp10_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_requiredby;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		alpm_pkg_t* _tmp2_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_requiredby);
		self->priv->_requiredby = _tmp1_;
		pamac_alpm_package_linked_found_local_pkg (self);
		_tmp2_ = self->priv->local_pkg;
		if (_tmp2_ != NULL) {
			alpm_list_t* owned_list = NULL;
			alpm_pkg_t* _tmp3_;
			alpm_list_t* _tmp4_;
			alpm_list_t* list = NULL;
			alpm_list_t* _tmp5_;
			_tmp3_ = self->priv->local_pkg;
			_tmp4_ = alpm_pkg_compute_requiredby (_tmp3_);
			owned_list = _tmp4_;
			_tmp5_ = owned_list;
			list = _tmp5_;
			while (TRUE) {
				alpm_list_t* _tmp6_;
				GPtrArray* _tmp7_;
				alpm_list_t* _tmp8_;
				gpointer _tmp9_;
				_tmp6_ = list;
				if (!(_tmp6_ != NULL)) {
					break;
				}
				_tmp7_ = self->priv->_requiredby;
				_tmp8_ = list;
				_tmp9_ = _tmp8_->data;
				_tmp8_->data = NULL;
				g_ptr_array_add (_tmp7_, (gchar*) _tmp9_);
				list = alpm_list_next (list);
			}
			_alpm_list_free0 (owned_list);
		}
	}
	_tmp10_ = self->priv->_requiredby;
	result = _tmp10_;
	return result;
}

static GPtrArray*
pamac_alpm_package_linked_real_get_optionalfor (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp10_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_optionalfor;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		alpm_pkg_t* _tmp2_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_optionalfor);
		self->priv->_optionalfor = _tmp1_;
		pamac_alpm_package_linked_found_local_pkg (self);
		_tmp2_ = self->priv->local_pkg;
		if (_tmp2_ != NULL) {
			alpm_list_t* owned_list = NULL;
			alpm_pkg_t* _tmp3_;
			alpm_list_t* _tmp4_;
			alpm_list_t* list = NULL;
			alpm_list_t* _tmp5_;
			_tmp3_ = self->priv->local_pkg;
			_tmp4_ = alpm_pkg_compute_optionalfor (_tmp3_);
			owned_list = _tmp4_;
			_tmp5_ = owned_list;
			list = _tmp5_;
			while (TRUE) {
				alpm_list_t* _tmp6_;
				GPtrArray* _tmp7_;
				alpm_list_t* _tmp8_;
				gpointer _tmp9_;
				_tmp6_ = list;
				if (!(_tmp6_ != NULL)) {
					break;
				}
				_tmp7_ = self->priv->_optionalfor;
				_tmp8_ = list;
				_tmp9_ = _tmp8_->data;
				_tmp8_->data = NULL;
				g_ptr_array_add (_tmp7_, (gchar*) _tmp9_);
				list = alpm_list_next (list);
			}
			_alpm_list_free0 (owned_list);
		}
	}
	_tmp10_ = self->priv->_optionalfor;
	result = _tmp10_;
	return result;
}

static GPtrArray*
pamac_alpm_package_linked_real_get_provides (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp10_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_provides;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		alpm_list_t* list = NULL;
		alpm_pkg_t* _tmp2_;
		alpm_list_t* _tmp3_;
		alpm_list_t* _tmp4_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_provides);
		self->priv->_provides = _tmp1_;
		_tmp2_ = self->priv->alpm_pkg;
		_tmp3_ = alpm_pkg_get_provides (_tmp2_);
		_tmp4_ = _tmp3_;
		list = _tmp4_;
		while (TRUE) {
			alpm_list_t* _tmp5_;
			GPtrArray* _tmp6_;
			alpm_list_t* _tmp7_;
			gconstpointer _tmp8_;
			gchar* _tmp9_;
			_tmp5_ = list;
			if (!(_tmp5_ != NULL)) {
				break;
			}
			_tmp6_ = self->priv->_provides;
			_tmp7_ = list;
			_tmp8_ = _tmp7_->data;
			_tmp9_ = alpm_dep_compute_string ((alpm_depend_t*) _tmp8_);
			g_ptr_array_add (_tmp6_, _tmp9_);
			list = alpm_list_next (list);
		}
	}
	_tmp10_ = self->priv->_provides;
	result = _tmp10_;
	return result;
}

static void
pamac_alpm_package_linked_real_set_provides (PamacAlpmPackage* base,
                                             GPtrArray* value)
{
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = _g_ptr_array_ref0 (value);
	_g_ptr_array_unref0 (self->priv->_provides);
	self->priv->_provides = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_PROVIDES_PROPERTY]);
}

static GPtrArray*
pamac_alpm_package_linked_real_get_replaces (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp10_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_replaces;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		alpm_list_t* list = NULL;
		alpm_pkg_t* _tmp2_;
		alpm_list_t* _tmp3_;
		alpm_list_t* _tmp4_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_replaces);
		self->priv->_replaces = _tmp1_;
		_tmp2_ = self->priv->alpm_pkg;
		_tmp3_ = alpm_pkg_get_replaces (_tmp2_);
		_tmp4_ = _tmp3_;
		list = _tmp4_;
		while (TRUE) {
			alpm_list_t* _tmp5_;
			GPtrArray* _tmp6_;
			alpm_list_t* _tmp7_;
			gconstpointer _tmp8_;
			gchar* _tmp9_;
			_tmp5_ = list;
			if (!(_tmp5_ != NULL)) {
				break;
			}
			_tmp6_ = self->priv->_replaces;
			_tmp7_ = list;
			_tmp8_ = _tmp7_->data;
			_tmp9_ = alpm_dep_compute_string ((alpm_depend_t*) _tmp8_);
			g_ptr_array_add (_tmp6_, _tmp9_);
			list = alpm_list_next (list);
		}
	}
	_tmp10_ = self->priv->_replaces;
	result = _tmp10_;
	return result;
}

static void
pamac_alpm_package_linked_real_set_replaces (PamacAlpmPackage* base,
                                             GPtrArray* value)
{
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = _g_ptr_array_ref0 (value);
	_g_ptr_array_unref0 (self->priv->_replaces);
	self->priv->_replaces = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_REPLACES_PROPERTY]);
}

static GPtrArray*
pamac_alpm_package_linked_real_get_conflicts (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp10_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_conflicts;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		alpm_list_t* list = NULL;
		alpm_pkg_t* _tmp2_;
		alpm_list_t* _tmp3_;
		alpm_list_t* _tmp4_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_conflicts);
		self->priv->_conflicts = _tmp1_;
		_tmp2_ = self->priv->alpm_pkg;
		_tmp3_ = alpm_pkg_get_conflicts (_tmp2_);
		_tmp4_ = _tmp3_;
		list = _tmp4_;
		while (TRUE) {
			alpm_list_t* _tmp5_;
			GPtrArray* _tmp6_;
			alpm_list_t* _tmp7_;
			gconstpointer _tmp8_;
			gchar* _tmp9_;
			_tmp5_ = list;
			if (!(_tmp5_ != NULL)) {
				break;
			}
			_tmp6_ = self->priv->_conflicts;
			_tmp7_ = list;
			_tmp8_ = _tmp7_->data;
			_tmp9_ = alpm_dep_compute_string ((alpm_depend_t*) _tmp8_);
			g_ptr_array_add (_tmp6_, _tmp9_);
			list = alpm_list_next (list);
		}
	}
	_tmp10_ = self->priv->_conflicts;
	result = _tmp10_;
	return result;
}

static void
pamac_alpm_package_linked_real_set_conflicts (PamacAlpmPackage* base,
                                              GPtrArray* value)
{
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = _g_ptr_array_ref0 (value);
	_g_ptr_array_unref0 (self->priv->_conflicts);
	self->priv->_conflicts = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_CONFLICTS_PROPERTY]);
}

static GPtrArray*
pamac_alpm_package_linked_real_get_backups (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAlpmPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp15_;
	self = (PamacAlpmPackageLinked*) base;
	_tmp0_ = self->priv->_backups;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		alpm_pkg_t* _tmp2_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_backups);
		self->priv->_backups = _tmp1_;
		pamac_alpm_package_linked_found_local_pkg (self);
		_tmp2_ = self->priv->local_pkg;
		if (_tmp2_ != NULL) {
			alpm_list_t* list = NULL;
			alpm_pkg_t* _tmp3_;
			alpm_list_t* _tmp4_;
			alpm_list_t* _tmp5_;
			_tmp3_ = self->priv->local_pkg;
			_tmp4_ = alpm_pkg_get_backup (_tmp3_);
			_tmp5_ = _tmp4_;
			list = _tmp5_;
			while (TRUE) {
				alpm_list_t* _tmp6_;
				GString* builder = NULL;
				GString* _tmp7_;
				GString* _tmp8_;
				alpm_list_t* _tmp9_;
				gconstpointer _tmp10_;
				const gchar* _tmp11_;
				GPtrArray* _tmp12_;
				GString* _tmp13_;
				gchar* _tmp14_;
				_tmp6_ = list;
				if (!(_tmp6_ != NULL)) {
					break;
				}
				_tmp7_ = g_string_new ("/");
				builder = _tmp7_;
				_tmp8_ = builder;
				_tmp9_ = list;
				_tmp10_ = _tmp9_->data;
				_tmp11_ = ((alpm_backup_t*) _tmp10_)->name;
				g_string_append (_tmp8_, _tmp11_);
				_tmp12_ = self->priv->_backups;
				_tmp13_ = builder;
				_tmp14_ = _tmp13_->str;
				_tmp13_->str = NULL;
				g_ptr_array_add (_tmp12_, _tmp14_);
				list = alpm_list_next (list);
				_g_string_free0 (builder);
			}
		}
	}
	_tmp15_ = self->priv->_backups;
	result = _tmp15_;
	return result;
}

static void
pamac_alpm_package_linked_class_init (PamacAlpmPackageLinkedClass * klass,
                                      gpointer klass_data)
{
	pamac_alpm_package_linked_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &PamacAlpmPackageLinked_private_offset);
	((PamacAlpmPackageClass *) klass)->get_files = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_files;
	((PamacAlpmPackageClass *) klass)->get_files_async = (void (*) (PamacAlpmPackage*, GAsyncReadyCallback, gpointer)) pamac_alpm_package_linked_real_get_files_async;
	((PamacAlpmPackageClass *) klass)->get_files_finish = (GPtrArray* (*) (PamacAlpmPackage*, GAsyncResult*)) pamac_alpm_package_linked_get_files_finish;
	PAMAC_PACKAGE_CLASS (klass)->get_name = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_name;
	PAMAC_PACKAGE_CLASS (klass)->set_name = (void (*) (PamacPackage*, const gchar*)) pamac_alpm_package_linked_real_set_name;
	PAMAC_PACKAGE_CLASS (klass)->get_id = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_id;
	PAMAC_PACKAGE_CLASS (klass)->set_id = (void (*) (PamacPackage*, const gchar*)) pamac_alpm_package_linked_real_set_id;
	PAMAC_PACKAGE_CLASS (klass)->get_version = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_version;
	PAMAC_PACKAGE_CLASS (klass)->set_version = (void (*) (PamacPackage*, const gchar*)) pamac_alpm_package_linked_real_set_version;
	PAMAC_PACKAGE_CLASS (klass)->get_installed_version = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_installed_version;
	PAMAC_PACKAGE_CLASS (klass)->set_installed_version = (void (*) (PamacPackage*, const gchar*)) pamac_alpm_package_linked_real_set_installed_version;
	PAMAC_PACKAGE_CLASS (klass)->get_desc = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_desc;
	PAMAC_PACKAGE_CLASS (klass)->set_desc = (void (*) (PamacPackage*, const gchar*)) pamac_alpm_package_linked_real_set_desc;
	PAMAC_PACKAGE_CLASS (klass)->get_repo = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_repo;
	PAMAC_PACKAGE_CLASS (klass)->set_repo = (void (*) (PamacPackage*, const gchar*)) pamac_alpm_package_linked_real_set_repo;
	PAMAC_PACKAGE_CLASS (klass)->get_license = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_license;
	PAMAC_PACKAGE_CLASS (klass)->get_url = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_url;
	PAMAC_PACKAGE_CLASS (klass)->get_installed_size = (guint64 (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_installed_size;
	PAMAC_PACKAGE_CLASS (klass)->get_download_size = (guint64 (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_download_size;
	PAMAC_PACKAGE_CLASS (klass)->get_install_date = (GDateTime* (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_install_date;
	PAMAC_PACKAGE_CLASS (klass)->get_app_name = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_app_name;
	PAMAC_PACKAGE_CLASS (klass)->get_app_id = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_app_id;
	PAMAC_PACKAGE_CLASS (klass)->get_long_desc = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_long_desc;
	PAMAC_PACKAGE_CLASS (klass)->get_launchable = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_launchable;
	PAMAC_PACKAGE_CLASS (klass)->get_icon = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_icon;
	PAMAC_PACKAGE_CLASS (klass)->get_screenshots = (GPtrArray* (*) (PamacPackage*)) pamac_alpm_package_linked_real_get_screenshots;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_build_date = (GDateTime* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_build_date;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_packager = (const gchar* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_packager;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_reason = (const gchar* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_reason;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_validations = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_validations;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_groups = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_groups;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_depends = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_depends;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->set_depends = (void (*) (PamacAlpmPackage*, GPtrArray*)) pamac_alpm_package_linked_real_set_depends;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_optdepends = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_optdepends;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_makedepends = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_makedepends;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_checkdepends = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_checkdepends;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_requiredby = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_requiredby;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_optionalfor = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_optionalfor;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_provides = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_provides;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->set_provides = (void (*) (PamacAlpmPackage*, GPtrArray*)) pamac_alpm_package_linked_real_set_provides;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_replaces = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_replaces;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->set_replaces = (void (*) (PamacAlpmPackage*, GPtrArray*)) pamac_alpm_package_linked_real_set_replaces;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_conflicts = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_conflicts;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->set_conflicts = (void (*) (PamacAlpmPackage*, GPtrArray*)) pamac_alpm_package_linked_real_set_conflicts;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_backups = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_alpm_package_linked_real_get_backups;
	G_OBJECT_CLASS (klass)->get_property = _vala_pamac_alpm_package_linked_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_pamac_alpm_package_linked_set_property;
	G_OBJECT_CLASS (klass)->finalize = pamac_alpm_package_linked_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_NAME_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_ID_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_VERSION_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_VERSION_PROPERTY] = g_param_spec_string ("version", "version", "version", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_INSTALLED_VERSION_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_INSTALLED_VERSION_PROPERTY] = g_param_spec_string ("installed-version", "installed-version", "installed-version", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_DESC_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_DESC_PROPERTY] = g_param_spec_string ("desc", "desc", "desc", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_REPO_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_REPO_PROPERTY] = g_param_spec_string ("repo", "repo", "repo", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_LICENSE_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_LICENSE_PROPERTY] = g_param_spec_string ("license", "license", "license", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_URL_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_URL_PROPERTY] = g_param_spec_string ("url", "url", "url", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_INSTALLED_SIZE_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_INSTALLED_SIZE_PROPERTY] = g_param_spec_uint64 ("installed-size", "installed-size", "installed-size", 0, G_MAXUINT64, 0U, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_DOWNLOAD_SIZE_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_DOWNLOAD_SIZE_PROPERTY] = g_param_spec_uint64 ("download-size", "download-size", "download-size", 0, G_MAXUINT64, 0U, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_INSTALL_DATE_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_INSTALL_DATE_PROPERTY] = g_param_spec_boxed ("install-date", "install-date", "install-date", G_TYPE_DATE_TIME, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_APP_NAME_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_APP_NAME_PROPERTY] = g_param_spec_string ("app-name", "app-name", "app-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_APP_ID_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_APP_ID_PROPERTY] = g_param_spec_string ("app-id", "app-id", "app-id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_LONG_DESC_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_LONG_DESC_PROPERTY] = g_param_spec_string ("long-desc", "long-desc", "long-desc", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_LAUNCHABLE_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_LAUNCHABLE_PROPERTY] = g_param_spec_string ("launchable", "launchable", "launchable", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_ICON_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_ICON_PROPERTY] = g_param_spec_string ("icon", "icon", "icon", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_SCREENSHOTS_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_SCREENSHOTS_PROPERTY] = g_param_spec_boxed ("screenshots", "screenshots", "screenshots", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_BUILD_DATE_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_BUILD_DATE_PROPERTY] = g_param_spec_boxed ("build-date", "build-date", "build-date", G_TYPE_DATE_TIME, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_PACKAGER_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_PACKAGER_PROPERTY] = g_param_spec_string ("packager", "packager", "packager", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_REASON_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_REASON_PROPERTY] = g_param_spec_string ("reason", "reason", "reason", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_VALIDATIONS_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_VALIDATIONS_PROPERTY] = g_param_spec_boxed ("validations", "validations", "validations", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_GROUPS_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_GROUPS_PROPERTY] = g_param_spec_boxed ("groups", "groups", "groups", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_DEPENDS_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_DEPENDS_PROPERTY] = g_param_spec_boxed ("depends", "depends", "depends", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_OPTDEPENDS_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_OPTDEPENDS_PROPERTY] = g_param_spec_boxed ("optdepends", "optdepends", "optdepends", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_MAKEDEPENDS_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_MAKEDEPENDS_PROPERTY] = g_param_spec_boxed ("makedepends", "makedepends", "makedepends", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_CHECKDEPENDS_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_CHECKDEPENDS_PROPERTY] = g_param_spec_boxed ("checkdepends", "checkdepends", "checkdepends", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_REQUIREDBY_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_REQUIREDBY_PROPERTY] = g_param_spec_boxed ("requiredby", "requiredby", "requiredby", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_OPTIONALFOR_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_OPTIONALFOR_PROPERTY] = g_param_spec_boxed ("optionalfor", "optionalfor", "optionalfor", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_PROVIDES_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_PROVIDES_PROPERTY] = g_param_spec_boxed ("provides", "provides", "provides", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_REPLACES_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_REPLACES_PROPERTY] = g_param_spec_boxed ("replaces", "replaces", "replaces", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_CONFLICTS_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_CONFLICTS_PROPERTY] = g_param_spec_boxed ("conflicts", "conflicts", "conflicts", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_LINKED_BACKUPS_PROPERTY, pamac_alpm_package_linked_properties[PAMAC_ALPM_PACKAGE_LINKED_BACKUPS_PROPERTY] = g_param_spec_boxed ("backups", "backups", "backups", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
pamac_alpm_package_linked_instance_init (PamacAlpmPackageLinked * self,
                                         gpointer klass)
{
	self->priv = pamac_alpm_package_linked_get_instance_private (self);
}

static void
pamac_alpm_package_linked_finalize (GObject * obj)
{
	PamacAlpmPackageLinked * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PAMAC_TYPE_ALPM_PACKAGE_LINKED, PamacAlpmPackageLinked);
	_g_free0 (self->priv->_name);
	_g_free0 (self->priv->_id);
	_g_free0 (self->priv->_license);
	_g_date_time_unref0 (self->priv->_install_date);
	_g_ptr_array_unref0 (self->priv->_screenshots);
	_g_date_time_unref0 (self->priv->_build_date);
	_g_ptr_array_unref0 (self->priv->_validations);
	_g_ptr_array_unref0 (self->priv->_groups);
	_g_ptr_array_unref0 (self->priv->_depends);
	_g_ptr_array_unref0 (self->priv->_optdepends);
	_g_ptr_array_unref0 (self->priv->_makedepends);
	_g_ptr_array_unref0 (self->priv->_checkdepends);
	_g_ptr_array_unref0 (self->priv->_requiredby);
	_g_ptr_array_unref0 (self->priv->_optionalfor);
	_g_ptr_array_unref0 (self->priv->_provides);
	_g_ptr_array_unref0 (self->priv->_replaces);
	_g_ptr_array_unref0 (self->priv->_conflicts);
	_g_ptr_array_unref0 (self->priv->_backups);
	_g_ptr_array_unref0 (self->priv->_files);
	G_OBJECT_CLASS (pamac_alpm_package_linked_parent_class)->finalize (obj);
}

static GType
pamac_alpm_package_linked_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PamacAlpmPackageLinkedClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) pamac_alpm_package_linked_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PamacAlpmPackageLinked), 0, (GInstanceInitFunc) pamac_alpm_package_linked_instance_init, NULL };
	GType pamac_alpm_package_linked_type_id;
	pamac_alpm_package_linked_type_id = g_type_register_static (PAMAC_TYPE_ALPM_PACKAGE, "PamacAlpmPackageLinked", &g_define_type_info, 0);
	PamacAlpmPackageLinked_private_offset = g_type_add_instance_private (pamac_alpm_package_linked_type_id, sizeof (PamacAlpmPackageLinkedPrivate));
	return pamac_alpm_package_linked_type_id;
}

GType
pamac_alpm_package_linked_get_type (void)
{
	static volatile gsize pamac_alpm_package_linked_type_id__once = 0;
	if (g_once_init_enter (&pamac_alpm_package_linked_type_id__once)) {
		GType pamac_alpm_package_linked_type_id;
		pamac_alpm_package_linked_type_id = pamac_alpm_package_linked_get_type_once ();
		g_once_init_leave (&pamac_alpm_package_linked_type_id__once, pamac_alpm_package_linked_type_id);
	}
	return pamac_alpm_package_linked_type_id__once;
}

static void
_vala_pamac_alpm_package_linked_get_property (GObject * object,
                                              guint property_id,
                                              GValue * value,
                                              GParamSpec * pspec)
{
	PamacAlpmPackageLinked * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_ALPM_PACKAGE_LINKED, PamacAlpmPackageLinked);
	switch (property_id) {
		case PAMAC_ALPM_PACKAGE_LINKED_NAME_PROPERTY:
		g_value_set_string (value, pamac_package_get_name ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_ID_PROPERTY:
		g_value_set_string (value, pamac_package_get_id ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_VERSION_PROPERTY:
		g_value_set_string (value, pamac_package_get_version ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_INSTALLED_VERSION_PROPERTY:
		g_value_set_string (value, pamac_package_get_installed_version ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_DESC_PROPERTY:
		g_value_set_string (value, pamac_package_get_desc ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_REPO_PROPERTY:
		g_value_set_string (value, pamac_package_get_repo ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_LICENSE_PROPERTY:
		g_value_set_string (value, pamac_package_get_license ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_URL_PROPERTY:
		g_value_set_string (value, pamac_package_get_url ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_INSTALLED_SIZE_PROPERTY:
		g_value_set_uint64 (value, pamac_package_get_installed_size ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_DOWNLOAD_SIZE_PROPERTY:
		g_value_set_uint64 (value, pamac_package_get_download_size ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_INSTALL_DATE_PROPERTY:
		g_value_set_boxed (value, pamac_package_get_install_date ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_APP_NAME_PROPERTY:
		g_value_set_string (value, pamac_package_get_app_name ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_APP_ID_PROPERTY:
		g_value_set_string (value, pamac_package_get_app_id ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_LONG_DESC_PROPERTY:
		g_value_set_string (value, pamac_package_get_long_desc ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_LAUNCHABLE_PROPERTY:
		g_value_set_string (value, pamac_package_get_launchable ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_ICON_PROPERTY:
		g_value_set_string (value, pamac_package_get_icon ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_SCREENSHOTS_PROPERTY:
		g_value_set_boxed (value, pamac_package_get_screenshots ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_BUILD_DATE_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_build_date ((PamacAlpmPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_PACKAGER_PROPERTY:
		g_value_set_string (value, pamac_alpm_package_get_packager ((PamacAlpmPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_REASON_PROPERTY:
		g_value_set_string (value, pamac_alpm_package_get_reason ((PamacAlpmPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_VALIDATIONS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_validations ((PamacAlpmPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_GROUPS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_groups ((PamacAlpmPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_DEPENDS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_depends ((PamacAlpmPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_OPTDEPENDS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_optdepends ((PamacAlpmPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_MAKEDEPENDS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_makedepends ((PamacAlpmPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_CHECKDEPENDS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_checkdepends ((PamacAlpmPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_REQUIREDBY_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_requiredby ((PamacAlpmPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_OPTIONALFOR_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_optionalfor ((PamacAlpmPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_PROVIDES_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_provides ((PamacAlpmPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_REPLACES_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_replaces ((PamacAlpmPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_CONFLICTS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_conflicts ((PamacAlpmPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_BACKUPS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_backups ((PamacAlpmPackage*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_pamac_alpm_package_linked_set_property (GObject * object,
                                              guint property_id,
                                              const GValue * value,
                                              GParamSpec * pspec)
{
	PamacAlpmPackageLinked * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_ALPM_PACKAGE_LINKED, PamacAlpmPackageLinked);
	switch (property_id) {
		case PAMAC_ALPM_PACKAGE_LINKED_NAME_PROPERTY:
		pamac_package_set_name ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_ID_PROPERTY:
		pamac_package_set_id ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_VERSION_PROPERTY:
		pamac_package_set_version ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_INSTALLED_VERSION_PROPERTY:
		pamac_package_set_installed_version ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_DESC_PROPERTY:
		pamac_package_set_desc ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_REPO_PROPERTY:
		pamac_package_set_repo ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_DEPENDS_PROPERTY:
		pamac_alpm_package_set_depends ((PamacAlpmPackage*) self, g_value_get_boxed (value));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_PROVIDES_PROPERTY:
		pamac_alpm_package_set_provides ((PamacAlpmPackage*) self, g_value_get_boxed (value));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_REPLACES_PROPERTY:
		pamac_alpm_package_set_replaces ((PamacAlpmPackage*) self, g_value_get_boxed (value));
		break;
		case PAMAC_ALPM_PACKAGE_LINKED_CONFLICTS_PROPERTY:
		pamac_alpm_package_set_conflicts ((PamacAlpmPackage*) self, g_value_get_boxed (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
pamac_alpm_package_static_get_instance_private (PamacAlpmPackageStatic* self)
{
	return G_STRUCT_MEMBER_P (self, PamacAlpmPackageStatic_private_offset);
}

static gpointer
_g_date_time_ref0 (gpointer self)
{
	return self ? g_date_time_ref (self) : NULL;
}

PamacAlpmPackageStatic*
pamac_alpm_package_static_construct (GType object_type,
                                     alpm_pkg_t* alpm_pkg,
                                     alpm_pkg_t* local_pkg,
                                     alpm_pkg_t* sync_pkg)
{
	PamacAlpmPackageStatic * self = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	gchar* _tmp8_;
	const gchar* str = NULL;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	guint64 val = 0ULL;
	guint64 _tmp15_;
	guint64 _tmp16_;
	guint64 _tmp17_;
	guint64 _tmp18_;
	GDateTime* date = NULL;
	GDateTime* _tmp19_;
	GDateTime* _tmp20_;
	GDateTime* _tmp21_;
	GPtrArray* list = NULL;
	GPtrArray* _tmp48_;
	GPtrArray* _tmp49_;
	GPtrArray* _tmp50_;
	GPtrArray* _tmp51_;
	GPtrArray* _tmp52_;
	GPtrArray* _tmp53_;
	GPtrArray* _tmp54_;
	GPtrArray* _tmp55_;
	GPtrArray* _tmp56_;
	GPtrArray* _tmp57_;
	GPtrArray* _tmp58_;
	GPtrArray* _tmp59_;
	GPtrArray* _tmp60_;
	GPtrArray* _tmp61_;
	g_return_val_if_fail (alpm_pkg != NULL, NULL);
	self = (PamacAlpmPackageStatic*) pamac_alpm_package_linked_construct (object_type);
	_tmp0_ = alpm_pkg_get_version (alpm_pkg);
	_tmp1_ = _tmp0_;
	_tmp2_ = g_strdup (_tmp1_);
	_g_free0 (self->priv->_version);
	self->priv->_version = _tmp2_;
	_tmp3_ = alpm_pkg_get_desc (alpm_pkg);
	_tmp4_ = _tmp3_;
	_tmp5_ = g_strdup (_tmp4_);
	_g_free0 (self->priv->_desc);
	self->priv->_desc = _tmp5_;
	_tmp6_ = alpm_pkg_get_packager (alpm_pkg);
	_tmp7_ = _tmp6_;
	_tmp8_ = g_strdup (_tmp7_);
	_g_free0 (self->priv->_packager);
	self->priv->_packager = _tmp8_;
	pamac_alpm_package_linked_set_alpm_pkg ((PamacAlpmPackageLinked*) self, alpm_pkg);
	pamac_alpm_package_linked_set_local_pkg ((PamacAlpmPackageLinked*) self, local_pkg);
	pamac_alpm_package_linked_set_sync_pkg ((PamacAlpmPackageLinked*) self, sync_pkg);
	_tmp9_ = pamac_package_get_name ((PamacPackage*) self);
	_tmp10_ = _tmp9_;
	str = _tmp10_;
	_tmp11_ = pamac_package_get_id ((PamacPackage*) self);
	_tmp12_ = _tmp11_;
	str = _tmp12_;
	_tmp13_ = pamac_package_get_license ((PamacPackage*) self);
	_tmp14_ = _tmp13_;
	str = _tmp14_;
	_tmp15_ = pamac_package_get_installed_size ((PamacPackage*) self);
	_tmp16_ = _tmp15_;
	val = _tmp16_;
	_tmp17_ = pamac_package_get_download_size ((PamacPackage*) self);
	_tmp18_ = _tmp17_;
	val = _tmp18_;
	_tmp19_ = pamac_alpm_package_get_build_date ((PamacAlpmPackage*) self);
	_tmp20_ = _tmp19_;
	_tmp21_ = _g_date_time_ref0 (_tmp20_);
	date = _tmp21_;
	if (local_pkg != NULL) {
		const gchar* _tmp22_;
		const gchar* _tmp23_;
		gchar* _tmp24_;
		GDateTime* _tmp25_;
		GDateTime* _tmp26_;
		GDateTime* _tmp27_;
		const gchar* _tmp28_;
		const gchar* _tmp29_;
		GPtrArray* list = NULL;
		GPtrArray* _tmp30_;
		GPtrArray* _tmp31_;
		GPtrArray* _tmp32_;
		GPtrArray* _tmp33_;
		GPtrArray* _tmp34_;
		GPtrArray* _tmp35_;
		_tmp22_ = alpm_pkg_get_version (local_pkg);
		_tmp23_ = _tmp22_;
		_tmp24_ = g_strdup (_tmp23_);
		_g_free0 (self->priv->_installed_version);
		self->priv->_installed_version = _tmp24_;
		_tmp25_ = pamac_package_get_install_date ((PamacPackage*) self);
		_tmp26_ = _tmp25_;
		_tmp27_ = _g_date_time_ref0 (_tmp26_);
		_g_date_time_unref0 (date);
		date = _tmp27_;
		_tmp28_ = pamac_alpm_package_get_reason ((PamacAlpmPackage*) self);
		_tmp29_ = _tmp28_;
		str = _tmp29_;
		_tmp30_ = pamac_alpm_package_get_requiredby ((PamacAlpmPackage*) self);
		_tmp31_ = _tmp30_;
		list = _tmp31_;
		_tmp32_ = pamac_alpm_package_get_optionalfor ((PamacAlpmPackage*) self);
		_tmp33_ = _tmp32_;
		list = _tmp33_;
		_tmp34_ = pamac_alpm_package_get_backups ((PamacAlpmPackage*) self);
		_tmp35_ = _tmp34_;
		list = _tmp35_;
	}
	if (sync_pkg != NULL) {
		const gchar* _tmp36_;
		const gchar* _tmp37_;
		gchar* _tmp38_;
		alpm_db_t* _tmp39_;
		alpm_db_t* _tmp40_;
		const gchar* _tmp41_;
		const gchar* _tmp42_;
		gchar* _tmp43_;
		GPtrArray* list = NULL;
		GPtrArray* _tmp44_;
		GPtrArray* _tmp45_;
		GPtrArray* _tmp46_;
		GPtrArray* _tmp47_;
		_tmp36_ = alpm_pkg_get_version (sync_pkg);
		_tmp37_ = _tmp36_;
		_tmp38_ = g_strdup (_tmp37_);
		_g_free0 (self->priv->_version);
		self->priv->_version = _tmp38_;
		_tmp39_ = alpm_pkg_get_db (sync_pkg);
		_tmp40_ = _tmp39_;
		_tmp41_ = alpm_db_get_name (_tmp40_);
		_tmp42_ = _tmp41_;
		_tmp43_ = g_strdup (_tmp42_);
		_g_free0 (self->priv->_repo);
		self->priv->_repo = _tmp43_;
		_tmp44_ = pamac_alpm_package_get_makedepends ((PamacAlpmPackage*) self);
		_tmp45_ = _tmp44_;
		list = _tmp45_;
		_tmp46_ = pamac_alpm_package_get_checkdepends ((PamacAlpmPackage*) self);
		_tmp47_ = _tmp46_;
		list = _tmp47_;
	}
	_tmp48_ = pamac_alpm_package_get_groups ((PamacAlpmPackage*) self);
	_tmp49_ = _tmp48_;
	list = _tmp49_;
	_tmp50_ = pamac_alpm_package_get_validations ((PamacAlpmPackage*) self);
	_tmp51_ = _tmp50_;
	list = _tmp51_;
	_tmp52_ = pamac_alpm_package_get_depends ((PamacAlpmPackage*) self);
	_tmp53_ = _tmp52_;
	list = _tmp53_;
	_tmp54_ = pamac_alpm_package_get_optdepends ((PamacAlpmPackage*) self);
	_tmp55_ = _tmp54_;
	list = _tmp55_;
	_tmp56_ = pamac_alpm_package_get_provides ((PamacAlpmPackage*) self);
	_tmp57_ = _tmp56_;
	list = _tmp57_;
	_tmp58_ = pamac_alpm_package_get_replaces ((PamacAlpmPackage*) self);
	_tmp59_ = _tmp58_;
	list = _tmp59_;
	_tmp60_ = pamac_alpm_package_get_conflicts ((PamacAlpmPackage*) self);
	_tmp61_ = _tmp60_;
	list = _tmp61_;
	pamac_alpm_package_linked_set_alpm_pkg ((PamacAlpmPackageLinked*) self, NULL);
	pamac_alpm_package_linked_set_local_pkg ((PamacAlpmPackageLinked*) self, NULL);
	pamac_alpm_package_linked_set_sync_pkg ((PamacAlpmPackageLinked*) self, NULL);
	_g_date_time_unref0 (date);
	return self;
}

PamacAlpmPackageStatic*
pamac_alpm_package_static_new (alpm_pkg_t* alpm_pkg,
                               alpm_pkg_t* local_pkg,
                               alpm_pkg_t* sync_pkg)
{
	return pamac_alpm_package_static_construct (PAMAC_TYPE_ALPM_PACKAGE_STATIC, alpm_pkg, local_pkg, sync_pkg);
}

PamacAlpmPackageStatic*
pamac_alpm_package_static_construct_transaction (GType object_type,
                                                 alpm_pkg_t* alpm_pkg,
                                                 alpm_pkg_t* local_pkg,
                                                 alpm_pkg_t* sync_pkg)
{
	PamacAlpmPackageStatic * self = NULL;
	const gchar* str = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	guint64 val = 0ULL;
	guint64 _tmp8_;
	guint64 _tmp9_;
	guint64 _tmp10_;
	guint64 _tmp11_;
	GPtrArray* list = NULL;
	GPtrArray* _tmp28_;
	GPtrArray* _tmp29_;
	g_return_val_if_fail (alpm_pkg != NULL, NULL);
	self = (PamacAlpmPackageStatic*) pamac_alpm_package_linked_construct (object_type);
	pamac_alpm_package_linked_set_alpm_pkg ((PamacAlpmPackageLinked*) self, alpm_pkg);
	pamac_alpm_package_linked_set_local_pkg ((PamacAlpmPackageLinked*) self, local_pkg);
	pamac_alpm_package_linked_set_sync_pkg ((PamacAlpmPackageLinked*) self, sync_pkg);
	_tmp0_ = pamac_package_get_name ((PamacPackage*) self);
	_tmp1_ = _tmp0_;
	str = _tmp1_;
	str = NULL;
	_tmp2_ = alpm_pkg_get_version (alpm_pkg);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strdup (_tmp3_);
	_g_free0 (self->priv->_version);
	self->priv->_version = _tmp4_;
	_tmp5_ = alpm_pkg_get_desc (alpm_pkg);
	_tmp6_ = _tmp5_;
	_tmp7_ = g_strdup (_tmp6_);
	_g_free0 (self->priv->_desc);
	self->priv->_desc = _tmp7_;
	_tmp8_ = pamac_package_get_installed_size ((PamacPackage*) self);
	_tmp9_ = _tmp8_;
	val = _tmp9_;
	_tmp10_ = pamac_package_get_download_size ((PamacPackage*) self);
	_tmp11_ = _tmp10_;
	val = _tmp11_;
	if (local_pkg != NULL) {
		const gchar* _tmp12_;
		const gchar* _tmp13_;
		gchar* _tmp14_;
		GDateTime* date = NULL;
		GDateTime* _tmp15_;
		GDateTime* _tmp16_;
		GDateTime* _tmp17_;
		_tmp12_ = alpm_pkg_get_version (local_pkg);
		_tmp13_ = _tmp12_;
		_tmp14_ = g_strdup (_tmp13_);
		_g_free0 (self->priv->_installed_version);
		self->priv->_installed_version = _tmp14_;
		_tmp15_ = pamac_package_get_install_date ((PamacPackage*) self);
		_tmp16_ = _tmp15_;
		_tmp17_ = _g_date_time_ref0 (_tmp16_);
		date = _tmp17_;
		_g_date_time_unref0 (date);
		date = NULL;
		_g_date_time_unref0 (date);
	}
	if (sync_pkg != NULL) {
		alpm_db_t* _tmp18_;
		alpm_db_t* _tmp19_;
		const gchar* _tmp20_;
		const gchar* _tmp21_;
		_tmp18_ = alpm_pkg_get_db (sync_pkg);
		_tmp19_ = _tmp18_;
		_tmp20_ = alpm_db_get_name (_tmp19_);
		_tmp21_ = _tmp20_;
		if (g_strcmp0 (_tmp21_, "pamac_aur") == 0) {
			gchar* _tmp22_;
			_tmp22_ = g_strdup (g_dgettext (NULL, "AUR"));
			_g_free0 (self->priv->_repo);
			self->priv->_repo = _tmp22_;
		} else {
			alpm_db_t* _tmp23_;
			alpm_db_t* _tmp24_;
			const gchar* _tmp25_;
			const gchar* _tmp26_;
			gchar* _tmp27_;
			_tmp23_ = alpm_pkg_get_db (sync_pkg);
			_tmp24_ = _tmp23_;
			_tmp25_ = alpm_db_get_name (_tmp24_);
			_tmp26_ = _tmp25_;
			_tmp27_ = g_strdup (_tmp26_);
			_g_free0 (self->priv->_repo);
			self->priv->_repo = _tmp27_;
		}
	}
	_tmp28_ = pamac_alpm_package_get_provides ((PamacAlpmPackage*) self);
	_tmp29_ = _tmp28_;
	list = _tmp29_;
	list = NULL;
	pamac_alpm_package_linked_set_alpm_pkg ((PamacAlpmPackageLinked*) self, NULL);
	pamac_alpm_package_linked_set_local_pkg ((PamacAlpmPackageLinked*) self, NULL);
	pamac_alpm_package_linked_set_sync_pkg ((PamacAlpmPackageLinked*) self, NULL);
	return self;
}

PamacAlpmPackageStatic*
pamac_alpm_package_static_new_transaction (alpm_pkg_t* alpm_pkg,
                                           alpm_pkg_t* local_pkg,
                                           alpm_pkg_t* sync_pkg)
{
	return pamac_alpm_package_static_construct_transaction (PAMAC_TYPE_ALPM_PACKAGE_STATIC, alpm_pkg, local_pkg, sync_pkg);
}

static const gchar*
pamac_alpm_package_static_real_get_version (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageStatic* self;
	const gchar* _tmp0_;
	self = (PamacAlpmPackageStatic*) base;
	_tmp0_ = self->priv->_version;
	result = _tmp0_;
	return result;
}

static void
pamac_alpm_package_static_real_set_version (PamacPackage* base,
                                            const gchar* value)
{
	PamacAlpmPackageStatic* self;
	gchar* _tmp0_;
	self = (PamacAlpmPackageStatic*) base;
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_version);
	self->priv->_version = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_alpm_package_static_properties[PAMAC_ALPM_PACKAGE_STATIC_VERSION_PROPERTY]);
}

static const gchar*
pamac_alpm_package_static_real_get_installed_version (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageStatic* self;
	const gchar* _tmp0_;
	self = (PamacAlpmPackageStatic*) base;
	_tmp0_ = self->priv->_installed_version;
	result = _tmp0_;
	return result;
}

static void
pamac_alpm_package_static_real_set_installed_version (PamacPackage* base,
                                                      const gchar* value)
{
	PamacAlpmPackageStatic* self;
	gchar* _tmp0_;
	self = (PamacAlpmPackageStatic*) base;
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_installed_version);
	self->priv->_installed_version = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_alpm_package_static_properties[PAMAC_ALPM_PACKAGE_STATIC_INSTALLED_VERSION_PROPERTY]);
}

static const gchar*
pamac_alpm_package_static_real_get_desc (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageStatic* self;
	const gchar* _tmp0_;
	self = (PamacAlpmPackageStatic*) base;
	_tmp0_ = self->priv->_desc;
	result = _tmp0_;
	return result;
}

static void
pamac_alpm_package_static_real_set_desc (PamacPackage* base,
                                         const gchar* value)
{
	PamacAlpmPackageStatic* self;
	gchar* _tmp0_;
	self = (PamacAlpmPackageStatic*) base;
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_desc);
	self->priv->_desc = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_alpm_package_static_properties[PAMAC_ALPM_PACKAGE_STATIC_DESC_PROPERTY]);
}

static const gchar*
pamac_alpm_package_static_real_get_repo (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageStatic* self;
	const gchar* _tmp0_;
	self = (PamacAlpmPackageStatic*) base;
	_tmp0_ = self->priv->_repo;
	result = _tmp0_;
	return result;
}

static void
pamac_alpm_package_static_real_set_repo (PamacPackage* base,
                                         const gchar* value)
{
	PamacAlpmPackageStatic* self;
	gchar* _tmp0_;
	self = (PamacAlpmPackageStatic*) base;
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_repo);
	self->priv->_repo = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_alpm_package_static_properties[PAMAC_ALPM_PACKAGE_STATIC_REPO_PROPERTY]);
}

static const gchar*
pamac_alpm_package_static_real_get_url (PamacPackage* base)
{
	const gchar* result;
	PamacAlpmPackageStatic* self;
	const gchar* _tmp0_;
	self = (PamacAlpmPackageStatic*) base;
	_tmp0_ = self->priv->_url;
	result = _tmp0_;
	return result;
}

static const gchar*
pamac_alpm_package_static_real_get_packager (PamacAlpmPackage* base)
{
	const gchar* result;
	PamacAlpmPackageStatic* self;
	const gchar* _tmp0_;
	self = (PamacAlpmPackageStatic*) base;
	_tmp0_ = self->priv->_packager;
	result = _tmp0_;
	return result;
}

static void
pamac_alpm_package_static_class_init (PamacAlpmPackageStaticClass * klass,
                                      gpointer klass_data)
{
	pamac_alpm_package_static_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &PamacAlpmPackageStatic_private_offset);
	PAMAC_PACKAGE_CLASS (klass)->get_version = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_static_real_get_version;
	PAMAC_PACKAGE_CLASS (klass)->set_version = (void (*) (PamacPackage*, const gchar*)) pamac_alpm_package_static_real_set_version;
	PAMAC_PACKAGE_CLASS (klass)->get_installed_version = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_static_real_get_installed_version;
	PAMAC_PACKAGE_CLASS (klass)->set_installed_version = (void (*) (PamacPackage*, const gchar*)) pamac_alpm_package_static_real_set_installed_version;
	PAMAC_PACKAGE_CLASS (klass)->get_desc = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_static_real_get_desc;
	PAMAC_PACKAGE_CLASS (klass)->set_desc = (void (*) (PamacPackage*, const gchar*)) pamac_alpm_package_static_real_set_desc;
	PAMAC_PACKAGE_CLASS (klass)->get_repo = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_static_real_get_repo;
	PAMAC_PACKAGE_CLASS (klass)->set_repo = (void (*) (PamacPackage*, const gchar*)) pamac_alpm_package_static_real_set_repo;
	PAMAC_PACKAGE_CLASS (klass)->get_url = (const gchar* (*) (PamacPackage*)) pamac_alpm_package_static_real_get_url;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_packager = (const gchar* (*) (PamacAlpmPackage*)) pamac_alpm_package_static_real_get_packager;
	G_OBJECT_CLASS (klass)->get_property = _vala_pamac_alpm_package_static_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_pamac_alpm_package_static_set_property;
	G_OBJECT_CLASS (klass)->finalize = pamac_alpm_package_static_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_STATIC_VERSION_PROPERTY, pamac_alpm_package_static_properties[PAMAC_ALPM_PACKAGE_STATIC_VERSION_PROPERTY] = g_param_spec_string ("version", "version", "version", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_STATIC_INSTALLED_VERSION_PROPERTY, pamac_alpm_package_static_properties[PAMAC_ALPM_PACKAGE_STATIC_INSTALLED_VERSION_PROPERTY] = g_param_spec_string ("installed-version", "installed-version", "installed-version", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_STATIC_DESC_PROPERTY, pamac_alpm_package_static_properties[PAMAC_ALPM_PACKAGE_STATIC_DESC_PROPERTY] = g_param_spec_string ("desc", "desc", "desc", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_STATIC_REPO_PROPERTY, pamac_alpm_package_static_properties[PAMAC_ALPM_PACKAGE_STATIC_REPO_PROPERTY] = g_param_spec_string ("repo", "repo", "repo", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_STATIC_URL_PROPERTY, pamac_alpm_package_static_properties[PAMAC_ALPM_PACKAGE_STATIC_URL_PROPERTY] = g_param_spec_string ("url", "url", "url", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_ALPM_PACKAGE_STATIC_PACKAGER_PROPERTY, pamac_alpm_package_static_properties[PAMAC_ALPM_PACKAGE_STATIC_PACKAGER_PROPERTY] = g_param_spec_string ("packager", "packager", "packager", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
pamac_alpm_package_static_instance_init (PamacAlpmPackageStatic * self,
                                         gpointer klass)
{
	self->priv = pamac_alpm_package_static_get_instance_private (self);
}

static void
pamac_alpm_package_static_finalize (GObject * obj)
{
	PamacAlpmPackageStatic * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PAMAC_TYPE_ALPM_PACKAGE_STATIC, PamacAlpmPackageStatic);
	_g_free0 (self->priv->_version);
	_g_free0 (self->priv->_installed_version);
	_g_free0 (self->priv->_desc);
	_g_free0 (self->priv->_repo);
	_g_free0 (self->priv->_url);
	_g_free0 (self->priv->_packager);
	G_OBJECT_CLASS (pamac_alpm_package_static_parent_class)->finalize (obj);
}

static GType
pamac_alpm_package_static_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PamacAlpmPackageStaticClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) pamac_alpm_package_static_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PamacAlpmPackageStatic), 0, (GInstanceInitFunc) pamac_alpm_package_static_instance_init, NULL };
	GType pamac_alpm_package_static_type_id;
	pamac_alpm_package_static_type_id = g_type_register_static (PAMAC_TYPE_ALPM_PACKAGE_LINKED, "PamacAlpmPackageStatic", &g_define_type_info, 0);
	PamacAlpmPackageStatic_private_offset = g_type_add_instance_private (pamac_alpm_package_static_type_id, sizeof (PamacAlpmPackageStaticPrivate));
	return pamac_alpm_package_static_type_id;
}

GType
pamac_alpm_package_static_get_type (void)
{
	static volatile gsize pamac_alpm_package_static_type_id__once = 0;
	if (g_once_init_enter (&pamac_alpm_package_static_type_id__once)) {
		GType pamac_alpm_package_static_type_id;
		pamac_alpm_package_static_type_id = pamac_alpm_package_static_get_type_once ();
		g_once_init_leave (&pamac_alpm_package_static_type_id__once, pamac_alpm_package_static_type_id);
	}
	return pamac_alpm_package_static_type_id__once;
}

static void
_vala_pamac_alpm_package_static_get_property (GObject * object,
                                              guint property_id,
                                              GValue * value,
                                              GParamSpec * pspec)
{
	PamacAlpmPackageStatic * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_ALPM_PACKAGE_STATIC, PamacAlpmPackageStatic);
	switch (property_id) {
		case PAMAC_ALPM_PACKAGE_STATIC_VERSION_PROPERTY:
		g_value_set_string (value, pamac_package_get_version ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_STATIC_INSTALLED_VERSION_PROPERTY:
		g_value_set_string (value, pamac_package_get_installed_version ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_STATIC_DESC_PROPERTY:
		g_value_set_string (value, pamac_package_get_desc ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_STATIC_REPO_PROPERTY:
		g_value_set_string (value, pamac_package_get_repo ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_STATIC_URL_PROPERTY:
		g_value_set_string (value, pamac_package_get_url ((PamacPackage*) self));
		break;
		case PAMAC_ALPM_PACKAGE_STATIC_PACKAGER_PROPERTY:
		g_value_set_string (value, pamac_alpm_package_get_packager ((PamacAlpmPackage*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_pamac_alpm_package_static_set_property (GObject * object,
                                              guint property_id,
                                              const GValue * value,
                                              GParamSpec * pspec)
{
	PamacAlpmPackageStatic * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_ALPM_PACKAGE_STATIC, PamacAlpmPackageStatic);
	switch (property_id) {
		case PAMAC_ALPM_PACKAGE_STATIC_VERSION_PROPERTY:
		pamac_package_set_version ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_ALPM_PACKAGE_STATIC_INSTALLED_VERSION_PROPERTY:
		pamac_package_set_installed_version ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_ALPM_PACKAGE_STATIC_DESC_PROPERTY:
		pamac_package_set_desc ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_ALPM_PACKAGE_STATIC_REPO_PROPERTY:
		pamac_package_set_repo ((PamacPackage*) self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

PamacAURPackage*
pamac_aur_package_construct (GType object_type)
{
	PamacAURPackage * self = NULL;
	self = (PamacAURPackage*) pamac_alpm_package_construct (object_type);
	return self;
}

const gchar*
pamac_aur_package_get_packagebase (PamacAURPackage* self)
{
	PamacAURPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_AUR_PACKAGE_GET_CLASS (self);
	if (_klass_->get_packagebase) {
		return _klass_->get_packagebase (self);
	}
	return NULL;
}

void
pamac_aur_package_set_packagebase (PamacAURPackage* self,
                                   const gchar* value)
{
	PamacAURPackageClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = PAMAC_AUR_PACKAGE_GET_CLASS (self);
	if (_klass_->set_packagebase) {
		_klass_->set_packagebase (self, value);
	}
}

const gchar*
pamac_aur_package_get_maintainer (PamacAURPackage* self)
{
	PamacAURPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_AUR_PACKAGE_GET_CLASS (self);
	if (_klass_->get_maintainer) {
		return _klass_->get_maintainer (self);
	}
	return NULL;
}

gdouble
pamac_aur_package_get_popularity (PamacAURPackage* self)
{
	PamacAURPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, 0.0);
	_klass_ = PAMAC_AUR_PACKAGE_GET_CLASS (self);
	if (_klass_->get_popularity) {
		return _klass_->get_popularity (self);
	}
	return -1.0;
}

GDateTime*
pamac_aur_package_get_lastmodified (PamacAURPackage* self)
{
	PamacAURPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_AUR_PACKAGE_GET_CLASS (self);
	if (_klass_->get_lastmodified) {
		return _klass_->get_lastmodified (self);
	}
	return NULL;
}

GDateTime*
pamac_aur_package_get_outofdate (PamacAURPackage* self)
{
	PamacAURPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_AUR_PACKAGE_GET_CLASS (self);
	if (_klass_->get_outofdate) {
		return _klass_->get_outofdate (self);
	}
	return NULL;
}

GDateTime*
pamac_aur_package_get_firstsubmitted (PamacAURPackage* self)
{
	PamacAURPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = PAMAC_AUR_PACKAGE_GET_CLASS (self);
	if (_klass_->get_firstsubmitted) {
		return _klass_->get_firstsubmitted (self);
	}
	return NULL;
}

guint64
pamac_aur_package_get_numvotes (PamacAURPackage* self)
{
	PamacAURPackageClass* _klass_;
	g_return_val_if_fail (self != NULL, 0ULL);
	_klass_ = PAMAC_AUR_PACKAGE_GET_CLASS (self);
	if (_klass_->get_numvotes) {
		return _klass_->get_numvotes (self);
	}
	return 0ULL;
}

static void
pamac_aur_package_class_init (PamacAURPackageClass * klass,
                              gpointer klass_data)
{
	pamac_aur_package_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_pamac_aur_package_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_pamac_aur_package_set_property;
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_PACKAGEBASE_PROPERTY, pamac_aur_package_properties[PAMAC_AUR_PACKAGE_PACKAGEBASE_PROPERTY] = g_param_spec_string ("packagebase", "packagebase", "packagebase", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_MAINTAINER_PROPERTY, pamac_aur_package_properties[PAMAC_AUR_PACKAGE_MAINTAINER_PROPERTY] = g_param_spec_string ("maintainer", "maintainer", "maintainer", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_POPULARITY_PROPERTY, pamac_aur_package_properties[PAMAC_AUR_PACKAGE_POPULARITY_PROPERTY] = g_param_spec_double ("popularity", "popularity", "popularity", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LASTMODIFIED_PROPERTY, pamac_aur_package_properties[PAMAC_AUR_PACKAGE_LASTMODIFIED_PROPERTY] = g_param_spec_boxed ("lastmodified", "lastmodified", "lastmodified", G_TYPE_DATE_TIME, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_OUTOFDATE_PROPERTY, pamac_aur_package_properties[PAMAC_AUR_PACKAGE_OUTOFDATE_PROPERTY] = g_param_spec_boxed ("outofdate", "outofdate", "outofdate", G_TYPE_DATE_TIME, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_FIRSTSUBMITTED_PROPERTY, pamac_aur_package_properties[PAMAC_AUR_PACKAGE_FIRSTSUBMITTED_PROPERTY] = g_param_spec_boxed ("firstsubmitted", "firstsubmitted", "firstsubmitted", G_TYPE_DATE_TIME, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_NUMVOTES_PROPERTY, pamac_aur_package_properties[PAMAC_AUR_PACKAGE_NUMVOTES_PROPERTY] = g_param_spec_uint64 ("numvotes", "numvotes", "numvotes", 0, G_MAXUINT64, 0U, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
pamac_aur_package_instance_init (PamacAURPackage * self,
                                 gpointer klass)
{
}

static GType
pamac_aur_package_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PamacAURPackageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) pamac_aur_package_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PamacAURPackage), 0, (GInstanceInitFunc) pamac_aur_package_instance_init, NULL };
	GType pamac_aur_package_type_id;
	pamac_aur_package_type_id = g_type_register_static (PAMAC_TYPE_ALPM_PACKAGE, "PamacAURPackage", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
	return pamac_aur_package_type_id;
}

GType
pamac_aur_package_get_type (void)
{
	static volatile gsize pamac_aur_package_type_id__once = 0;
	if (g_once_init_enter (&pamac_aur_package_type_id__once)) {
		GType pamac_aur_package_type_id;
		pamac_aur_package_type_id = pamac_aur_package_get_type_once ();
		g_once_init_leave (&pamac_aur_package_type_id__once, pamac_aur_package_type_id);
	}
	return pamac_aur_package_type_id__once;
}

static void
_vala_pamac_aur_package_get_property (GObject * object,
                                      guint property_id,
                                      GValue * value,
                                      GParamSpec * pspec)
{
	PamacAURPackage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_AUR_PACKAGE, PamacAURPackage);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_pamac_aur_package_set_property (GObject * object,
                                      guint property_id,
                                      const GValue * value,
                                      GParamSpec * pspec)
{
	PamacAURPackage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_AUR_PACKAGE, PamacAURPackage);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
pamac_aur_package_linked_get_instance_private (PamacAURPackageLinked* self)
{
	return G_STRUCT_MEMBER_P (self, PamacAURPackageLinked_private_offset);
}

PamacAURPackageLinked*
pamac_aur_package_linked_construct (GType object_type)
{
	PamacAURPackageLinked * self = NULL;
	self = (PamacAURPackageLinked*) pamac_aur_package_construct (object_type);
	return self;
}

PamacAURPackageLinked*
pamac_aur_package_linked_new (void)
{
	return pamac_aur_package_linked_construct (PAMAC_TYPE_AUR_PACKAGE_LINKED);
}

void
pamac_aur_package_linked_initialise_from_aur_infos (PamacAURPackageLinked* self,
                                                    PamacAURInfos* aur_infos,
                                                    alpm_pkg_t* local_pkg,
                                                    PamacDatabase* database,
                                                    gboolean is_update)
{
	PamacAURInfos* _tmp0_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (database != NULL);
	_tmp0_ = _g_object_ref0 (aur_infos);
	_g_object_unref0 (self->priv->aur_infos);
	self->priv->aur_infos = _tmp0_;
	self->priv->local_pkg = local_pkg;
	self->priv->database = database;
	self->priv->is_update = is_update;
}

static GPtrArray*
pamac_aur_package_linked_real_get_files (PamacAlpmPackage* base)
{
	PamacAURPackageLinked * self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp9_;
	GPtrArray* result;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_files;
	if (_tmp0_ == NULL) {
		alpm_pkg_t* _tmp1_;
		_tmp1_ = self->priv->local_pkg;
		if (_tmp1_ == NULL) {
			GPtrArray* _tmp2_;
			_tmp2_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
			_g_ptr_array_unref0 (self->priv->_files);
			self->priv->_files = _tmp2_;
		} else {
			PamacDatabase* _tmp3_;
			alpm_pkg_t* _tmp4_;
			const gchar* _tmp5_;
			const gchar* _tmp6_;
			alpm_pkg_t* _tmp7_;
			GPtrArray* _tmp8_;
			_tmp3_ = self->priv->database;
			_tmp4_ = self->priv->local_pkg;
			_tmp5_ = alpm_pkg_get_name (_tmp4_);
			_tmp6_ = _tmp5_;
			_tmp7_ = self->priv->local_pkg;
			_tmp8_ = pamac_database_get_pkg_files (_tmp3_, _tmp6_, _tmp7_);
			_g_ptr_array_unref0 (self->priv->_files);
			self->priv->_files = _tmp8_;
		}
	}
	_tmp9_ = self->priv->_files;
	result = _tmp9_;
	return result;
}

static void
pamac_aur_package_linked_real_get_files_async_data_free (gpointer _data)
{
	PamacAurPackageLinkedGetFilesAsyncData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (PamacAurPackageLinkedGetFilesAsyncData, _data_);
}

static void
pamac_aur_package_linked_real_get_files_async (PamacAlpmPackage* base,
                                               GAsyncReadyCallback _callback_,
                                               gpointer _user_data_)
{
	PamacAURPackageLinked * self;
	PamacAurPackageLinkedGetFilesAsyncData* _data_;
	PamacAURPackageLinked* _tmp0_;
	self = (PamacAURPackageLinked*) base;
	_data_ = g_slice_new0 (PamacAurPackageLinkedGetFilesAsyncData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, pamac_aur_package_linked_real_get_files_async_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	pamac_aur_package_linked_real_get_files_async_co (_data_);
}

static GPtrArray*
pamac_aur_package_linked_get_files_finish (PamacAlpmPackage* base,
                                           GAsyncResult* _res_)
{
	GPtrArray* result;
	PamacAurPackageLinkedGetFilesAsyncData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
	result = _data_->result;
	_data_->result = NULL;
	return result;
}

static void
pamac_aur_package_linked_get_files_async_ready (GObject* source_object,
                                                GAsyncResult* _res_,
                                                gpointer _user_data_)
{
	PamacAurPackageLinkedGetFilesAsyncData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	pamac_aur_package_linked_real_get_files_async_co (_data_);
}

static gboolean
pamac_aur_package_linked_real_get_files_async_co (PamacAurPackageLinkedGetFilesAsyncData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = _data_->self->priv->_files;
	if (_data_->_tmp0_ == NULL) {
		_data_->_tmp1_ = _data_->self->priv->local_pkg;
		if (_data_->_tmp1_ == NULL) {
			_data_->_tmp2_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
			_g_ptr_array_unref0 (_data_->self->priv->_files);
			_data_->self->priv->_files = _data_->_tmp2_;
		} else {
			_data_->_tmp3_ = _data_->self->priv->database;
			_data_->_tmp4_ = _data_->self->priv->local_pkg;
			_data_->_tmp5_ = alpm_pkg_get_name (_data_->_tmp4_);
			_data_->_tmp6_ = _data_->_tmp5_;
			_data_->_tmp7_ = _data_->self->priv->local_pkg;
			_data_->_state_ = 1;
			pamac_database_get_pkg_files_async (_data_->_tmp3_, _data_->_tmp6_, _data_->_tmp7_, pamac_aur_package_linked_get_files_async_ready, _data_);
			return FALSE;
			_state_1:
			_data_->_tmp8_ = pamac_database_get_pkg_files_finish (_data_->_tmp3_, _data_->_res_);
			_g_ptr_array_unref0 (_data_->self->priv->_files);
			_data_->self->priv->_files = _data_->_tmp8_;
		}
	}
	_data_->_tmp9_ = _data_->self->priv->_files;
	_data_->result = _data_->_tmp9_;
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static const gchar*
pamac_aur_package_linked_real_get_name (PamacPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	const gchar* _tmp7_;
	self = (PamacAURPackageLinked*) base;
	_tmp1_ = self->priv->_name;
	if (_tmp1_ == NULL) {
		PamacAURInfos* _tmp2_;
		_tmp2_ = self->priv->aur_infos;
		_tmp0_ = _tmp2_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		PamacAURInfos* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		_tmp3_ = self->priv->aur_infos;
		_tmp4_ = pamac_aur_infos_get_name (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp6_ = g_strdup (_tmp5_);
		_g_free0 (self->priv->_name);
		self->priv->_name = _tmp6_;
	}
	_tmp7_ = self->priv->_name;
	result = _tmp7_;
	return result;
}

static void
pamac_aur_package_linked_real_set_name (PamacPackage* base,
                                        const gchar* value)
{
	PamacAURPackageLinked* self;
	gchar* _tmp0_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_name);
	self->priv->_name = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_NAME_PROPERTY]);
}

static const gchar*
pamac_aur_package_linked_real_get_id (PamacPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	const gchar* _tmp7_;
	self = (PamacAURPackageLinked*) base;
	_tmp1_ = self->priv->_id;
	if (_tmp1_ == NULL) {
		PamacAURInfos* _tmp2_;
		_tmp2_ = self->priv->aur_infos;
		_tmp0_ = _tmp2_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		PamacAURInfos* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		_tmp3_ = self->priv->aur_infos;
		_tmp4_ = pamac_aur_infos_get_name (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp6_ = g_strdup (_tmp5_);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp6_;
	}
	_tmp7_ = self->priv->_id;
	result = _tmp7_;
	return result;
}

static void
pamac_aur_package_linked_real_set_id (PamacPackage* base,
                                      const gchar* value)
{
	PamacAURPackageLinked* self;
	gchar* _tmp0_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_id);
	self->priv->_id = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_ID_PROPERTY]);
}

static const gchar*
pamac_aur_package_linked_real_get_version (PamacPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	const gchar* _tmp7_;
	self = (PamacAURPackageLinked*) base;
	_tmp1_ = self->priv->_version;
	if (_tmp1_ == NULL) {
		PamacAURInfos* _tmp2_;
		_tmp2_ = self->priv->aur_infos;
		_tmp0_ = _tmp2_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		PamacAURInfos* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		_tmp3_ = self->priv->aur_infos;
		_tmp4_ = pamac_aur_infos_get_version (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp6_ = g_strdup (_tmp5_);
		_g_free0 (self->priv->_version);
		self->priv->_version = _tmp6_;
	}
	_tmp7_ = self->priv->_version;
	result = _tmp7_;
	return result;
}

static void
pamac_aur_package_linked_real_set_version (PamacPackage* base,
                                           const gchar* value)
{
	PamacAURPackageLinked* self;
	gchar* _tmp0_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_version);
	self->priv->_version = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_VERSION_PROPERTY]);
}

static const gchar*
pamac_aur_package_linked_real_get_installed_version (PamacPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	const gchar* _tmp4_;
	self = (PamacAURPackageLinked*) base;
	if (!self->priv->installed_version_set) {
		alpm_pkg_t* _tmp0_;
		self->priv->installed_version_set = TRUE;
		_tmp0_ = self->priv->local_pkg;
		if (_tmp0_ != NULL) {
			alpm_pkg_t* _tmp1_;
			const gchar* _tmp2_;
			const gchar* _tmp3_;
			_tmp1_ = self->priv->local_pkg;
			_tmp2_ = alpm_pkg_get_version (_tmp1_);
			_tmp3_ = _tmp2_;
			self->priv->_installed_version = _tmp3_;
		}
	}
	_tmp4_ = self->priv->_installed_version;
	result = _tmp4_;
	return result;
}

static void
pamac_aur_package_linked_real_set_installed_version (PamacPackage* base,
                                                     const gchar* value)
{
	PamacAURPackageLinked* self;
	self = (PamacAURPackageLinked*) base;
	self->priv->_installed_version = value;
	g_object_notify_by_pspec ((GObject *) self, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_INSTALLED_VERSION_PROPERTY]);
}

static const gchar*
pamac_aur_package_linked_real_get_desc (PamacPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	const gchar* _tmp0_;
	const gchar* _tmp10_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_desc;
	if (_tmp0_ == NULL) {
		gboolean _tmp1_ = FALSE;
		if (!self->priv->is_update) {
			alpm_pkg_t* _tmp2_;
			_tmp2_ = self->priv->local_pkg;
			_tmp1_ = _tmp2_ != NULL;
		} else {
			_tmp1_ = FALSE;
		}
		if (_tmp1_) {
			alpm_pkg_t* _tmp3_;
			const gchar* _tmp4_;
			const gchar* _tmp5_;
			_tmp3_ = self->priv->local_pkg;
			_tmp4_ = alpm_pkg_get_desc (_tmp3_);
			_tmp5_ = _tmp4_;
			self->priv->_desc = _tmp5_;
		} else {
			PamacAURInfos* _tmp6_;
			_tmp6_ = self->priv->aur_infos;
			if (_tmp6_ != NULL) {
				PamacAURInfos* _tmp7_;
				const gchar* _tmp8_;
				const gchar* _tmp9_;
				_tmp7_ = self->priv->aur_infos;
				_tmp8_ = pamac_aur_infos_get_desc (_tmp7_);
				_tmp9_ = _tmp8_;
				self->priv->_desc = _tmp9_;
			}
		}
	}
	_tmp10_ = self->priv->_desc;
	result = _tmp10_;
	return result;
}

static void
pamac_aur_package_linked_real_set_desc (PamacPackage* base,
                                        const gchar* value)
{
	PamacAURPackageLinked* self;
	self = (PamacAURPackageLinked*) base;
	self->priv->_desc = value;
	g_object_notify_by_pspec ((GObject *) self, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_DESC_PROPERTY]);
}

static const gchar*
pamac_aur_package_linked_real_get_repo (PamacPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_repo;
	if (_tmp0_ == NULL) {
		self->priv->_repo = g_dgettext (NULL, "AUR");
	}
	_tmp1_ = self->priv->_repo;
	result = _tmp1_;
	return result;
}

static void
pamac_aur_package_linked_real_set_repo (PamacPackage* base,
                                        const gchar* value)
{
	PamacAURPackageLinked* self;
	self = (PamacAURPackageLinked*) base;
	self->priv->_repo = value;
	g_object_notify_by_pspec ((GObject *) self, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_REPO_PROPERTY]);
}

static const gchar*
pamac_aur_package_linked_real_get_license (PamacPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	const gchar* _tmp24_;
	self = (PamacAURPackageLinked*) base;
	_tmp1_ = self->priv->_license;
	if (_tmp1_ == NULL) {
		_tmp0_ = !self->priv->license_set;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		gboolean _tmp2_ = FALSE;
		self->priv->license_set = TRUE;
		if (!self->priv->is_update) {
			alpm_pkg_t* _tmp3_;
			_tmp3_ = self->priv->local_pkg;
			_tmp2_ = _tmp3_ != NULL;
		} else {
			_tmp2_ = FALSE;
		}
		if (_tmp2_) {
			alpm_list_t* list = NULL;
			alpm_pkg_t* _tmp4_;
			alpm_list_t* _tmp5_;
			alpm_list_t* _tmp6_;
			alpm_list_t* _tmp7_;
			_tmp4_ = self->priv->local_pkg;
			_tmp5_ = alpm_pkg_get_licenses (_tmp4_);
			_tmp6_ = _tmp5_;
			list = _tmp6_;
			_tmp7_ = list;
			if (_tmp7_ != NULL) {
				GString* license_str = NULL;
				alpm_list_t* _tmp8_;
				gconstpointer _tmp9_;
				GString* _tmp10_;
				GString* _tmp16_;
				gchar* _tmp17_;
				_tmp8_ = list;
				_tmp9_ = _tmp8_->data;
				_tmp10_ = g_string_new ((const gchar*) _tmp9_);
				license_str = _tmp10_;
				list = alpm_list_next (list);
				while (TRUE) {
					alpm_list_t* _tmp11_;
					GString* _tmp12_;
					GString* _tmp13_;
					alpm_list_t* _tmp14_;
					gconstpointer _tmp15_;
					_tmp11_ = list;
					if (!(_tmp11_ != NULL)) {
						break;
					}
					_tmp12_ = license_str;
					g_string_append (_tmp12_, " ");
					_tmp13_ = license_str;
					_tmp14_ = list;
					_tmp15_ = _tmp14_->data;
					g_string_append (_tmp13_, (const gchar*) _tmp15_);
					list = alpm_list_next (list);
				}
				_tmp16_ = license_str;
				_tmp17_ = _tmp16_->str;
				_tmp16_->str = NULL;
				_g_free0 (self->priv->_license);
				self->priv->_license = _tmp17_;
				_g_string_free0 (license_str);
			} else {
				gchar* _tmp18_;
				_tmp18_ = g_strdup (g_dgettext (NULL, "Unknown"));
				_g_free0 (self->priv->_license);
				self->priv->_license = _tmp18_;
			}
		} else {
			PamacAURInfos* _tmp19_;
			_tmp19_ = self->priv->aur_infos;
			if (_tmp19_ != NULL) {
				PamacAURInfos* _tmp20_;
				const gchar* _tmp21_;
				const gchar* _tmp22_;
				gchar* _tmp23_;
				_tmp20_ = self->priv->aur_infos;
				_tmp21_ = pamac_aur_infos_get_license (_tmp20_);
				_tmp22_ = _tmp21_;
				_tmp23_ = g_strdup (_tmp22_);
				_g_free0 (self->priv->_license);
				self->priv->_license = _tmp23_;
			}
		}
	}
	_tmp24_ = self->priv->_license;
	result = _tmp24_;
	return result;
}

static const gchar*
pamac_aur_package_linked_real_get_url (PamacPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	const gchar* _tmp0_;
	const gchar* _tmp10_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_url;
	if (_tmp0_ == NULL) {
		gboolean _tmp1_ = FALSE;
		if (!self->priv->is_update) {
			alpm_pkg_t* _tmp2_;
			_tmp2_ = self->priv->local_pkg;
			_tmp1_ = _tmp2_ != NULL;
		} else {
			_tmp1_ = FALSE;
		}
		if (_tmp1_) {
			alpm_pkg_t* _tmp3_;
			const gchar* _tmp4_;
			const gchar* _tmp5_;
			_tmp3_ = self->priv->local_pkg;
			_tmp4_ = alpm_pkg_get_url (_tmp3_);
			_tmp5_ = _tmp4_;
			self->priv->_url = _tmp5_;
		} else {
			PamacAURInfos* _tmp6_;
			_tmp6_ = self->priv->aur_infos;
			if (_tmp6_ != NULL) {
				PamacAURInfos* _tmp7_;
				const gchar* _tmp8_;
				const gchar* _tmp9_;
				_tmp7_ = self->priv->aur_infos;
				_tmp8_ = pamac_aur_infos_get_url (_tmp7_);
				_tmp9_ = _tmp8_;
				self->priv->_url = _tmp9_;
			}
		}
	}
	_tmp10_ = self->priv->_url;
	result = _tmp10_;
	return result;
}

static guint64
pamac_aur_package_linked_real_get_installed_size (PamacPackage* base)
{
	guint64 result;
	PamacAURPackageLinked* self;
	self = (PamacAURPackageLinked*) base;
	if (!self->priv->installed_size_set) {
		alpm_pkg_t* _tmp0_;
		self->priv->installed_size_set = TRUE;
		_tmp0_ = self->priv->local_pkg;
		if (_tmp0_ != NULL) {
			alpm_pkg_t* _tmp1_;
			guint64 _tmp2_;
			guint64 _tmp3_;
			_tmp1_ = self->priv->local_pkg;
			_tmp2_ = alpm_pkg_get_isize (_tmp1_);
			_tmp3_ = _tmp2_;
			self->priv->_installed_size = _tmp3_;
		}
	}
	result = self->priv->_installed_size;
	return result;
}

static guint64
pamac_aur_package_linked_real_get_download_size (PamacPackage* base)
{
	guint64 result;
	PamacAURPackageLinked* self;
	self = (PamacAURPackageLinked*) base;
	if (!self->priv->download_size_set) {
		alpm_pkg_t* _tmp0_;
		self->priv->download_size_set = TRUE;
		_tmp0_ = self->priv->local_pkg;
		if (_tmp0_ != NULL) {
			alpm_pkg_t* _tmp1_;
			guint64 _tmp2_;
			guint64 _tmp3_;
			_tmp1_ = self->priv->local_pkg;
			_tmp2_ = alpm_pkg_download_size (_tmp1_);
			_tmp3_ = _tmp2_;
			self->priv->_download_size = _tmp3_;
		}
	}
	result = self->priv->_download_size;
	return result;
}

static GDateTime*
pamac_aur_package_linked_real_get_install_date (PamacPackage* base)
{
	GDateTime* result;
	PamacAURPackageLinked* self;
	GDateTime* _tmp5_;
	self = (PamacAURPackageLinked*) base;
	if (!self->priv->install_date_set) {
		alpm_pkg_t* _tmp0_;
		self->priv->install_date_set = TRUE;
		_tmp0_ = self->priv->local_pkg;
		if (_tmp0_ != NULL) {
			alpm_pkg_t* _tmp1_;
			alpm_time_t _tmp2_;
			alpm_time_t _tmp3_;
			GDateTime* _tmp4_;
			_tmp1_ = self->priv->local_pkg;
			_tmp2_ = alpm_pkg_get_installdate (_tmp1_);
			_tmp3_ = _tmp2_;
			_tmp4_ = g_date_time_new_from_unix_local ((gint64) _tmp3_);
			_g_date_time_unref0 (self->priv->_install_date);
			self->priv->_install_date = _tmp4_;
		}
	}
	_tmp5_ = self->priv->_install_date;
	result = _tmp5_;
	return result;
}

static const gchar*
pamac_aur_package_linked_real_get_app_name (PamacPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	self = (PamacAURPackageLinked*) base;
	result = NULL;
	return result;
}

static const gchar*
pamac_aur_package_linked_real_get_app_id (PamacPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	self = (PamacAURPackageLinked*) base;
	result = NULL;
	return result;
}

static const gchar*
pamac_aur_package_linked_real_get_long_desc (PamacPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	self = (PamacAURPackageLinked*) base;
	result = NULL;
	return result;
}

static const gchar*
pamac_aur_package_linked_real_get_launchable (PamacPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	self = (PamacAURPackageLinked*) base;
	result = NULL;
	return result;
}

static const gchar*
pamac_aur_package_linked_real_get_icon (PamacPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	self = (PamacAURPackageLinked*) base;
	result = NULL;
	return result;
}

static GPtrArray*
pamac_aur_package_linked_real_get_screenshots (PamacPackage* base)
{
	GPtrArray* result;
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp2_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_screenshots;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_screenshots);
		self->priv->_screenshots = _tmp1_;
	}
	_tmp2_ = self->priv->_screenshots;
	result = _tmp2_;
	return result;
}

static GDateTime*
pamac_aur_package_linked_real_get_build_date (PamacAlpmPackage* base)
{
	GDateTime* result;
	PamacAURPackageLinked* self;
	GDateTime* _tmp5_;
	self = (PamacAURPackageLinked*) base;
	if (!self->priv->build_date_set) {
		alpm_pkg_t* _tmp0_;
		self->priv->build_date_set = TRUE;
		_tmp0_ = self->priv->local_pkg;
		if (_tmp0_ != NULL) {
			alpm_pkg_t* _tmp1_;
			alpm_time_t _tmp2_;
			alpm_time_t _tmp3_;
			GDateTime* _tmp4_;
			_tmp1_ = self->priv->local_pkg;
			_tmp2_ = alpm_pkg_get_builddate (_tmp1_);
			_tmp3_ = _tmp2_;
			_tmp4_ = g_date_time_new_from_unix_local ((gint64) _tmp3_);
			_g_date_time_unref0 (self->priv->_build_date);
			self->priv->_build_date = _tmp4_;
		}
	}
	_tmp5_ = self->priv->_build_date;
	result = _tmp5_;
	return result;
}

static const gchar*
pamac_aur_package_linked_real_get_packager (PamacAlpmPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	const gchar* _tmp4_;
	self = (PamacAURPackageLinked*) base;
	if (!self->priv->packager_set) {
		alpm_pkg_t* _tmp0_;
		self->priv->packager_set = TRUE;
		_tmp0_ = self->priv->local_pkg;
		if (_tmp0_ != NULL) {
			alpm_pkg_t* _tmp1_;
			const gchar* _tmp2_;
			const gchar* _tmp3_;
			_tmp1_ = self->priv->local_pkg;
			_tmp2_ = alpm_pkg_get_packager (_tmp1_);
			_tmp3_ = _tmp2_;
			self->priv->_packager = _tmp3_;
		}
	}
	_tmp4_ = self->priv->_packager;
	result = _tmp4_;
	return result;
}

static const gchar*
pamac_aur_package_linked_real_get_reason (PamacAlpmPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	const gchar* _tmp7_;
	self = (PamacAURPackageLinked*) base;
	if (!self->priv->reason_set) {
		alpm_pkg_t* _tmp0_;
		self->priv->reason_set = TRUE;
		_tmp0_ = self->priv->local_pkg;
		if (_tmp0_ != NULL) {
			alpm_pkg_t* _tmp1_;
			alpm_pkgreason_t _tmp2_;
			alpm_pkgreason_t _tmp3_;
			_tmp1_ = self->priv->local_pkg;
			_tmp2_ = alpm_pkg_get_reason (_tmp1_);
			_tmp3_ = _tmp2_;
			if (_tmp3_ == ALPM_PKG_REASON_EXPLICIT) {
				self->priv->_reason = g_dgettext (NULL, "Explicitly installed");
			} else {
				alpm_pkg_t* _tmp4_;
				alpm_pkgreason_t _tmp5_;
				alpm_pkgreason_t _tmp6_;
				_tmp4_ = self->priv->local_pkg;
				_tmp5_ = alpm_pkg_get_reason (_tmp4_);
				_tmp6_ = _tmp5_;
				if (_tmp6_ == ALPM_PKG_REASON_DEPEND) {
					self->priv->_reason = g_dgettext (NULL, "Installed as a dependency for another package");
				}
			}
		}
	}
	_tmp7_ = self->priv->_reason;
	result = _tmp7_;
	return result;
}

static GPtrArray*
pamac_aur_package_linked_real_get_validations (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp18_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_validations;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		alpm_pkg_t* _tmp2_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_validations);
		self->priv->_validations = _tmp1_;
		_tmp2_ = self->priv->local_pkg;
		if (_tmp2_ != NULL) {
			alpm_pkgvalidation_t validation = 0;
			alpm_pkg_t* _tmp3_;
			alpm_pkgvalidation_t _tmp4_;
			alpm_pkgvalidation_t _tmp5_;
			_tmp3_ = self->priv->local_pkg;
			_tmp4_ = alpm_pkg_get_validation (_tmp3_);
			_tmp5_ = _tmp4_;
			validation = _tmp5_;
			if (validation != 0) {
				if ((validation & ALPM_PKG_VALIDATION_NONE) != 0) {
					GPtrArray* _tmp6_;
					gchar* _tmp7_;
					_tmp6_ = self->priv->_validations;
					_tmp7_ = g_strdup (g_dgettext (NULL, "None"));
					g_ptr_array_add (_tmp6_, _tmp7_);
				} else {
					if ((validation & ALPM_PKG_VALIDATION_MD5SUM) != 0) {
						GPtrArray* _tmp8_;
						gchar* _tmp9_;
						_tmp8_ = self->priv->_validations;
						_tmp9_ = g_strdup (g_dgettext (NULL, "MD5 Sum"));
						g_ptr_array_add (_tmp8_, _tmp9_);
					}
					if ((validation & ALPM_PKG_VALIDATION_SHA256SUM) != 0) {
						GPtrArray* _tmp10_;
						gchar* _tmp11_;
						_tmp10_ = self->priv->_validations;
						_tmp11_ = g_strdup (g_dgettext (NULL, "SHA-256 Sum"));
						g_ptr_array_add (_tmp10_, _tmp11_);
					}
					if ((validation & ALPM_PKG_VALIDATION_SIGNATURE) != 0) {
						GPtrArray* _tmp12_;
						gchar* _tmp13_;
						_tmp12_ = self->priv->_validations;
						_tmp13_ = g_strdup (g_dgettext (NULL, "Signature"));
						g_ptr_array_add (_tmp12_, _tmp13_);
					}
				}
			} else {
				GPtrArray* _tmp14_;
				gchar* _tmp15_;
				_tmp14_ = self->priv->_validations;
				_tmp15_ = g_strdup (g_dgettext (NULL, "Unknown"));
				g_ptr_array_add (_tmp14_, _tmp15_);
			}
		} else {
			GPtrArray* _tmp16_;
			gchar* _tmp17_;
			_tmp16_ = self->priv->_validations;
			_tmp17_ = g_strdup (g_dgettext (NULL, "Unknown"));
			g_ptr_array_add (_tmp16_, _tmp17_);
		}
	}
	_tmp18_ = self->priv->_validations;
	result = _tmp18_;
	return result;
}

static GPtrArray*
pamac_aur_package_linked_real_get_groups (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp17_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_groups;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		gboolean _tmp2_ = FALSE;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_groups);
		self->priv->_groups = _tmp1_;
		if (!self->priv->is_update) {
			alpm_pkg_t* _tmp3_;
			_tmp3_ = self->priv->local_pkg;
			_tmp2_ = _tmp3_ != NULL;
		} else {
			_tmp2_ = FALSE;
		}
		if (_tmp2_) {
			alpm_list_t* list = NULL;
			alpm_pkg_t* _tmp4_;
			alpm_list_t* _tmp5_;
			alpm_list_t* _tmp6_;
			_tmp4_ = self->priv->local_pkg;
			_tmp5_ = alpm_pkg_get_groups (_tmp4_);
			_tmp6_ = _tmp5_;
			list = _tmp6_;
			while (TRUE) {
				alpm_list_t* _tmp7_;
				GPtrArray* _tmp8_;
				alpm_list_t* _tmp9_;
				gconstpointer _tmp10_;
				gchar* _tmp11_;
				_tmp7_ = list;
				if (!(_tmp7_ != NULL)) {
					break;
				}
				_tmp8_ = self->priv->_groups;
				_tmp9_ = list;
				_tmp10_ = _tmp9_->data;
				_tmp11_ = g_strdup ((const gchar*) _tmp10_);
				g_ptr_array_add (_tmp8_, _tmp11_);
				list = alpm_list_next (list);
			}
		} else {
			PamacAURInfos* _tmp12_;
			_tmp12_ = self->priv->aur_infos;
			if (_tmp12_ != NULL) {
				PamacAURInfos* _tmp13_;
				GPtrArray* _tmp14_;
				GPtrArray* _tmp15_;
				GPtrArray* _tmp16_;
				_tmp13_ = self->priv->aur_infos;
				_tmp14_ = pamac_aur_infos_get_groups (_tmp13_);
				_tmp15_ = _tmp14_;
				_tmp16_ = _g_ptr_array_ref0 (_tmp15_);
				_g_ptr_array_unref0 (self->priv->_groups);
				self->priv->_groups = _tmp16_;
			}
		}
	}
	_tmp17_ = self->priv->_groups;
	result = _tmp17_;
	return result;
}

static GPtrArray*
pamac_aur_package_linked_real_get_depends (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp17_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_depends;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		gboolean _tmp2_ = FALSE;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_depends);
		self->priv->_depends = _tmp1_;
		if (!self->priv->is_update) {
			alpm_pkg_t* _tmp3_;
			_tmp3_ = self->priv->local_pkg;
			_tmp2_ = _tmp3_ != NULL;
		} else {
			_tmp2_ = FALSE;
		}
		if (_tmp2_) {
			alpm_list_t* list = NULL;
			alpm_pkg_t* _tmp4_;
			alpm_list_t* _tmp5_;
			alpm_list_t* _tmp6_;
			_tmp4_ = self->priv->local_pkg;
			_tmp5_ = alpm_pkg_get_depends (_tmp4_);
			_tmp6_ = _tmp5_;
			list = _tmp6_;
			while (TRUE) {
				alpm_list_t* _tmp7_;
				GPtrArray* _tmp8_;
				alpm_list_t* _tmp9_;
				gconstpointer _tmp10_;
				gchar* _tmp11_;
				_tmp7_ = list;
				if (!(_tmp7_ != NULL)) {
					break;
				}
				_tmp8_ = self->priv->_depends;
				_tmp9_ = list;
				_tmp10_ = _tmp9_->data;
				_tmp11_ = alpm_dep_compute_string ((alpm_depend_t*) _tmp10_);
				g_ptr_array_add (_tmp8_, _tmp11_);
				list = alpm_list_next (list);
			}
		} else {
			PamacAURInfos* _tmp12_;
			_tmp12_ = self->priv->aur_infos;
			if (_tmp12_ != NULL) {
				PamacAURInfos* _tmp13_;
				GPtrArray* _tmp14_;
				GPtrArray* _tmp15_;
				GPtrArray* _tmp16_;
				_tmp13_ = self->priv->aur_infos;
				_tmp14_ = pamac_aur_infos_get_depends (_tmp13_);
				_tmp15_ = _tmp14_;
				_tmp16_ = _g_ptr_array_ref0 (_tmp15_);
				_g_ptr_array_unref0 (self->priv->_depends);
				self->priv->_depends = _tmp16_;
			}
		}
	}
	_tmp17_ = self->priv->_depends;
	result = _tmp17_;
	return result;
}

static void
pamac_aur_package_linked_real_set_depends (PamacAlpmPackage* base,
                                           GPtrArray* value)
{
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = _g_ptr_array_ref0 (value);
	_g_ptr_array_unref0 (self->priv->_depends);
	self->priv->_depends = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_DEPENDS_PROPERTY]);
}

static GPtrArray*
pamac_aur_package_linked_real_get_optdepends (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp17_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_optdepends;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		gboolean _tmp2_ = FALSE;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_optdepends);
		self->priv->_optdepends = _tmp1_;
		if (!self->priv->is_update) {
			alpm_pkg_t* _tmp3_;
			_tmp3_ = self->priv->local_pkg;
			_tmp2_ = _tmp3_ != NULL;
		} else {
			_tmp2_ = FALSE;
		}
		if (_tmp2_) {
			alpm_list_t* list = NULL;
			alpm_pkg_t* _tmp4_;
			alpm_list_t* _tmp5_;
			alpm_list_t* _tmp6_;
			_tmp4_ = self->priv->local_pkg;
			_tmp5_ = alpm_pkg_get_optdepends (_tmp4_);
			_tmp6_ = _tmp5_;
			list = _tmp6_;
			while (TRUE) {
				alpm_list_t* _tmp7_;
				GPtrArray* _tmp8_;
				alpm_list_t* _tmp9_;
				gconstpointer _tmp10_;
				gchar* _tmp11_;
				_tmp7_ = list;
				if (!(_tmp7_ != NULL)) {
					break;
				}
				_tmp8_ = self->priv->_optdepends;
				_tmp9_ = list;
				_tmp10_ = _tmp9_->data;
				_tmp11_ = alpm_dep_compute_string ((alpm_depend_t*) _tmp10_);
				g_ptr_array_add (_tmp8_, _tmp11_);
				list = alpm_list_next (list);
			}
		} else {
			PamacAURInfos* _tmp12_;
			_tmp12_ = self->priv->aur_infos;
			if (_tmp12_ != NULL) {
				PamacAURInfos* _tmp13_;
				GPtrArray* _tmp14_;
				GPtrArray* _tmp15_;
				GPtrArray* _tmp16_;
				_tmp13_ = self->priv->aur_infos;
				_tmp14_ = pamac_aur_infos_get_optdepends (_tmp13_);
				_tmp15_ = _tmp14_;
				_tmp16_ = _g_ptr_array_ref0 (_tmp15_);
				_g_ptr_array_unref0 (self->priv->_optdepends);
				self->priv->_optdepends = _tmp16_;
			}
		}
	}
	_tmp17_ = self->priv->_optdepends;
	result = _tmp17_;
	return result;
}

static GPtrArray*
pamac_aur_package_linked_real_get_makedepends (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp7_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_makedepends;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		PamacAURInfos* _tmp2_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_makedepends);
		self->priv->_makedepends = _tmp1_;
		_tmp2_ = self->priv->aur_infos;
		if (_tmp2_ != NULL) {
			PamacAURInfos* _tmp3_;
			GPtrArray* _tmp4_;
			GPtrArray* _tmp5_;
			GPtrArray* _tmp6_;
			_tmp3_ = self->priv->aur_infos;
			_tmp4_ = pamac_aur_infos_get_makedepends (_tmp3_);
			_tmp5_ = _tmp4_;
			_tmp6_ = _g_ptr_array_ref0 (_tmp5_);
			_g_ptr_array_unref0 (self->priv->_makedepends);
			self->priv->_makedepends = _tmp6_;
		}
	}
	_tmp7_ = self->priv->_makedepends;
	result = _tmp7_;
	return result;
}

static GPtrArray*
pamac_aur_package_linked_real_get_checkdepends (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp7_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_checkdepends;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		PamacAURInfos* _tmp2_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_checkdepends);
		self->priv->_checkdepends = _tmp1_;
		_tmp2_ = self->priv->aur_infos;
		if (_tmp2_ != NULL) {
			PamacAURInfos* _tmp3_;
			GPtrArray* _tmp4_;
			GPtrArray* _tmp5_;
			GPtrArray* _tmp6_;
			_tmp3_ = self->priv->aur_infos;
			_tmp4_ = pamac_aur_infos_get_checkdepends (_tmp3_);
			_tmp5_ = _tmp4_;
			_tmp6_ = _g_ptr_array_ref0 (_tmp5_);
			_g_ptr_array_unref0 (self->priv->_checkdepends);
			self->priv->_checkdepends = _tmp6_;
		}
	}
	_tmp7_ = self->priv->_checkdepends;
	result = _tmp7_;
	return result;
}

static GPtrArray*
pamac_aur_package_linked_real_get_requiredby (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp11_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_requiredby;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		gboolean _tmp2_ = FALSE;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_requiredby);
		self->priv->_requiredby = _tmp1_;
		if (!self->priv->is_update) {
			alpm_pkg_t* _tmp3_;
			_tmp3_ = self->priv->local_pkg;
			_tmp2_ = _tmp3_ != NULL;
		} else {
			_tmp2_ = FALSE;
		}
		if (_tmp2_) {
			alpm_list_t* owned_list = NULL;
			alpm_pkg_t* _tmp4_;
			alpm_list_t* _tmp5_;
			alpm_list_t* list = NULL;
			alpm_list_t* _tmp6_;
			_tmp4_ = self->priv->local_pkg;
			_tmp5_ = alpm_pkg_compute_requiredby (_tmp4_);
			owned_list = _tmp5_;
			_tmp6_ = owned_list;
			list = _tmp6_;
			while (TRUE) {
				alpm_list_t* _tmp7_;
				GPtrArray* _tmp8_;
				alpm_list_t* _tmp9_;
				gpointer _tmp10_;
				_tmp7_ = list;
				if (!(_tmp7_ != NULL)) {
					break;
				}
				_tmp8_ = self->priv->_requiredby;
				_tmp9_ = list;
				_tmp10_ = _tmp9_->data;
				_tmp9_->data = NULL;
				g_ptr_array_add (_tmp8_, (gchar*) _tmp10_);
				list = alpm_list_next (list);
			}
			_alpm_list_free0 (owned_list);
		}
	}
	_tmp11_ = self->priv->_requiredby;
	result = _tmp11_;
	return result;
}

static GPtrArray*
pamac_aur_package_linked_real_get_optionalfor (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp11_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_optionalfor;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		gboolean _tmp2_ = FALSE;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_optionalfor);
		self->priv->_optionalfor = _tmp1_;
		if (!self->priv->is_update) {
			alpm_pkg_t* _tmp3_;
			_tmp3_ = self->priv->local_pkg;
			_tmp2_ = _tmp3_ != NULL;
		} else {
			_tmp2_ = FALSE;
		}
		if (_tmp2_) {
			alpm_list_t* owned_list = NULL;
			alpm_pkg_t* _tmp4_;
			alpm_list_t* _tmp5_;
			alpm_list_t* list = NULL;
			alpm_list_t* _tmp6_;
			_tmp4_ = self->priv->local_pkg;
			_tmp5_ = alpm_pkg_compute_optionalfor (_tmp4_);
			owned_list = _tmp5_;
			_tmp6_ = owned_list;
			list = _tmp6_;
			while (TRUE) {
				alpm_list_t* _tmp7_;
				GPtrArray* _tmp8_;
				alpm_list_t* _tmp9_;
				gpointer _tmp10_;
				_tmp7_ = list;
				if (!(_tmp7_ != NULL)) {
					break;
				}
				_tmp8_ = self->priv->_optionalfor;
				_tmp9_ = list;
				_tmp10_ = _tmp9_->data;
				_tmp9_->data = NULL;
				g_ptr_array_add (_tmp8_, (gchar*) _tmp10_);
				list = alpm_list_next (list);
			}
			_alpm_list_free0 (owned_list);
		}
	}
	_tmp11_ = self->priv->_optionalfor;
	result = _tmp11_;
	return result;
}

static GPtrArray*
pamac_aur_package_linked_real_get_provides (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp17_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_provides;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		gboolean _tmp2_ = FALSE;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_provides);
		self->priv->_provides = _tmp1_;
		if (!self->priv->is_update) {
			alpm_pkg_t* _tmp3_;
			_tmp3_ = self->priv->local_pkg;
			_tmp2_ = _tmp3_ != NULL;
		} else {
			_tmp2_ = FALSE;
		}
		if (_tmp2_) {
			alpm_list_t* list = NULL;
			alpm_pkg_t* _tmp4_;
			alpm_list_t* _tmp5_;
			alpm_list_t* _tmp6_;
			_tmp4_ = self->priv->local_pkg;
			_tmp5_ = alpm_pkg_get_provides (_tmp4_);
			_tmp6_ = _tmp5_;
			list = _tmp6_;
			while (TRUE) {
				alpm_list_t* _tmp7_;
				GPtrArray* _tmp8_;
				alpm_list_t* _tmp9_;
				gconstpointer _tmp10_;
				gchar* _tmp11_;
				_tmp7_ = list;
				if (!(_tmp7_ != NULL)) {
					break;
				}
				_tmp8_ = self->priv->_provides;
				_tmp9_ = list;
				_tmp10_ = _tmp9_->data;
				_tmp11_ = alpm_dep_compute_string ((alpm_depend_t*) _tmp10_);
				g_ptr_array_add (_tmp8_, _tmp11_);
				list = alpm_list_next (list);
			}
		} else {
			PamacAURInfos* _tmp12_;
			_tmp12_ = self->priv->aur_infos;
			if (_tmp12_ != NULL) {
				PamacAURInfos* _tmp13_;
				GPtrArray* _tmp14_;
				GPtrArray* _tmp15_;
				GPtrArray* _tmp16_;
				_tmp13_ = self->priv->aur_infos;
				_tmp14_ = pamac_aur_infos_get_provides (_tmp13_);
				_tmp15_ = _tmp14_;
				_tmp16_ = _g_ptr_array_ref0 (_tmp15_);
				_g_ptr_array_unref0 (self->priv->_provides);
				self->priv->_provides = _tmp16_;
			}
		}
	}
	_tmp17_ = self->priv->_provides;
	result = _tmp17_;
	return result;
}

static void
pamac_aur_package_linked_real_set_provides (PamacAlpmPackage* base,
                                            GPtrArray* value)
{
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = _g_ptr_array_ref0 (value);
	_g_ptr_array_unref0 (self->priv->_provides);
	self->priv->_provides = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_PROVIDES_PROPERTY]);
}

static GPtrArray*
pamac_aur_package_linked_real_get_replaces (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp17_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_replaces;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		gboolean _tmp2_ = FALSE;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_replaces);
		self->priv->_replaces = _tmp1_;
		if (!self->priv->is_update) {
			alpm_pkg_t* _tmp3_;
			_tmp3_ = self->priv->local_pkg;
			_tmp2_ = _tmp3_ != NULL;
		} else {
			_tmp2_ = FALSE;
		}
		if (_tmp2_) {
			alpm_list_t* list = NULL;
			alpm_pkg_t* _tmp4_;
			alpm_list_t* _tmp5_;
			alpm_list_t* _tmp6_;
			_tmp4_ = self->priv->local_pkg;
			_tmp5_ = alpm_pkg_get_replaces (_tmp4_);
			_tmp6_ = _tmp5_;
			list = _tmp6_;
			while (TRUE) {
				alpm_list_t* _tmp7_;
				GPtrArray* _tmp8_;
				alpm_list_t* _tmp9_;
				gconstpointer _tmp10_;
				gchar* _tmp11_;
				_tmp7_ = list;
				if (!(_tmp7_ != NULL)) {
					break;
				}
				_tmp8_ = self->priv->_replaces;
				_tmp9_ = list;
				_tmp10_ = _tmp9_->data;
				_tmp11_ = alpm_dep_compute_string ((alpm_depend_t*) _tmp10_);
				g_ptr_array_add (_tmp8_, _tmp11_);
				list = alpm_list_next (list);
			}
		} else {
			PamacAURInfos* _tmp12_;
			_tmp12_ = self->priv->aur_infos;
			if (_tmp12_ != NULL) {
				PamacAURInfos* _tmp13_;
				GPtrArray* _tmp14_;
				GPtrArray* _tmp15_;
				GPtrArray* _tmp16_;
				_tmp13_ = self->priv->aur_infos;
				_tmp14_ = pamac_aur_infos_get_replaces (_tmp13_);
				_tmp15_ = _tmp14_;
				_tmp16_ = _g_ptr_array_ref0 (_tmp15_);
				_g_ptr_array_unref0 (self->priv->_replaces);
				self->priv->_replaces = _tmp16_;
			}
		}
	}
	_tmp17_ = self->priv->_replaces;
	result = _tmp17_;
	return result;
}

static void
pamac_aur_package_linked_real_set_replaces (PamacAlpmPackage* base,
                                            GPtrArray* value)
{
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = _g_ptr_array_ref0 (value);
	_g_ptr_array_unref0 (self->priv->_replaces);
	self->priv->_replaces = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_REPLACES_PROPERTY]);
}

static GPtrArray*
pamac_aur_package_linked_real_get_conflicts (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp17_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_conflicts;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		gboolean _tmp2_ = FALSE;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_conflicts);
		self->priv->_conflicts = _tmp1_;
		if (!self->priv->is_update) {
			alpm_pkg_t* _tmp3_;
			_tmp3_ = self->priv->local_pkg;
			_tmp2_ = _tmp3_ != NULL;
		} else {
			_tmp2_ = FALSE;
		}
		if (_tmp2_) {
			alpm_list_t* list = NULL;
			alpm_pkg_t* _tmp4_;
			alpm_list_t* _tmp5_;
			alpm_list_t* _tmp6_;
			_tmp4_ = self->priv->local_pkg;
			_tmp5_ = alpm_pkg_get_conflicts (_tmp4_);
			_tmp6_ = _tmp5_;
			list = _tmp6_;
			while (TRUE) {
				alpm_list_t* _tmp7_;
				GPtrArray* _tmp8_;
				alpm_list_t* _tmp9_;
				gconstpointer _tmp10_;
				gchar* _tmp11_;
				_tmp7_ = list;
				if (!(_tmp7_ != NULL)) {
					break;
				}
				_tmp8_ = self->priv->_conflicts;
				_tmp9_ = list;
				_tmp10_ = _tmp9_->data;
				_tmp11_ = alpm_dep_compute_string ((alpm_depend_t*) _tmp10_);
				g_ptr_array_add (_tmp8_, _tmp11_);
				list = alpm_list_next (list);
			}
		} else {
			PamacAURInfos* _tmp12_;
			_tmp12_ = self->priv->aur_infos;
			if (_tmp12_ != NULL) {
				PamacAURInfos* _tmp13_;
				GPtrArray* _tmp14_;
				GPtrArray* _tmp15_;
				GPtrArray* _tmp16_;
				_tmp13_ = self->priv->aur_infos;
				_tmp14_ = pamac_aur_infos_get_conflicts (_tmp13_);
				_tmp15_ = _tmp14_;
				_tmp16_ = _g_ptr_array_ref0 (_tmp15_);
				_g_ptr_array_unref0 (self->priv->_conflicts);
				self->priv->_conflicts = _tmp16_;
			}
		}
	}
	_tmp17_ = self->priv->_conflicts;
	result = _tmp17_;
	return result;
}

static void
pamac_aur_package_linked_real_set_conflicts (PamacAlpmPackage* base,
                                             GPtrArray* value)
{
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = _g_ptr_array_ref0 (value);
	_g_ptr_array_unref0 (self->priv->_conflicts);
	self->priv->_conflicts = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_CONFLICTS_PROPERTY]);
}

static GPtrArray*
pamac_aur_package_linked_real_get_backups (PamacAlpmPackage* base)
{
	GPtrArray* result;
	PamacAURPackageLinked* self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp15_;
	self = (PamacAURPackageLinked*) base;
	_tmp0_ = self->priv->_backups;
	if (_tmp0_ == NULL) {
		GPtrArray* _tmp1_;
		alpm_pkg_t* _tmp2_;
		_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
		_g_ptr_array_unref0 (self->priv->_backups);
		self->priv->_backups = _tmp1_;
		_tmp2_ = self->priv->local_pkg;
		if (_tmp2_ != NULL) {
			alpm_list_t* list = NULL;
			alpm_pkg_t* _tmp3_;
			alpm_list_t* _tmp4_;
			alpm_list_t* _tmp5_;
			_tmp3_ = self->priv->local_pkg;
			_tmp4_ = alpm_pkg_get_backup (_tmp3_);
			_tmp5_ = _tmp4_;
			list = _tmp5_;
			while (TRUE) {
				alpm_list_t* _tmp6_;
				GString* builder = NULL;
				GString* _tmp7_;
				GString* _tmp8_;
				alpm_list_t* _tmp9_;
				gconstpointer _tmp10_;
				const gchar* _tmp11_;
				GPtrArray* _tmp12_;
				GString* _tmp13_;
				gchar* _tmp14_;
				_tmp6_ = list;
				if (!(_tmp6_ != NULL)) {
					break;
				}
				_tmp7_ = g_string_new ("/");
				builder = _tmp7_;
				_tmp8_ = builder;
				_tmp9_ = list;
				_tmp10_ = _tmp9_->data;
				_tmp11_ = ((alpm_backup_t*) _tmp10_)->name;
				g_string_append (_tmp8_, _tmp11_);
				_tmp12_ = self->priv->_backups;
				_tmp13_ = builder;
				_tmp14_ = _tmp13_->str;
				_tmp13_->str = NULL;
				g_ptr_array_add (_tmp12_, _tmp14_);
				list = alpm_list_next (list);
				_g_string_free0 (builder);
			}
		}
	}
	_tmp15_ = self->priv->_backups;
	result = _tmp15_;
	return result;
}

static const gchar*
pamac_aur_package_linked_real_get_packagebase (PamacAURPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	const gchar* _tmp6_;
	self = (PamacAURPackageLinked*) base;
	_tmp1_ = self->priv->_packagebase;
	if (_tmp1_ == NULL) {
		PamacAURInfos* _tmp2_;
		_tmp2_ = self->priv->aur_infos;
		_tmp0_ = _tmp2_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		PamacAURInfos* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		_tmp3_ = self->priv->aur_infos;
		_tmp4_ = pamac_aur_infos_get_packagebase (_tmp3_);
		_tmp5_ = _tmp4_;
		self->priv->_packagebase = _tmp5_;
	}
	_tmp6_ = self->priv->_packagebase;
	result = _tmp6_;
	return result;
}

static void
pamac_aur_package_linked_real_set_packagebase (PamacAURPackage* base,
                                               const gchar* value)
{
	PamacAURPackageLinked* self;
	self = (PamacAURPackageLinked*) base;
	self->priv->_packagebase = value;
	g_object_notify_by_pspec ((GObject *) self, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_PACKAGEBASE_PROPERTY]);
}

static const gchar*
pamac_aur_package_linked_real_get_maintainer (PamacAURPackage* base)
{
	const gchar* result;
	PamacAURPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	const gchar* _tmp6_;
	self = (PamacAURPackageLinked*) base;
	_tmp1_ = self->priv->_maintainer;
	if (_tmp1_ == NULL) {
		PamacAURInfos* _tmp2_;
		_tmp2_ = self->priv->aur_infos;
		_tmp0_ = _tmp2_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		PamacAURInfos* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		_tmp3_ = self->priv->aur_infos;
		_tmp4_ = pamac_aur_infos_get_maintainer (_tmp3_);
		_tmp5_ = _tmp4_;
		self->priv->_maintainer = _tmp5_;
	}
	_tmp6_ = self->priv->_maintainer;
	result = _tmp6_;
	return result;
}

static gdouble
pamac_aur_package_linked_real_get_popularity (PamacAURPackage* base)
{
	gdouble result;
	PamacAURPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	self = (PamacAURPackageLinked*) base;
	if (self->priv->_popularity == ((gdouble) 0)) {
		PamacAURInfos* _tmp1_;
		_tmp1_ = self->priv->aur_infos;
		_tmp0_ = _tmp1_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		PamacAURInfos* _tmp2_;
		gdouble _tmp3_;
		gdouble _tmp4_;
		_tmp2_ = self->priv->aur_infos;
		_tmp3_ = pamac_aur_infos_get_popularity (_tmp2_);
		_tmp4_ = _tmp3_;
		self->priv->_popularity = _tmp4_;
	}
	result = self->priv->_popularity;
	return result;
}

static GDateTime*
pamac_aur_package_linked_real_get_lastmodified (PamacAURPackage* base)
{
	GDateTime* result;
	PamacAURPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	GDateTime* _tmp1_;
	GDateTime* _tmp7_;
	self = (PamacAURPackageLinked*) base;
	_tmp1_ = self->priv->_lastmodified;
	if (_tmp1_ == NULL) {
		PamacAURInfos* _tmp2_;
		_tmp2_ = self->priv->aur_infos;
		_tmp0_ = _tmp2_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		PamacAURInfos* _tmp3_;
		GDateTime* _tmp4_;
		GDateTime* _tmp5_;
		GDateTime* _tmp6_;
		_tmp3_ = self->priv->aur_infos;
		_tmp4_ = pamac_aur_infos_get_lastmodified (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp6_ = _g_date_time_ref0 (_tmp5_);
		_g_date_time_unref0 (self->priv->_lastmodified);
		self->priv->_lastmodified = _tmp6_;
	}
	_tmp7_ = self->priv->_lastmodified;
	result = _tmp7_;
	return result;
}

static GDateTime*
pamac_aur_package_linked_real_get_outofdate (PamacAURPackage* base)
{
	GDateTime* result;
	PamacAURPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	GDateTime* _tmp1_;
	GDateTime* _tmp7_;
	self = (PamacAURPackageLinked*) base;
	_tmp1_ = self->priv->_outofdate;
	if (_tmp1_ == NULL) {
		PamacAURInfos* _tmp2_;
		_tmp2_ = self->priv->aur_infos;
		_tmp0_ = _tmp2_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		PamacAURInfos* _tmp3_;
		GDateTime* _tmp4_;
		GDateTime* _tmp5_;
		GDateTime* _tmp6_;
		_tmp3_ = self->priv->aur_infos;
		_tmp4_ = pamac_aur_infos_get_outofdate (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp6_ = _g_date_time_ref0 (_tmp5_);
		_g_date_time_unref0 (self->priv->_outofdate);
		self->priv->_outofdate = _tmp6_;
	}
	_tmp7_ = self->priv->_outofdate;
	result = _tmp7_;
	return result;
}

static GDateTime*
pamac_aur_package_linked_real_get_firstsubmitted (PamacAURPackage* base)
{
	GDateTime* result;
	PamacAURPackageLinked* self;
	gboolean _tmp0_ = FALSE;
	GDateTime* _tmp1_;
	GDateTime* _tmp7_;
	self = (PamacAURPackageLinked*) base;
	_tmp1_ = self->priv->_firstsubmitted;
	if (_tmp1_ == NULL) {
		PamacAURInfos* _tmp2_;
		_tmp2_ = self->priv->aur_infos;
		_tmp0_ = _tmp2_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		PamacAURInfos* _tmp3_;
		GDateTime* _tmp4_;
		GDateTime* _tmp5_;
		GDateTime* _tmp6_;
		_tmp3_ = self->priv->aur_infos;
		_tmp4_ = pamac_aur_infos_get_firstsubmitted (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp6_ = _g_date_time_ref0 (_tmp5_);
		_g_date_time_unref0 (self->priv->_firstsubmitted);
		self->priv->_firstsubmitted = _tmp6_;
	}
	_tmp7_ = self->priv->_firstsubmitted;
	result = _tmp7_;
	return result;
}

static guint64
pamac_aur_package_linked_real_get_numvotes (PamacAURPackage* base)
{
	guint64 result;
	PamacAURPackageLinked* self;
	self = (PamacAURPackageLinked*) base;
	if (self->priv->_numvotes == ((guint64) 0)) {
		PamacAURInfos* _tmp0_;
		guint64 _tmp1_;
		guint64 _tmp2_;
		_tmp0_ = self->priv->aur_infos;
		_tmp1_ = pamac_aur_infos_get_numvotes (_tmp0_);
		_tmp2_ = _tmp1_;
		self->priv->_numvotes = _tmp2_;
	}
	result = self->priv->_numvotes;
	return result;
}

static void
pamac_aur_package_linked_class_init (PamacAURPackageLinkedClass * klass,
                                     gpointer klass_data)
{
	pamac_aur_package_linked_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &PamacAURPackageLinked_private_offset);
	((PamacAlpmPackageClass *) klass)->get_files = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_files;
	((PamacAlpmPackageClass *) klass)->get_files_async = (void (*) (PamacAlpmPackage*, GAsyncReadyCallback, gpointer)) pamac_aur_package_linked_real_get_files_async;
	((PamacAlpmPackageClass *) klass)->get_files_finish = (GPtrArray* (*) (PamacAlpmPackage*, GAsyncResult*)) pamac_aur_package_linked_get_files_finish;
	PAMAC_PACKAGE_CLASS (klass)->get_name = (const gchar* (*) (PamacPackage*)) pamac_aur_package_linked_real_get_name;
	PAMAC_PACKAGE_CLASS (klass)->set_name = (void (*) (PamacPackage*, const gchar*)) pamac_aur_package_linked_real_set_name;
	PAMAC_PACKAGE_CLASS (klass)->get_id = (const gchar* (*) (PamacPackage*)) pamac_aur_package_linked_real_get_id;
	PAMAC_PACKAGE_CLASS (klass)->set_id = (void (*) (PamacPackage*, const gchar*)) pamac_aur_package_linked_real_set_id;
	PAMAC_PACKAGE_CLASS (klass)->get_version = (const gchar* (*) (PamacPackage*)) pamac_aur_package_linked_real_get_version;
	PAMAC_PACKAGE_CLASS (klass)->set_version = (void (*) (PamacPackage*, const gchar*)) pamac_aur_package_linked_real_set_version;
	PAMAC_PACKAGE_CLASS (klass)->get_installed_version = (const gchar* (*) (PamacPackage*)) pamac_aur_package_linked_real_get_installed_version;
	PAMAC_PACKAGE_CLASS (klass)->set_installed_version = (void (*) (PamacPackage*, const gchar*)) pamac_aur_package_linked_real_set_installed_version;
	PAMAC_PACKAGE_CLASS (klass)->get_desc = (const gchar* (*) (PamacPackage*)) pamac_aur_package_linked_real_get_desc;
	PAMAC_PACKAGE_CLASS (klass)->set_desc = (void (*) (PamacPackage*, const gchar*)) pamac_aur_package_linked_real_set_desc;
	PAMAC_PACKAGE_CLASS (klass)->get_repo = (const gchar* (*) (PamacPackage*)) pamac_aur_package_linked_real_get_repo;
	PAMAC_PACKAGE_CLASS (klass)->set_repo = (void (*) (PamacPackage*, const gchar*)) pamac_aur_package_linked_real_set_repo;
	PAMAC_PACKAGE_CLASS (klass)->get_license = (const gchar* (*) (PamacPackage*)) pamac_aur_package_linked_real_get_license;
	PAMAC_PACKAGE_CLASS (klass)->get_url = (const gchar* (*) (PamacPackage*)) pamac_aur_package_linked_real_get_url;
	PAMAC_PACKAGE_CLASS (klass)->get_installed_size = (guint64 (*) (PamacPackage*)) pamac_aur_package_linked_real_get_installed_size;
	PAMAC_PACKAGE_CLASS (klass)->get_download_size = (guint64 (*) (PamacPackage*)) pamac_aur_package_linked_real_get_download_size;
	PAMAC_PACKAGE_CLASS (klass)->get_install_date = (GDateTime* (*) (PamacPackage*)) pamac_aur_package_linked_real_get_install_date;
	PAMAC_PACKAGE_CLASS (klass)->get_app_name = (const gchar* (*) (PamacPackage*)) pamac_aur_package_linked_real_get_app_name;
	PAMAC_PACKAGE_CLASS (klass)->get_app_id = (const gchar* (*) (PamacPackage*)) pamac_aur_package_linked_real_get_app_id;
	PAMAC_PACKAGE_CLASS (klass)->get_long_desc = (const gchar* (*) (PamacPackage*)) pamac_aur_package_linked_real_get_long_desc;
	PAMAC_PACKAGE_CLASS (klass)->get_launchable = (const gchar* (*) (PamacPackage*)) pamac_aur_package_linked_real_get_launchable;
	PAMAC_PACKAGE_CLASS (klass)->get_icon = (const gchar* (*) (PamacPackage*)) pamac_aur_package_linked_real_get_icon;
	PAMAC_PACKAGE_CLASS (klass)->get_screenshots = (GPtrArray* (*) (PamacPackage*)) pamac_aur_package_linked_real_get_screenshots;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_build_date = (GDateTime* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_build_date;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_packager = (const gchar* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_packager;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_reason = (const gchar* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_reason;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_validations = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_validations;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_groups = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_groups;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_depends = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_depends;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->set_depends = (void (*) (PamacAlpmPackage*, GPtrArray*)) pamac_aur_package_linked_real_set_depends;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_optdepends = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_optdepends;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_makedepends = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_makedepends;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_checkdepends = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_checkdepends;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_requiredby = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_requiredby;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_optionalfor = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_optionalfor;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_provides = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_provides;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->set_provides = (void (*) (PamacAlpmPackage*, GPtrArray*)) pamac_aur_package_linked_real_set_provides;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_replaces = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_replaces;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->set_replaces = (void (*) (PamacAlpmPackage*, GPtrArray*)) pamac_aur_package_linked_real_set_replaces;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_conflicts = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_conflicts;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->set_conflicts = (void (*) (PamacAlpmPackage*, GPtrArray*)) pamac_aur_package_linked_real_set_conflicts;
	PAMAC_ALPM_PACKAGE_CLASS (klass)->get_backups = (GPtrArray* (*) (PamacAlpmPackage*)) pamac_aur_package_linked_real_get_backups;
	PAMAC_AUR_PACKAGE_CLASS (klass)->get_packagebase = (const gchar* (*) (PamacAURPackage*)) pamac_aur_package_linked_real_get_packagebase;
	PAMAC_AUR_PACKAGE_CLASS (klass)->set_packagebase = (void (*) (PamacAURPackage*, const gchar*)) pamac_aur_package_linked_real_set_packagebase;
	PAMAC_AUR_PACKAGE_CLASS (klass)->get_maintainer = (const gchar* (*) (PamacAURPackage*)) pamac_aur_package_linked_real_get_maintainer;
	PAMAC_AUR_PACKAGE_CLASS (klass)->get_popularity = (gdouble (*) (PamacAURPackage*)) pamac_aur_package_linked_real_get_popularity;
	PAMAC_AUR_PACKAGE_CLASS (klass)->get_lastmodified = (GDateTime* (*) (PamacAURPackage*)) pamac_aur_package_linked_real_get_lastmodified;
	PAMAC_AUR_PACKAGE_CLASS (klass)->get_outofdate = (GDateTime* (*) (PamacAURPackage*)) pamac_aur_package_linked_real_get_outofdate;
	PAMAC_AUR_PACKAGE_CLASS (klass)->get_firstsubmitted = (GDateTime* (*) (PamacAURPackage*)) pamac_aur_package_linked_real_get_firstsubmitted;
	PAMAC_AUR_PACKAGE_CLASS (klass)->get_numvotes = (guint64 (*) (PamacAURPackage*)) pamac_aur_package_linked_real_get_numvotes;
	G_OBJECT_CLASS (klass)->get_property = _vala_pamac_aur_package_linked_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_pamac_aur_package_linked_set_property;
	G_OBJECT_CLASS (klass)->finalize = pamac_aur_package_linked_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_NAME_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_ID_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_VERSION_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_VERSION_PROPERTY] = g_param_spec_string ("version", "version", "version", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_INSTALLED_VERSION_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_INSTALLED_VERSION_PROPERTY] = g_param_spec_string ("installed-version", "installed-version", "installed-version", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_DESC_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_DESC_PROPERTY] = g_param_spec_string ("desc", "desc", "desc", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_REPO_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_REPO_PROPERTY] = g_param_spec_string ("repo", "repo", "repo", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_LICENSE_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_LICENSE_PROPERTY] = g_param_spec_string ("license", "license", "license", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_URL_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_URL_PROPERTY] = g_param_spec_string ("url", "url", "url", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_INSTALLED_SIZE_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_INSTALLED_SIZE_PROPERTY] = g_param_spec_uint64 ("installed-size", "installed-size", "installed-size", 0, G_MAXUINT64, 0U, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_DOWNLOAD_SIZE_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_DOWNLOAD_SIZE_PROPERTY] = g_param_spec_uint64 ("download-size", "download-size", "download-size", 0, G_MAXUINT64, 0U, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_INSTALL_DATE_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_INSTALL_DATE_PROPERTY] = g_param_spec_boxed ("install-date", "install-date", "install-date", G_TYPE_DATE_TIME, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_APP_NAME_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_APP_NAME_PROPERTY] = g_param_spec_string ("app-name", "app-name", "app-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_APP_ID_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_APP_ID_PROPERTY] = g_param_spec_string ("app-id", "app-id", "app-id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_LONG_DESC_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_LONG_DESC_PROPERTY] = g_param_spec_string ("long-desc", "long-desc", "long-desc", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_LAUNCHABLE_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_LAUNCHABLE_PROPERTY] = g_param_spec_string ("launchable", "launchable", "launchable", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_ICON_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_ICON_PROPERTY] = g_param_spec_string ("icon", "icon", "icon", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_SCREENSHOTS_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_SCREENSHOTS_PROPERTY] = g_param_spec_boxed ("screenshots", "screenshots", "screenshots", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_BUILD_DATE_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_BUILD_DATE_PROPERTY] = g_param_spec_boxed ("build-date", "build-date", "build-date", G_TYPE_DATE_TIME, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_PACKAGER_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_PACKAGER_PROPERTY] = g_param_spec_string ("packager", "packager", "packager", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_REASON_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_REASON_PROPERTY] = g_param_spec_string ("reason", "reason", "reason", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_VALIDATIONS_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_VALIDATIONS_PROPERTY] = g_param_spec_boxed ("validations", "validations", "validations", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_GROUPS_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_GROUPS_PROPERTY] = g_param_spec_boxed ("groups", "groups", "groups", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_DEPENDS_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_DEPENDS_PROPERTY] = g_param_spec_boxed ("depends", "depends", "depends", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_OPTDEPENDS_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_OPTDEPENDS_PROPERTY] = g_param_spec_boxed ("optdepends", "optdepends", "optdepends", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_MAKEDEPENDS_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_MAKEDEPENDS_PROPERTY] = g_param_spec_boxed ("makedepends", "makedepends", "makedepends", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_CHECKDEPENDS_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_CHECKDEPENDS_PROPERTY] = g_param_spec_boxed ("checkdepends", "checkdepends", "checkdepends", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_REQUIREDBY_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_REQUIREDBY_PROPERTY] = g_param_spec_boxed ("requiredby", "requiredby", "requiredby", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_OPTIONALFOR_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_OPTIONALFOR_PROPERTY] = g_param_spec_boxed ("optionalfor", "optionalfor", "optionalfor", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_PROVIDES_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_PROVIDES_PROPERTY] = g_param_spec_boxed ("provides", "provides", "provides", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_REPLACES_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_REPLACES_PROPERTY] = g_param_spec_boxed ("replaces", "replaces", "replaces", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_CONFLICTS_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_CONFLICTS_PROPERTY] = g_param_spec_boxed ("conflicts", "conflicts", "conflicts", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_BACKUPS_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_BACKUPS_PROPERTY] = g_param_spec_boxed ("backups", "backups", "backups", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_PACKAGEBASE_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_PACKAGEBASE_PROPERTY] = g_param_spec_string ("packagebase", "packagebase", "packagebase", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_MAINTAINER_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_MAINTAINER_PROPERTY] = g_param_spec_string ("maintainer", "maintainer", "maintainer", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_POPULARITY_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_POPULARITY_PROPERTY] = g_param_spec_double ("popularity", "popularity", "popularity", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_LASTMODIFIED_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_LASTMODIFIED_PROPERTY] = g_param_spec_boxed ("lastmodified", "lastmodified", "lastmodified", G_TYPE_DATE_TIME, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_OUTOFDATE_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_OUTOFDATE_PROPERTY] = g_param_spec_boxed ("outofdate", "outofdate", "outofdate", G_TYPE_DATE_TIME, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_FIRSTSUBMITTED_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_FIRSTSUBMITTED_PROPERTY] = g_param_spec_boxed ("firstsubmitted", "firstsubmitted", "firstsubmitted", G_TYPE_DATE_TIME, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_LINKED_NUMVOTES_PROPERTY, pamac_aur_package_linked_properties[PAMAC_AUR_PACKAGE_LINKED_NUMVOTES_PROPERTY] = g_param_spec_uint64 ("numvotes", "numvotes", "numvotes", 0, G_MAXUINT64, 0U, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
pamac_aur_package_linked_instance_init (PamacAURPackageLinked * self,
                                        gpointer klass)
{
	self->priv = pamac_aur_package_linked_get_instance_private (self);
}

static void
pamac_aur_package_linked_finalize (GObject * obj)
{
	PamacAURPackageLinked * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PAMAC_TYPE_AUR_PACKAGE_LINKED, PamacAURPackageLinked);
	_g_free0 (self->priv->_name);
	_g_free0 (self->priv->_id);
	_g_free0 (self->priv->_version);
	_g_free0 (self->priv->_license);
	_g_date_time_unref0 (self->priv->_install_date);
	_g_date_time_unref0 (self->priv->_build_date);
	_g_ptr_array_unref0 (self->priv->_validations);
	_g_ptr_array_unref0 (self->priv->_groups);
	_g_ptr_array_unref0 (self->priv->_depends);
	_g_ptr_array_unref0 (self->priv->_optdepends);
	_g_ptr_array_unref0 (self->priv->_makedepends);
	_g_ptr_array_unref0 (self->priv->_checkdepends);
	_g_ptr_array_unref0 (self->priv->_requiredby);
	_g_ptr_array_unref0 (self->priv->_optionalfor);
	_g_ptr_array_unref0 (self->priv->_provides);
	_g_ptr_array_unref0 (self->priv->_replaces);
	_g_ptr_array_unref0 (self->priv->_conflicts);
	_g_ptr_array_unref0 (self->priv->_backups);
	_g_ptr_array_unref0 (self->priv->_files);
	_g_ptr_array_unref0 (self->priv->_screenshots);
	_g_object_unref0 (self->priv->aur_infos);
	_g_date_time_unref0 (self->priv->_lastmodified);
	_g_date_time_unref0 (self->priv->_outofdate);
	_g_date_time_unref0 (self->priv->_firstsubmitted);
	G_OBJECT_CLASS (pamac_aur_package_linked_parent_class)->finalize (obj);
}

static GType
pamac_aur_package_linked_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PamacAURPackageLinkedClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) pamac_aur_package_linked_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PamacAURPackageLinked), 0, (GInstanceInitFunc) pamac_aur_package_linked_instance_init, NULL };
	GType pamac_aur_package_linked_type_id;
	pamac_aur_package_linked_type_id = g_type_register_static (PAMAC_TYPE_AUR_PACKAGE, "PamacAURPackageLinked", &g_define_type_info, 0);
	PamacAURPackageLinked_private_offset = g_type_add_instance_private (pamac_aur_package_linked_type_id, sizeof (PamacAURPackageLinkedPrivate));
	return pamac_aur_package_linked_type_id;
}

GType
pamac_aur_package_linked_get_type (void)
{
	static volatile gsize pamac_aur_package_linked_type_id__once = 0;
	if (g_once_init_enter (&pamac_aur_package_linked_type_id__once)) {
		GType pamac_aur_package_linked_type_id;
		pamac_aur_package_linked_type_id = pamac_aur_package_linked_get_type_once ();
		g_once_init_leave (&pamac_aur_package_linked_type_id__once, pamac_aur_package_linked_type_id);
	}
	return pamac_aur_package_linked_type_id__once;
}

static void
_vala_pamac_aur_package_linked_get_property (GObject * object,
                                             guint property_id,
                                             GValue * value,
                                             GParamSpec * pspec)
{
	PamacAURPackageLinked * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_AUR_PACKAGE_LINKED, PamacAURPackageLinked);
	switch (property_id) {
		case PAMAC_AUR_PACKAGE_LINKED_NAME_PROPERTY:
		g_value_set_string (value, pamac_package_get_name ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_ID_PROPERTY:
		g_value_set_string (value, pamac_package_get_id ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_VERSION_PROPERTY:
		g_value_set_string (value, pamac_package_get_version ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_INSTALLED_VERSION_PROPERTY:
		g_value_set_string (value, pamac_package_get_installed_version ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_DESC_PROPERTY:
		g_value_set_string (value, pamac_package_get_desc ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_REPO_PROPERTY:
		g_value_set_string (value, pamac_package_get_repo ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_LICENSE_PROPERTY:
		g_value_set_string (value, pamac_package_get_license ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_URL_PROPERTY:
		g_value_set_string (value, pamac_package_get_url ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_INSTALLED_SIZE_PROPERTY:
		g_value_set_uint64 (value, pamac_package_get_installed_size ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_DOWNLOAD_SIZE_PROPERTY:
		g_value_set_uint64 (value, pamac_package_get_download_size ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_INSTALL_DATE_PROPERTY:
		g_value_set_boxed (value, pamac_package_get_install_date ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_APP_NAME_PROPERTY:
		g_value_set_string (value, pamac_package_get_app_name ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_APP_ID_PROPERTY:
		g_value_set_string (value, pamac_package_get_app_id ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_LONG_DESC_PROPERTY:
		g_value_set_string (value, pamac_package_get_long_desc ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_LAUNCHABLE_PROPERTY:
		g_value_set_string (value, pamac_package_get_launchable ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_ICON_PROPERTY:
		g_value_set_string (value, pamac_package_get_icon ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_SCREENSHOTS_PROPERTY:
		g_value_set_boxed (value, pamac_package_get_screenshots ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_BUILD_DATE_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_build_date ((PamacAlpmPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_PACKAGER_PROPERTY:
		g_value_set_string (value, pamac_alpm_package_get_packager ((PamacAlpmPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_REASON_PROPERTY:
		g_value_set_string (value, pamac_alpm_package_get_reason ((PamacAlpmPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_VALIDATIONS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_validations ((PamacAlpmPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_GROUPS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_groups ((PamacAlpmPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_DEPENDS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_depends ((PamacAlpmPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_OPTDEPENDS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_optdepends ((PamacAlpmPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_MAKEDEPENDS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_makedepends ((PamacAlpmPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_CHECKDEPENDS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_checkdepends ((PamacAlpmPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_REQUIREDBY_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_requiredby ((PamacAlpmPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_OPTIONALFOR_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_optionalfor ((PamacAlpmPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_PROVIDES_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_provides ((PamacAlpmPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_REPLACES_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_replaces ((PamacAlpmPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_CONFLICTS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_conflicts ((PamacAlpmPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_BACKUPS_PROPERTY:
		g_value_set_boxed (value, pamac_alpm_package_get_backups ((PamacAlpmPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_PACKAGEBASE_PROPERTY:
		g_value_set_string (value, pamac_aur_package_get_packagebase ((PamacAURPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_MAINTAINER_PROPERTY:
		g_value_set_string (value, pamac_aur_package_get_maintainer ((PamacAURPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_POPULARITY_PROPERTY:
		g_value_set_double (value, pamac_aur_package_get_popularity ((PamacAURPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_LASTMODIFIED_PROPERTY:
		g_value_set_boxed (value, pamac_aur_package_get_lastmodified ((PamacAURPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_OUTOFDATE_PROPERTY:
		g_value_set_boxed (value, pamac_aur_package_get_outofdate ((PamacAURPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_FIRSTSUBMITTED_PROPERTY:
		g_value_set_boxed (value, pamac_aur_package_get_firstsubmitted ((PamacAURPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_NUMVOTES_PROPERTY:
		g_value_set_uint64 (value, pamac_aur_package_get_numvotes ((PamacAURPackage*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_pamac_aur_package_linked_set_property (GObject * object,
                                             guint property_id,
                                             const GValue * value,
                                             GParamSpec * pspec)
{
	PamacAURPackageLinked * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_AUR_PACKAGE_LINKED, PamacAURPackageLinked);
	switch (property_id) {
		case PAMAC_AUR_PACKAGE_LINKED_NAME_PROPERTY:
		pamac_package_set_name ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_ID_PROPERTY:
		pamac_package_set_id ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_VERSION_PROPERTY:
		pamac_package_set_version ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_INSTALLED_VERSION_PROPERTY:
		pamac_package_set_installed_version ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_DESC_PROPERTY:
		pamac_package_set_desc ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_REPO_PROPERTY:
		pamac_package_set_repo ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_DEPENDS_PROPERTY:
		pamac_alpm_package_set_depends ((PamacAlpmPackage*) self, g_value_get_boxed (value));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_PROVIDES_PROPERTY:
		pamac_alpm_package_set_provides ((PamacAlpmPackage*) self, g_value_get_boxed (value));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_REPLACES_PROPERTY:
		pamac_alpm_package_set_replaces ((PamacAlpmPackage*) self, g_value_get_boxed (value));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_CONFLICTS_PROPERTY:
		pamac_alpm_package_set_conflicts ((PamacAlpmPackage*) self, g_value_get_boxed (value));
		break;
		case PAMAC_AUR_PACKAGE_LINKED_PACKAGEBASE_PROPERTY:
		pamac_aur_package_set_packagebase ((PamacAURPackage*) self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
pamac_aur_package_static_get_instance_private (PamacAURPackageStatic* self)
{
	return G_STRUCT_MEMBER_P (self, PamacAURPackageStatic_private_offset);
}

PamacAURPackageStatic*
pamac_aur_package_static_construct (GType object_type)
{
	PamacAURPackageStatic * self = NULL;
	self = (PamacAURPackageStatic*) pamac_aur_package_linked_construct (object_type);
	return self;
}

PamacAURPackageStatic*
pamac_aur_package_static_new (void)
{
	return pamac_aur_package_static_construct (PAMAC_TYPE_AUR_PACKAGE_STATIC);
}

static const gchar*
pamac_aur_package_static_real_get_desc (PamacPackage* base)
{
	const gchar* result;
	PamacAURPackageStatic* self;
	const gchar* _tmp0_;
	self = (PamacAURPackageStatic*) base;
	_tmp0_ = self->priv->_desc;
	result = _tmp0_;
	return result;
}

static void
pamac_aur_package_static_real_set_desc (PamacPackage* base,
                                        const gchar* value)
{
	PamacAURPackageStatic* self;
	gchar* _tmp0_;
	self = (PamacAURPackageStatic*) base;
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_desc);
	self->priv->_desc = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_aur_package_static_properties[PAMAC_AUR_PACKAGE_STATIC_DESC_PROPERTY]);
}

static const gchar*
pamac_aur_package_static_real_get_packagebase (PamacAURPackage* base)
{
	const gchar* result;
	PamacAURPackageStatic* self;
	const gchar* _tmp0_;
	self = (PamacAURPackageStatic*) base;
	_tmp0_ = self->priv->_packagebase;
	result = _tmp0_;
	return result;
}

static void
pamac_aur_package_static_real_set_packagebase (PamacAURPackage* base,
                                               const gchar* value)
{
	PamacAURPackageStatic* self;
	gchar* _tmp0_;
	self = (PamacAURPackageStatic*) base;
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_packagebase);
	self->priv->_packagebase = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, pamac_aur_package_static_properties[PAMAC_AUR_PACKAGE_STATIC_PACKAGEBASE_PROPERTY]);
}

static void
pamac_aur_package_static_class_init (PamacAURPackageStaticClass * klass,
                                     gpointer klass_data)
{
	pamac_aur_package_static_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &PamacAURPackageStatic_private_offset);
	PAMAC_PACKAGE_CLASS (klass)->get_desc = (const gchar* (*) (PamacPackage*)) pamac_aur_package_static_real_get_desc;
	PAMAC_PACKAGE_CLASS (klass)->set_desc = (void (*) (PamacPackage*, const gchar*)) pamac_aur_package_static_real_set_desc;
	PAMAC_AUR_PACKAGE_CLASS (klass)->get_packagebase = (const gchar* (*) (PamacAURPackage*)) pamac_aur_package_static_real_get_packagebase;
	PAMAC_AUR_PACKAGE_CLASS (klass)->set_packagebase = (void (*) (PamacAURPackage*, const gchar*)) pamac_aur_package_static_real_set_packagebase;
	G_OBJECT_CLASS (klass)->get_property = _vala_pamac_aur_package_static_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_pamac_aur_package_static_set_property;
	G_OBJECT_CLASS (klass)->finalize = pamac_aur_package_static_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_STATIC_DESC_PROPERTY, pamac_aur_package_static_properties[PAMAC_AUR_PACKAGE_STATIC_DESC_PROPERTY] = g_param_spec_string ("desc", "desc", "desc", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_AUR_PACKAGE_STATIC_PACKAGEBASE_PROPERTY, pamac_aur_package_static_properties[PAMAC_AUR_PACKAGE_STATIC_PACKAGEBASE_PROPERTY] = g_param_spec_string ("packagebase", "packagebase", "packagebase", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
pamac_aur_package_static_instance_init (PamacAURPackageStatic * self,
                                        gpointer klass)
{
	self->priv = pamac_aur_package_static_get_instance_private (self);
}

static void
pamac_aur_package_static_finalize (GObject * obj)
{
	PamacAURPackageStatic * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PAMAC_TYPE_AUR_PACKAGE_STATIC, PamacAURPackageStatic);
	_g_free0 (self->priv->_desc);
	_g_free0 (self->priv->_packagebase);
	G_OBJECT_CLASS (pamac_aur_package_static_parent_class)->finalize (obj);
}

static GType
pamac_aur_package_static_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PamacAURPackageStaticClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) pamac_aur_package_static_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PamacAURPackageStatic), 0, (GInstanceInitFunc) pamac_aur_package_static_instance_init, NULL };
	GType pamac_aur_package_static_type_id;
	pamac_aur_package_static_type_id = g_type_register_static (PAMAC_TYPE_AUR_PACKAGE_LINKED, "PamacAURPackageStatic", &g_define_type_info, 0);
	PamacAURPackageStatic_private_offset = g_type_add_instance_private (pamac_aur_package_static_type_id, sizeof (PamacAURPackageStaticPrivate));
	return pamac_aur_package_static_type_id;
}

GType
pamac_aur_package_static_get_type (void)
{
	static volatile gsize pamac_aur_package_static_type_id__once = 0;
	if (g_once_init_enter (&pamac_aur_package_static_type_id__once)) {
		GType pamac_aur_package_static_type_id;
		pamac_aur_package_static_type_id = pamac_aur_package_static_get_type_once ();
		g_once_init_leave (&pamac_aur_package_static_type_id__once, pamac_aur_package_static_type_id);
	}
	return pamac_aur_package_static_type_id__once;
}

static void
_vala_pamac_aur_package_static_get_property (GObject * object,
                                             guint property_id,
                                             GValue * value,
                                             GParamSpec * pspec)
{
	PamacAURPackageStatic * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_AUR_PACKAGE_STATIC, PamacAURPackageStatic);
	switch (property_id) {
		case PAMAC_AUR_PACKAGE_STATIC_DESC_PROPERTY:
		g_value_set_string (value, pamac_package_get_desc ((PamacPackage*) self));
		break;
		case PAMAC_AUR_PACKAGE_STATIC_PACKAGEBASE_PROPERTY:
		g_value_set_string (value, pamac_aur_package_get_packagebase ((PamacAURPackage*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_pamac_aur_package_static_set_property (GObject * object,
                                             guint property_id,
                                             const GValue * value,
                                             GParamSpec * pspec)
{
	PamacAURPackageStatic * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_AUR_PACKAGE_STATIC, PamacAURPackageStatic);
	switch (property_id) {
		case PAMAC_AUR_PACKAGE_STATIC_DESC_PROPERTY:
		pamac_package_set_desc ((PamacPackage*) self, g_value_get_string (value));
		break;
		case PAMAC_AUR_PACKAGE_STATIC_PACKAGEBASE_PROPERTY:
		pamac_aur_package_set_packagebase ((PamacAURPackage*) self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
pamac_transaction_summary_get_instance_private (PamacTransactionSummary* self)
{
	return G_STRUCT_MEMBER_P (self, PamacTransactionSummary_private_offset);
}

static void
_g_object_unref0_ (gpointer var)
{
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
}

PamacTransactionSummary*
pamac_transaction_summary_construct (GType object_type)
{
	PamacTransactionSummary * self = NULL;
	self = (PamacTransactionSummary*) g_object_new (object_type, NULL);
	return self;
}

PamacTransactionSummary*
pamac_transaction_summary_new (void)
{
	return pamac_transaction_summary_construct (PAMAC_TYPE_TRANSACTION_SUMMARY);
}

GPtrArray*
pamac_transaction_summary_get_to_install (PamacTransactionSummary* self)
{
	GPtrArray* result;
	GPtrArray* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_to_install;
	result = _tmp0_;
	return result;
}

void
pamac_transaction_summary_set_to_install (PamacTransactionSummary* self,
                                          GPtrArray* value)
{
	GPtrArray* old_value;
	g_return_if_fail (self != NULL);
	old_value = pamac_transaction_summary_get_to_install (self);
	if (old_value != value) {
		GPtrArray* _tmp0_;
		_tmp0_ = _g_ptr_array_ref0 (value);
		_g_ptr_array_unref0 (self->priv->_to_install);
		self->priv->_to_install = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_TO_INSTALL_PROPERTY]);
	}
}

GPtrArray*
pamac_transaction_summary_get_to_upgrade (PamacTransactionSummary* self)
{
	GPtrArray* result;
	GPtrArray* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_to_upgrade;
	result = _tmp0_;
	return result;
}

void
pamac_transaction_summary_set_to_upgrade (PamacTransactionSummary* self,
                                          GPtrArray* value)
{
	GPtrArray* old_value;
	g_return_if_fail (self != NULL);
	old_value = pamac_transaction_summary_get_to_upgrade (self);
	if (old_value != value) {
		GPtrArray* _tmp0_;
		_tmp0_ = _g_ptr_array_ref0 (value);
		_g_ptr_array_unref0 (self->priv->_to_upgrade);
		self->priv->_to_upgrade = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_TO_UPGRADE_PROPERTY]);
	}
}

GPtrArray*
pamac_transaction_summary_get_to_downgrade (PamacTransactionSummary* self)
{
	GPtrArray* result;
	GPtrArray* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_to_downgrade;
	result = _tmp0_;
	return result;
}

void
pamac_transaction_summary_set_to_downgrade (PamacTransactionSummary* self,
                                            GPtrArray* value)
{
	GPtrArray* old_value;
	g_return_if_fail (self != NULL);
	old_value = pamac_transaction_summary_get_to_downgrade (self);
	if (old_value != value) {
		GPtrArray* _tmp0_;
		_tmp0_ = _g_ptr_array_ref0 (value);
		_g_ptr_array_unref0 (self->priv->_to_downgrade);
		self->priv->_to_downgrade = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_TO_DOWNGRADE_PROPERTY]);
	}
}

GPtrArray*
pamac_transaction_summary_get_to_reinstall (PamacTransactionSummary* self)
{
	GPtrArray* result;
	GPtrArray* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_to_reinstall;
	result = _tmp0_;
	return result;
}

void
pamac_transaction_summary_set_to_reinstall (PamacTransactionSummary* self,
                                            GPtrArray* value)
{
	GPtrArray* old_value;
	g_return_if_fail (self != NULL);
	old_value = pamac_transaction_summary_get_to_reinstall (self);
	if (old_value != value) {
		GPtrArray* _tmp0_;
		_tmp0_ = _g_ptr_array_ref0 (value);
		_g_ptr_array_unref0 (self->priv->_to_reinstall);
		self->priv->_to_reinstall = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_TO_REINSTALL_PROPERTY]);
	}
}

GPtrArray*
pamac_transaction_summary_get_to_remove (PamacTransactionSummary* self)
{
	GPtrArray* result;
	GPtrArray* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_to_remove;
	result = _tmp0_;
	return result;
}

void
pamac_transaction_summary_set_to_remove (PamacTransactionSummary* self,
                                         GPtrArray* value)
{
	GPtrArray* old_value;
	g_return_if_fail (self != NULL);
	old_value = pamac_transaction_summary_get_to_remove (self);
	if (old_value != value) {
		GPtrArray* _tmp0_;
		_tmp0_ = _g_ptr_array_ref0 (value);
		_g_ptr_array_unref0 (self->priv->_to_remove);
		self->priv->_to_remove = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_TO_REMOVE_PROPERTY]);
	}
}

GPtrArray*
pamac_transaction_summary_get_conflicts_to_remove (PamacTransactionSummary* self)
{
	GPtrArray* result;
	GPtrArray* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_conflicts_to_remove;
	result = _tmp0_;
	return result;
}

void
pamac_transaction_summary_set_conflicts_to_remove (PamacTransactionSummary* self,
                                                   GPtrArray* value)
{
	GPtrArray* old_value;
	g_return_if_fail (self != NULL);
	old_value = pamac_transaction_summary_get_conflicts_to_remove (self);
	if (old_value != value) {
		GPtrArray* _tmp0_;
		_tmp0_ = _g_ptr_array_ref0 (value);
		_g_ptr_array_unref0 (self->priv->_conflicts_to_remove);
		self->priv->_conflicts_to_remove = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_CONFLICTS_TO_REMOVE_PROPERTY]);
	}
}

GPtrArray*
pamac_transaction_summary_get_to_build (PamacTransactionSummary* self)
{
	GPtrArray* result;
	GPtrArray* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_to_build;
	result = _tmp0_;
	return result;
}

void
pamac_transaction_summary_set_to_build (PamacTransactionSummary* self,
                                        GPtrArray* value)
{
	GPtrArray* old_value;
	g_return_if_fail (self != NULL);
	old_value = pamac_transaction_summary_get_to_build (self);
	if (old_value != value) {
		GPtrArray* _tmp0_;
		_tmp0_ = _g_ptr_array_ref0 (value);
		_g_ptr_array_unref0 (self->priv->_to_build);
		self->priv->_to_build = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_TO_BUILD_PROPERTY]);
	}
}

GPtrArray*
pamac_transaction_summary_get_aur_pkgbases_to_build (PamacTransactionSummary* self)
{
	GPtrArray* result;
	GPtrArray* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_aur_pkgbases_to_build;
	result = _tmp0_;
	return result;
}

void
pamac_transaction_summary_set_aur_pkgbases_to_build (PamacTransactionSummary* self,
                                                     GPtrArray* value)
{
	GPtrArray* old_value;
	g_return_if_fail (self != NULL);
	old_value = pamac_transaction_summary_get_aur_pkgbases_to_build (self);
	if (old_value != value) {
		GPtrArray* _tmp0_;
		_tmp0_ = _g_ptr_array_ref0 (value);
		_g_ptr_array_unref0 (self->priv->_aur_pkgbases_to_build);
		self->priv->_aur_pkgbases_to_build = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_AUR_PKGBASES_TO_BUILD_PROPERTY]);
	}
}

GPtrArray*
pamac_transaction_summary_get_to_load (PamacTransactionSummary* self)
{
	GPtrArray* result;
	GPtrArray* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_to_load;
	result = _tmp0_;
	return result;
}

void
pamac_transaction_summary_set_to_load (PamacTransactionSummary* self,
                                       GPtrArray* value)
{
	GPtrArray* old_value;
	g_return_if_fail (self != NULL);
	old_value = pamac_transaction_summary_get_to_load (self);
	if (old_value != value) {
		GPtrArray* _tmp0_;
		_tmp0_ = _g_ptr_array_ref0 (value);
		_g_ptr_array_unref0 (self->priv->_to_load);
		self->priv->_to_load = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_TO_LOAD_PROPERTY]);
	}
}

static void
pamac_transaction_summary_class_init (PamacTransactionSummaryClass * klass,
                                      gpointer klass_data)
{
	pamac_transaction_summary_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &PamacTransactionSummary_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_pamac_transaction_summary_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_pamac_transaction_summary_set_property;
	G_OBJECT_CLASS (klass)->finalize = pamac_transaction_summary_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_TRANSACTION_SUMMARY_TO_INSTALL_PROPERTY, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_TO_INSTALL_PROPERTY] = g_param_spec_boxed ("to-install", "to-install", "to-install", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_TRANSACTION_SUMMARY_TO_UPGRADE_PROPERTY, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_TO_UPGRADE_PROPERTY] = g_param_spec_boxed ("to-upgrade", "to-upgrade", "to-upgrade", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_TRANSACTION_SUMMARY_TO_DOWNGRADE_PROPERTY, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_TO_DOWNGRADE_PROPERTY] = g_param_spec_boxed ("to-downgrade", "to-downgrade", "to-downgrade", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_TRANSACTION_SUMMARY_TO_REINSTALL_PROPERTY, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_TO_REINSTALL_PROPERTY] = g_param_spec_boxed ("to-reinstall", "to-reinstall", "to-reinstall", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_TRANSACTION_SUMMARY_TO_REMOVE_PROPERTY, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_TO_REMOVE_PROPERTY] = g_param_spec_boxed ("to-remove", "to-remove", "to-remove", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_TRANSACTION_SUMMARY_CONFLICTS_TO_REMOVE_PROPERTY, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_CONFLICTS_TO_REMOVE_PROPERTY] = g_param_spec_boxed ("conflicts-to-remove", "conflicts-to-remove", "conflicts-to-remove", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_TRANSACTION_SUMMARY_TO_BUILD_PROPERTY, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_TO_BUILD_PROPERTY] = g_param_spec_boxed ("to-build", "to-build", "to-build", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_TRANSACTION_SUMMARY_AUR_PKGBASES_TO_BUILD_PROPERTY, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_AUR_PKGBASES_TO_BUILD_PROPERTY] = g_param_spec_boxed ("aur-pkgbases-to-build", "aur-pkgbases-to-build", "aur-pkgbases-to-build", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_TRANSACTION_SUMMARY_TO_LOAD_PROPERTY, pamac_transaction_summary_properties[PAMAC_TRANSACTION_SUMMARY_TO_LOAD_PROPERTY] = g_param_spec_boxed ("to-load", "to-load", "to-load", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
pamac_transaction_summary_instance_init (PamacTransactionSummary * self,
                                         gpointer klass)
{
	GPtrArray* _tmp0_;
	GPtrArray* _tmp1_;
	GPtrArray* _tmp2_;
	GPtrArray* _tmp3_;
	GPtrArray* _tmp4_;
	GPtrArray* _tmp5_;
	GPtrArray* _tmp6_;
	GPtrArray* _tmp7_;
	GPtrArray* _tmp8_;
	self->priv = pamac_transaction_summary_get_instance_private (self);
	_tmp0_ = g_ptr_array_new_full ((guint) 0, _g_object_unref0_);
	self->priv->_to_install = _tmp0_;
	_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_object_unref0_);
	self->priv->_to_upgrade = _tmp1_;
	_tmp2_ = g_ptr_array_new_full ((guint) 0, _g_object_unref0_);
	self->priv->_to_downgrade = _tmp2_;
	_tmp3_ = g_ptr_array_new_full ((guint) 0, _g_object_unref0_);
	self->priv->_to_reinstall = _tmp3_;
	_tmp4_ = g_ptr_array_new_full ((guint) 0, _g_object_unref0_);
	self->priv->_to_remove = _tmp4_;
	_tmp5_ = g_ptr_array_new_full ((guint) 0, _g_object_unref0_);
	self->priv->_conflicts_to_remove = _tmp5_;
	_tmp6_ = g_ptr_array_new_full ((guint) 0, _g_object_unref0_);
	self->priv->_to_build = _tmp6_;
	_tmp7_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
	self->priv->_aur_pkgbases_to_build = _tmp7_;
	_tmp8_ = g_ptr_array_new_full ((guint) 0, _g_free0_);
	self->priv->_to_load = _tmp8_;
}

static void
pamac_transaction_summary_finalize (GObject * obj)
{
	PamacTransactionSummary * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PAMAC_TYPE_TRANSACTION_SUMMARY, PamacTransactionSummary);
	_g_ptr_array_unref0 (self->priv->_to_install);
	_g_ptr_array_unref0 (self->priv->_to_upgrade);
	_g_ptr_array_unref0 (self->priv->_to_downgrade);
	_g_ptr_array_unref0 (self->priv->_to_reinstall);
	_g_ptr_array_unref0 (self->priv->_to_remove);
	_g_ptr_array_unref0 (self->priv->_conflicts_to_remove);
	_g_ptr_array_unref0 (self->priv->_to_build);
	_g_ptr_array_unref0 (self->priv->_aur_pkgbases_to_build);
	_g_ptr_array_unref0 (self->priv->_to_load);
	G_OBJECT_CLASS (pamac_transaction_summary_parent_class)->finalize (obj);
}

static GType
pamac_transaction_summary_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PamacTransactionSummaryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) pamac_transaction_summary_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PamacTransactionSummary), 0, (GInstanceInitFunc) pamac_transaction_summary_instance_init, NULL };
	GType pamac_transaction_summary_type_id;
	pamac_transaction_summary_type_id = g_type_register_static (G_TYPE_OBJECT, "PamacTransactionSummary", &g_define_type_info, 0);
	PamacTransactionSummary_private_offset = g_type_add_instance_private (pamac_transaction_summary_type_id, sizeof (PamacTransactionSummaryPrivate));
	return pamac_transaction_summary_type_id;
}

GType
pamac_transaction_summary_get_type (void)
{
	static volatile gsize pamac_transaction_summary_type_id__once = 0;
	if (g_once_init_enter (&pamac_transaction_summary_type_id__once)) {
		GType pamac_transaction_summary_type_id;
		pamac_transaction_summary_type_id = pamac_transaction_summary_get_type_once ();
		g_once_init_leave (&pamac_transaction_summary_type_id__once, pamac_transaction_summary_type_id);
	}
	return pamac_transaction_summary_type_id__once;
}

static void
_vala_pamac_transaction_summary_get_property (GObject * object,
                                              guint property_id,
                                              GValue * value,
                                              GParamSpec * pspec)
{
	PamacTransactionSummary * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_TRANSACTION_SUMMARY, PamacTransactionSummary);
	switch (property_id) {
		case PAMAC_TRANSACTION_SUMMARY_TO_INSTALL_PROPERTY:
		g_value_set_boxed (value, pamac_transaction_summary_get_to_install (self));
		break;
		case PAMAC_TRANSACTION_SUMMARY_TO_UPGRADE_PROPERTY:
		g_value_set_boxed (value, pamac_transaction_summary_get_to_upgrade (self));
		break;
		case PAMAC_TRANSACTION_SUMMARY_TO_DOWNGRADE_PROPERTY:
		g_value_set_boxed (value, pamac_transaction_summary_get_to_downgrade (self));
		break;
		case PAMAC_TRANSACTION_SUMMARY_TO_REINSTALL_PROPERTY:
		g_value_set_boxed (value, pamac_transaction_summary_get_to_reinstall (self));
		break;
		case PAMAC_TRANSACTION_SUMMARY_TO_REMOVE_PROPERTY:
		g_value_set_boxed (value, pamac_transaction_summary_get_to_remove (self));
		break;
		case PAMAC_TRANSACTION_SUMMARY_CONFLICTS_TO_REMOVE_PROPERTY:
		g_value_set_boxed (value, pamac_transaction_summary_get_conflicts_to_remove (self));
		break;
		case PAMAC_TRANSACTION_SUMMARY_TO_BUILD_PROPERTY:
		g_value_set_boxed (value, pamac_transaction_summary_get_to_build (self));
		break;
		case PAMAC_TRANSACTION_SUMMARY_AUR_PKGBASES_TO_BUILD_PROPERTY:
		g_value_set_boxed (value, pamac_transaction_summary_get_aur_pkgbases_to_build (self));
		break;
		case PAMAC_TRANSACTION_SUMMARY_TO_LOAD_PROPERTY:
		g_value_set_boxed (value, pamac_transaction_summary_get_to_load (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_pamac_transaction_summary_set_property (GObject * object,
                                              guint property_id,
                                              const GValue * value,
                                              GParamSpec * pspec)
{
	PamacTransactionSummary * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_TRANSACTION_SUMMARY, PamacTransactionSummary);
	switch (property_id) {
		case PAMAC_TRANSACTION_SUMMARY_TO_INSTALL_PROPERTY:
		pamac_transaction_summary_set_to_install (self, g_value_get_boxed (value));
		break;
		case PAMAC_TRANSACTION_SUMMARY_TO_UPGRADE_PROPERTY:
		pamac_transaction_summary_set_to_upgrade (self, g_value_get_boxed (value));
		break;
		case PAMAC_TRANSACTION_SUMMARY_TO_DOWNGRADE_PROPERTY:
		pamac_transaction_summary_set_to_downgrade (self, g_value_get_boxed (value));
		break;
		case PAMAC_TRANSACTION_SUMMARY_TO_REINSTALL_PROPERTY:
		pamac_transaction_summary_set_to_reinstall (self, g_value_get_boxed (value));
		break;
		case PAMAC_TRANSACTION_SUMMARY_TO_REMOVE_PROPERTY:
		pamac_transaction_summary_set_to_remove (self, g_value_get_boxed (value));
		break;
		case PAMAC_TRANSACTION_SUMMARY_CONFLICTS_TO_REMOVE_PROPERTY:
		pamac_transaction_summary_set_conflicts_to_remove (self, g_value_get_boxed (value));
		break;
		case PAMAC_TRANSACTION_SUMMARY_TO_BUILD_PROPERTY:
		pamac_transaction_summary_set_to_build (self, g_value_get_boxed (value));
		break;
		case PAMAC_TRANSACTION_SUMMARY_AUR_PKGBASES_TO_BUILD_PROPERTY:
		pamac_transaction_summary_set_aur_pkgbases_to_build (self, g_value_get_boxed (value));
		break;
		case PAMAC_TRANSACTION_SUMMARY_TO_LOAD_PROPERTY:
		pamac_transaction_summary_set_to_load (self, g_value_get_boxed (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
pamac_updates_get_instance_private (PamacUpdates* self)
{
	return G_STRUCT_MEMBER_P (self, PamacUpdates_private_offset);
}

PamacUpdates*
pamac_updates_construct (GType object_type)
{
	PamacUpdates * self = NULL;
	self = (PamacUpdates*) g_object_new (object_type, NULL);
	return self;
}

PamacUpdates*
pamac_updates_new (void)
{
	return pamac_updates_construct (PAMAC_TYPE_UPDATES);
}

GPtrArray*
pamac_updates_get_repos_updates (PamacUpdates* self)
{
	GPtrArray* result;
	GPtrArray* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_repos_updates;
	result = _tmp0_;
	return result;
}

void
pamac_updates_set_repos_updates (PamacUpdates* self,
                                 GPtrArray* value)
{
	GPtrArray* old_value;
	g_return_if_fail (self != NULL);
	old_value = pamac_updates_get_repos_updates (self);
	if (old_value != value) {
		GPtrArray* _tmp0_;
		_tmp0_ = _g_ptr_array_ref0 (value);
		_g_ptr_array_unref0 (self->priv->_repos_updates);
		self->priv->_repos_updates = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, pamac_updates_properties[PAMAC_UPDATES_REPOS_UPDATES_PROPERTY]);
	}
}

GPtrArray*
pamac_updates_get_ignored_repos_updates (PamacUpdates* self)
{
	GPtrArray* result;
	GPtrArray* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_ignored_repos_updates;
	result = _tmp0_;
	return result;
}

void
pamac_updates_set_ignored_repos_updates (PamacUpdates* self,
                                         GPtrArray* value)
{
	GPtrArray* old_value;
	g_return_if_fail (self != NULL);
	old_value = pamac_updates_get_ignored_repos_updates (self);
	if (old_value != value) {
		GPtrArray* _tmp0_;
		_tmp0_ = _g_ptr_array_ref0 (value);
		_g_ptr_array_unref0 (self->priv->_ignored_repos_updates);
		self->priv->_ignored_repos_updates = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, pamac_updates_properties[PAMAC_UPDATES_IGNORED_REPOS_UPDATES_PROPERTY]);
	}
}

GPtrArray*
pamac_updates_get_aur_updates (PamacUpdates* self)
{
	GPtrArray* result;
	GPtrArray* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_aur_updates;
	result = _tmp0_;
	return result;
}

void
pamac_updates_set_aur_updates (PamacUpdates* self,
                               GPtrArray* value)
{
	GPtrArray* old_value;
	g_return_if_fail (self != NULL);
	old_value = pamac_updates_get_aur_updates (self);
	if (old_value != value) {
		GPtrArray* _tmp0_;
		_tmp0_ = _g_ptr_array_ref0 (value);
		_g_ptr_array_unref0 (self->priv->_aur_updates);
		self->priv->_aur_updates = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, pamac_updates_properties[PAMAC_UPDATES_AUR_UPDATES_PROPERTY]);
	}
}

GPtrArray*
pamac_updates_get_ignored_aur_updates (PamacUpdates* self)
{
	GPtrArray* result;
	GPtrArray* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_ignored_aur_updates;
	result = _tmp0_;
	return result;
}

void
pamac_updates_set_ignored_aur_updates (PamacUpdates* self,
                                       GPtrArray* value)
{
	GPtrArray* old_value;
	g_return_if_fail (self != NULL);
	old_value = pamac_updates_get_ignored_aur_updates (self);
	if (old_value != value) {
		GPtrArray* _tmp0_;
		_tmp0_ = _g_ptr_array_ref0 (value);
		_g_ptr_array_unref0 (self->priv->_ignored_aur_updates);
		self->priv->_ignored_aur_updates = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, pamac_updates_properties[PAMAC_UPDATES_IGNORED_AUR_UPDATES_PROPERTY]);
	}
}

GPtrArray*
pamac_updates_get_outofdate (PamacUpdates* self)
{
	GPtrArray* result;
	GPtrArray* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_outofdate;
	result = _tmp0_;
	return result;
}

void
pamac_updates_set_outofdate (PamacUpdates* self,
                             GPtrArray* value)
{
	GPtrArray* old_value;
	g_return_if_fail (self != NULL);
	old_value = pamac_updates_get_outofdate (self);
	if (old_value != value) {
		GPtrArray* _tmp0_;
		_tmp0_ = _g_ptr_array_ref0 (value);
		_g_ptr_array_unref0 (self->priv->_outofdate);
		self->priv->_outofdate = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, pamac_updates_properties[PAMAC_UPDATES_OUTOFDATE_PROPERTY]);
	}
}

GPtrArray*
pamac_updates_get_flatpak_updates (PamacUpdates* self)
{
	GPtrArray* result;
	GPtrArray* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_flatpak_updates;
	result = _tmp0_;
	return result;
}

void
pamac_updates_set_flatpak_updates (PamacUpdates* self,
                                   GPtrArray* value)
{
	GPtrArray* old_value;
	g_return_if_fail (self != NULL);
	old_value = pamac_updates_get_flatpak_updates (self);
	if (old_value != value) {
		GPtrArray* _tmp0_;
		_tmp0_ = _g_ptr_array_ref0 (value);
		_g_ptr_array_unref0 (self->priv->_flatpak_updates);
		self->priv->_flatpak_updates = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, pamac_updates_properties[PAMAC_UPDATES_FLATPAK_UPDATES_PROPERTY]);
	}
}

static void
pamac_updates_class_init (PamacUpdatesClass * klass,
                          gpointer klass_data)
{
	pamac_updates_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &PamacUpdates_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_pamac_updates_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_pamac_updates_set_property;
	G_OBJECT_CLASS (klass)->finalize = pamac_updates_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_UPDATES_REPOS_UPDATES_PROPERTY, pamac_updates_properties[PAMAC_UPDATES_REPOS_UPDATES_PROPERTY] = g_param_spec_boxed ("repos-updates", "repos-updates", "repos-updates", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_UPDATES_IGNORED_REPOS_UPDATES_PROPERTY, pamac_updates_properties[PAMAC_UPDATES_IGNORED_REPOS_UPDATES_PROPERTY] = g_param_spec_boxed ("ignored-repos-updates", "ignored-repos-updates", "ignored-repos-updates", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_UPDATES_AUR_UPDATES_PROPERTY, pamac_updates_properties[PAMAC_UPDATES_AUR_UPDATES_PROPERTY] = g_param_spec_boxed ("aur-updates", "aur-updates", "aur-updates", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_UPDATES_IGNORED_AUR_UPDATES_PROPERTY, pamac_updates_properties[PAMAC_UPDATES_IGNORED_AUR_UPDATES_PROPERTY] = g_param_spec_boxed ("ignored-aur-updates", "ignored-aur-updates", "ignored-aur-updates", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_UPDATES_OUTOFDATE_PROPERTY, pamac_updates_properties[PAMAC_UPDATES_OUTOFDATE_PROPERTY] = g_param_spec_boxed ("outofdate", "outofdate", "outofdate", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PAMAC_UPDATES_FLATPAK_UPDATES_PROPERTY, pamac_updates_properties[PAMAC_UPDATES_FLATPAK_UPDATES_PROPERTY] = g_param_spec_boxed ("flatpak-updates", "flatpak-updates", "flatpak-updates", G_TYPE_PTR_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
pamac_updates_instance_init (PamacUpdates * self,
                             gpointer klass)
{
	GPtrArray* _tmp0_;
	GPtrArray* _tmp1_;
	GPtrArray* _tmp2_;
	GPtrArray* _tmp3_;
	GPtrArray* _tmp4_;
	GPtrArray* _tmp5_;
	self->priv = pamac_updates_get_instance_private (self);
	_tmp0_ = g_ptr_array_new_full ((guint) 0, _g_object_unref0_);
	self->priv->_repos_updates = _tmp0_;
	_tmp1_ = g_ptr_array_new_full ((guint) 0, _g_object_unref0_);
	self->priv->_ignored_repos_updates = _tmp1_;
	_tmp2_ = g_ptr_array_new_full ((guint) 0, _g_object_unref0_);
	self->priv->_aur_updates = _tmp2_;
	_tmp3_ = g_ptr_array_new_full ((guint) 0, _g_object_unref0_);
	self->priv->_ignored_aur_updates = _tmp3_;
	_tmp4_ = g_ptr_array_new_full ((guint) 0, _g_object_unref0_);
	self->priv->_outofdate = _tmp4_;
	_tmp5_ = g_ptr_array_new_full ((guint) 0, _g_object_unref0_);
	self->priv->_flatpak_updates = _tmp5_;
}

static void
pamac_updates_finalize (GObject * obj)
{
	PamacUpdates * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PAMAC_TYPE_UPDATES, PamacUpdates);
	_g_ptr_array_unref0 (self->priv->_repos_updates);
	_g_ptr_array_unref0 (self->priv->_ignored_repos_updates);
	_g_ptr_array_unref0 (self->priv->_aur_updates);
	_g_ptr_array_unref0 (self->priv->_ignored_aur_updates);
	_g_ptr_array_unref0 (self->priv->_outofdate);
	_g_ptr_array_unref0 (self->priv->_flatpak_updates);
	G_OBJECT_CLASS (pamac_updates_parent_class)->finalize (obj);
}

static GType
pamac_updates_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PamacUpdatesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) pamac_updates_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PamacUpdates), 0, (GInstanceInitFunc) pamac_updates_instance_init, NULL };
	GType pamac_updates_type_id;
	pamac_updates_type_id = g_type_register_static (G_TYPE_OBJECT, "PamacUpdates", &g_define_type_info, 0);
	PamacUpdates_private_offset = g_type_add_instance_private (pamac_updates_type_id, sizeof (PamacUpdatesPrivate));
	return pamac_updates_type_id;
}

GType
pamac_updates_get_type (void)
{
	static volatile gsize pamac_updates_type_id__once = 0;
	if (g_once_init_enter (&pamac_updates_type_id__once)) {
		GType pamac_updates_type_id;
		pamac_updates_type_id = pamac_updates_get_type_once ();
		g_once_init_leave (&pamac_updates_type_id__once, pamac_updates_type_id);
	}
	return pamac_updates_type_id__once;
}

static void
_vala_pamac_updates_get_property (GObject * object,
                                  guint property_id,
                                  GValue * value,
                                  GParamSpec * pspec)
{
	PamacUpdates * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_UPDATES, PamacUpdates);
	switch (property_id) {
		case PAMAC_UPDATES_REPOS_UPDATES_PROPERTY:
		g_value_set_boxed (value, pamac_updates_get_repos_updates (self));
		break;
		case PAMAC_UPDATES_IGNORED_REPOS_UPDATES_PROPERTY:
		g_value_set_boxed (value, pamac_updates_get_ignored_repos_updates (self));
		break;
		case PAMAC_UPDATES_AUR_UPDATES_PROPERTY:
		g_value_set_boxed (value, pamac_updates_get_aur_updates (self));
		break;
		case PAMAC_UPDATES_IGNORED_AUR_UPDATES_PROPERTY:
		g_value_set_boxed (value, pamac_updates_get_ignored_aur_updates (self));
		break;
		case PAMAC_UPDATES_OUTOFDATE_PROPERTY:
		g_value_set_boxed (value, pamac_updates_get_outofdate (self));
		break;
		case PAMAC_UPDATES_FLATPAK_UPDATES_PROPERTY:
		g_value_set_boxed (value, pamac_updates_get_flatpak_updates (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_pamac_updates_set_property (GObject * object,
                                  guint property_id,
                                  const GValue * value,
                                  GParamSpec * pspec)
{
	PamacUpdates * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PAMAC_TYPE_UPDATES, PamacUpdates);
	switch (property_id) {
		case PAMAC_UPDATES_REPOS_UPDATES_PROPERTY:
		pamac_updates_set_repos_updates (self, g_value_get_boxed (value));
		break;
		case PAMAC_UPDATES_IGNORED_REPOS_UPDATES_PROPERTY:
		pamac_updates_set_ignored_repos_updates (self, g_value_get_boxed (value));
		break;
		case PAMAC_UPDATES_AUR_UPDATES_PROPERTY:
		pamac_updates_set_aur_updates (self, g_value_get_boxed (value));
		break;
		case PAMAC_UPDATES_IGNORED_AUR_UPDATES_PROPERTY:
		pamac_updates_set_ignored_aur_updates (self, g_value_get_boxed (value));
		break;
		case PAMAC_UPDATES_OUTOFDATE_PROPERTY:
		pamac_updates_set_outofdate (self, g_value_get_boxed (value));
		break;
		case PAMAC_UPDATES_FLATPAK_UPDATES_PROPERTY:
		pamac_updates_set_flatpak_updates (self, g_value_get_boxed (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

